" Vim syntax file
" Language: PHP 5.3 & up
"
" Maintainer: Paul Garvin <paul@paulgarvin.net>
"
" Contributor: Stan Angeloff <stanimir@angeloff.name>
" URL: https://github.com/StanAngeloff/php.vim
"
" Contributor: Alessandro Antonello <aleantonello@hotmail.com>
" URL: https://github.com/aantonello/php.vim
"
" Contributor: Tim Carry <tim@pixelastic.com>
" URL: https://github.com/pixelastic/php.vim
"
" Contributor: Joshua Sherman <josh@gravityblvd.com>
" URL: https://github.com/joshtronic/php.vim
"
" Contributor: Kristijan Husak
" URL: https://github.com/kris89/php.vim
"
" Former Maintainer:  Peter Hodge <toomuchphp-vim@yahoo.com>
" Former URL: http://www.vim.org/scripts/script.php?script_id=1571
"
" Note: All of the switches for VIM 5.X and 6.X compatability were removed.
"       DO NOT USE THIS FILE WITH A VERSION OF VIM < 7.0.
"
" Note: If you are using a colour terminal with dark background, you will probably find
"       the 'elflord' colorscheme is much better for PHP's syntax than the default
"       colourscheme, because elflord's colours will better highlight the break-points
"       (Statements) in your code.
"
" Options:  php_sql_query = 1  for SQL syntax highlighting inside strings
"           php_html_in_strings = 1  for HTML syntax highlighting inside strings
"           php_parent_error_close = 1  for highlighting parent error ] or )
"           php_parent_error_open = 1  for skipping an php end tag,
"                                      if there exists an open ( or [ without a closing one
"           php_no_shorttags = 1  don't sync <? ?> as php
"           php_folding = 1  for folding classes and functions
"           php_sync_method = x
"                             x=-1 to sync by search ( default )
"                             x>0 to sync at least x lines backwards
"                             x=0 to sync from start
"
" Note:
" Setting php_folding=1 will match a closing } by comparing the indent
" before the class or function keyword with the indent of a matching }.
" Setting php_folding=2 will match all of pairs of {,} ( see known
" bugs ii )
"
" Known Bugs:
"  - setting  php_parent_error_close  on  and  php_parent_error_open  off
"    has these two leaks:
"     i) A closing ) or ] inside a string match to the last open ( or [
"        before the string, when the the closing ) or ] is on the same line
"        where the string started. In this case a following ) or ] after
"        the string would be highlighted as an error, what is incorrect.
"    ii) Same problem if you are setting php_folding = 2 with a closing
"        } inside an string on the first line of this string.
"
"  - A double-quoted string like this:
"      "$foo->someVar->someOtherVar->bar"
"    will highight '->someOtherVar->bar' as though they will be parsed
"    as object member variables, but PHP only recognizes the first
"    object member variable ($foo->someVar).


if exists("b:current_syntax")
  finish
endif

if !exists("main_syntax")
  let main_syntax = 'php'
endif

runtime! syntax/html.vim
unlet! b:current_syntax
" HTML syntax file turns on spelling for all top level words, we attempt to turn off
syntax spell default

" Set sync method if none declared
if !exists("php_sync_method")
  if exists("php_minlines")
    let php_sync_method=php_minlines
  else
    let php_sync_method=-1
  endif
endif

syn cluster htmlPreproc add=phpRegion

" Use MySQL as the default SQL syntax file.
" See https://github.com/StanAngeloff/php.vim/pull/1
if !exists('b:sql_type_override') && !exists('g:sql_type_default')
  let b:sql_type_override='mysql'
endif
syn include @sqlTop syntax/sql.vim

syn sync clear
unlet! b:current_syntax
syn cluster sqlTop remove=sqlString,sqlComment
if exists("php_sql_query")
  syn cluster phpAddStrings contains=@sqlTop
endif

if exists("php_html_in_strings")
  syn cluster phpAddStrings add=@htmlTop
endif

syn case match

" Superglobals
syn keyword phpSuperglobals GLOBALS _GET _POST _REQUEST _FILES _COOKIE _SERVER _SESSION _ENV HTTP_RAW_POST_DATA php_errormsg http_response_header argc argv contained

" Magic Constants
syn keyword phpMagicConstants __LINE__ __FILE__ __DIR__ __FUNCTION__ __CLASS__ __METHOD__ __NAMESPACE__ contained

" $_SERVER Variables
syn keyword phpServerVars GATEWAY_INTERFACE SERVER_NAME SERVER_SOFTWARE SERVER_PROTOCOL REQUEST_METHOD QUERY_STRING DOCUMENT_ROOT HTTP_ACCEPT HTTP_ACCEPT_CHARSET HTTP_ENCODING HTTP_ACCEPT_LANGUAGE HTTP_CONNECTION HTTP_HOST HTTP_REFERER HTTP_USER_AGENT REMOTE_ADDR REMOTE_PORT SCRIPT_FILENAME SERVER_ADMIN SERVER_PORT SERVER_SIGNATURE PATH_TRANSLATED SCRIPT_NAME REQUEST_URI PHP_SELF contained

" === BEGIN BUILTIN FUNCTIONS, CLASSES, AND CONSTANTS ===================================

syn case match

" amqp
syn keyword phpConstants AMQP_NOPARAM AMQP_DURABLE AMQP_PASSIVE AMQP_EXCLUSIVE AMQP_AUTODELETE AMQP_INTERNAL AMQP_NOLOCAL AMQP_AUTOACK AMQP_IFEMPTY AMQP_IFUNUSED AMQP_MANDATORY AMQP_IMMEDIATE AMQP_MULTIPLE AMQP_NOWAIT AMQP_REQUEUE AMQP_EX_TYPE_DIRECT AMQP_EX_TYPE_FANOUT AMQP_EX_TYPE_TOPIC AMQP_EX_TYPE_HEADERS AMQP_OS_SOCKET_TIMEOUT_ERRNO contained

" apcu
syn keyword phpConstants APC_LIST_ACTIVE APC_LIST_DELETED APC_ITER_KEY APC_ITER_VALUE APC_ITER_NUM_HITS APC_ITER_MTIME APC_ITER_CTIME APC_ITER_DTIME APC_ITER_ATIME APC_ITER_REFCOUNT APC_ITER_MEM_SIZE APC_ITER_TTL APC_ITER_NONE APC_ITER_ALL APC_BIN_VERIFY_MD5 APC_BIN_VERIFY_CRC32 APCU_APC_FULL_BC contained

" calendar
syn keyword phpConstants CAL_GREGORIAN CAL_JULIAN CAL_JEWISH CAL_FRENCH CAL_NUM_CALS CAL_DOW_DAYNO CAL_DOW_SHORT CAL_DOW_LONG CAL_MONTH_GREGORIAN_SHORT CAL_MONTH_GREGORIAN_LONG CAL_MONTH_JULIAN_SHORT CAL_MONTH_JULIAN_LONG CAL_MONTH_JEWISH CAL_MONTH_FRENCH CAL_EASTER_DEFAULT CAL_EASTER_ROMAN CAL_EASTER_ALWAYS_GREGORIAN CAL_EASTER_ALWAYS_JULIAN CAL_JEWISH_ADD_ALAFIM_GERESH CAL_JEWISH_ADD_ALAFIM CAL_JEWISH_ADD_GERESHAYIM contained

" Core
syn keyword phpConstants E_ERROR E_RECOVERABLE_ERROR E_WARNING E_PARSE E_NOTICE E_STRICT E_DEPRECATED E_CORE_ERROR E_CORE_WARNING E_COMPILE_ERROR E_COMPILE_WARNING E_USER_ERROR E_USER_WARNING E_USER_NOTICE E_USER_DEPRECATED E_ALL DEBUG_BACKTRACE_PROVIDE_OBJECT DEBUG_BACKTRACE_IGNORE_ARGS TRUE FALSE NULL ZEND_THREAD_SAFE ZEND_DEBUG_BUILD PHP_VERSION PHP_MAJOR_VERSION PHP_MINOR_VERSION PHP_RELEASE_VERSION PHP_EXTRA_VERSION PHP_VERSION_ID PHP_ZTS PHP_DEBUG PHP_OS PHP_SAPI DEFAULT_INCLUDE_PATH PEAR_INSTALL_DIR PEAR_EXTENSION_DIR PHP_EXTENSION_DIR PHP_PREFIX PHP_BINDIR PHP_MANDIR PHP_LIBDIR PHP_DATADIR PHP_SYSCONFDIR PHP_LOCALSTATEDIR PHP_CONFIG_FILE_PATH PHP_CONFIG_FILE_SCAN_DIR PHP_SHLIB_SUFFIX PHP_EOL PHP_MAXPATHLEN PHP_INT_MAX PHP_INT_SIZE PHP_BINARY PHP_OUTPUT_HANDLER_START PHP_OUTPUT_HANDLER_WRITE PHP_OUTPUT_HANDLER_FLUSH PHP_OUTPUT_HANDLER_CLEAN PHP_OUTPUT_HANDLER_FINAL PHP_OUTPUT_HANDLER_CONT PHP_OUTPUT_HANDLER_END PHP_OUTPUT_HANDLER_CLEANABLE PHP_OUTPUT_HANDLER_FLUSHABLE PHP_OUTPUT_HANDLER_REMOVABLE PHP_OUTPUT_HANDLER_STDFLAGS PHP_OUTPUT_HANDLER_STARTED PHP_OUTPUT_HANDLER_DISABLED UPLOAD_ERR_OK UPLOAD_ERR_INI_SIZE UPLOAD_ERR_FORM_SIZE UPLOAD_ERR_PARTIAL UPLOAD_ERR_NO_FILE UPLOAD_ERR_NO_TMP_DIR UPLOAD_ERR_CANT_WRITE UPLOAD_ERR_EXTENSION swig_runtime_data_type_pointer STDIN STDOUT STDERR contained

" couchbase
syn keyword phpConstants COUCHBASE_SUCCESS COUCHBASE_AUTH_CONTINUE COUCHBASE_DELTA_BADVAL COUCHBASE_E2BIG COUCHBASE_EBUSY COUCHBASE_EINTERNAL COUCHBASE_EINVAL COUCHBASE_ENOMEM COUCHBASE_ERROR COUCHBASE_ETMPFAIL COUCHBASE_KEY_EEXISTS COUCHBASE_KEY_ENOENT COUCHBASE_NETWORK_ERROR COUCHBASE_NOT_MY_VBUCKET COUCHBASE_NOT_STORED COUCHBASE_NOT_SUPPORTED COUCHBASE_UNKNOWN_COMMAND COUCHBASE_UNKNOWN_HOST COUCHBASE_OPT_SERIALIZER COUCHBASE_OPT_COMPRESSION COUCHBASE_OPT_PREFIX_KEY COUCHBASE_OPT_IGNOREFLAGS COUCHBASE_SERIALIZER_PHP COUCHBASE_SERIALIZER_JSON COUCHBASE_SERIALIZER_JSON_ARRAY COUCHBASE_SERIALIZER_IGBINARY COUCHBASE_COMPRESSION_NONE COUCHBASE_COMPRESSION_FASTLZ COUCHBASE_COMPRESSION_ZLIB COUCHBASE_GET_PRESERVE_ORDER COUCHBASE_OPT_VOPTS_PASSTHROUGH COUCHBASE_REPLICA_FIRST COUCHBASE_REPLICA_ALL COUCHBASE_REPLICA_SELECT SUCCESS AUTH_CONTINUE DELTA_BADVAL E2BIG EBUSY EINTERNAL EINVAL ENOMEM ERROR ETMPFAIL KEY_EEXISTS KEY_ENOENT NETWORK_ERROR NOT_MY_VBUCKET NOT_STORED NOT_SUPPORTED UNKNOWN_COMMAND UNKNOWN_HOST OPT_SERIALIZER OPT_COMPRESSION OPT_PREFIX_KEY OPT_IGNOREFLAGS SERIALIZER_PHP SERIALIZER_JSON SERIALIZER_JSON_ARRAY SERIALIZER_IGBINARY COMPRESSION_NONE COMPRESSION_FASTLZ COMPRESSION_ZLIB GET_PRESERVE_ORDER OPT_VOPTS_PASSTHROUGH REPLICA_FIRST REPLICA_ALL REPLICA_SELECT contained

" crypto
syn keyword phpConstants CIPHER_NOT_FOUND CIPHER_MODE_NOT_FOUND CIPHER_MODE_NOT_AVAILABLE CIPHER_AUTHENTICATION_NOT_SUPPORTED CIPHER_AUTHENTICATION_FAILED CIPHER_KEY_LENGTH CIPHER_IV_LENGTH CIPHER_AAD_SETTER_FLOW CIPHER_AAD_SETTER_FAILED CIPHER_TAG_GETTER_FLOW CIPHER_TAG_SETTER_FLOW CIPHER_TAG_GETTER_FAILED CIPHER_TAG_SETTER_FAILED CIPHER_TAG_LENGTH_UNDER CIPHER_TAG_LENGTH_OVER CIPHER_TAG_VARIFY_FAILED CIPHER_INIT_ALG_FAILED CIPHER_INIT_CTX_FAILED CIPHER_UPDATE_FAILED CIPHER_FINISH_FAILED ENCRYPT_INIT_STATUS ENCRYPT_UPDATE_STATUS ENCRYPT_FINISH_STATUS DECRYPT_INIT_STATUS DECRYPT_UPDATE_STATUS DECRYPT_FINISH_STATUS HASH_ALGORITHM_NOT_FOUND HASH_STATIC_NOT_FOUND HASH_INIT_FAILED HASH_UPDATE_FAILED HASH_DIGEST_FAILED MODE_ECB MODE_CBC MODE_CFB MODE_OFB MODE_CTR MODE_GCM MODE_CCM MODE_XTS ENCODE_UPDATE_STATUS ENCODE_FINISH_STATUS DECODE_UPDATE_STATUS DECODE_FINISH_STATUS DECODE_FAILED GENERATE_PREDICTABLE FILE_WRITE_PREDICTABLE contained

" curl
syn keyword phpConstants CURLOPT_AUTOREFERER CURLOPT_BINARYTRANSFER CURLOPT_BUFFERSIZE CURLOPT_CAINFO CURLOPT_CAPATH CURLOPT_CLOSEPOLICY CURLOPT_CONNECTTIMEOUT CURLOPT_COOKIE CURLOPT_COOKIEFILE CURLOPT_COOKIEJAR CURLOPT_COOKIESESSION CURLOPT_CRLF CURLOPT_CUSTOMREQUEST CURLOPT_DNS_CACHE_TIMEOUT CURLOPT_DNS_USE_GLOBAL_CACHE CURLOPT_EGDSOCKET CURLOPT_ENCODING CURLOPT_FAILONERROR CURLOPT_FILE CURLOPT_FILETIME CURLOPT_FOLLOWLOCATION CURLOPT_FORBID_REUSE CURLOPT_FRESH_CONNECT CURLOPT_FTPAPPEND CURLOPT_FTPLISTONLY CURLOPT_FTPPORT CURLOPT_FTP_USE_EPRT CURLOPT_FTP_USE_EPSV CURLOPT_HEADER CURLOPT_HEADERFUNCTION CURLOPT_HTTP200ALIASES CURLOPT_HTTPGET CURLOPT_HTTPHEADER CURLOPT_HTTPPROXYTUNNEL CURLOPT_HTTP_VERSION CURLOPT_INFILE CURLOPT_INFILESIZE CURLOPT_INTERFACE CURLOPT_KRB4LEVEL CURLOPT_LOW_SPEED_LIMIT CURLOPT_LOW_SPEED_TIME CURLOPT_MAXCONNECTS CURLOPT_MAXREDIRS CURLOPT_NETRC CURLOPT_NOBODY CURLOPT_NOPROGRESS CURLOPT_NOSIGNAL CURLOPT_PORT CURLOPT_POST CURLOPT_POSTFIELDS CURLOPT_POSTQUOTE CURLOPT_PREQUOTE CURLOPT_PRIVATE CURLOPT_PROGRESSFUNCTION CURLOPT_PROXY CURLOPT_PROXYPORT CURLOPT_PROXYTYPE CURLOPT_PROXYUSERPWD CURLOPT_PUT CURLOPT_QUOTE CURLOPT_RANDOM_FILE CURLOPT_RANGE CURLOPT_READDATA CURLOPT_READFUNCTION CURLOPT_REFERER CURLOPT_RESUME_FROM CURLOPT_RETURNTRANSFER CURLOPT_SHARE CURLOPT_SSLCERT CURLOPT_SSLCERTPASSWD CURLOPT_SSLCERTTYPE CURLOPT_SSLENGINE CURLOPT_SSLENGINE_DEFAULT CURLOPT_SSLKEY CURLOPT_SSLKEYPASSWD CURLOPT_SSLKEYTYPE CURLOPT_SSLVERSION CURLOPT_SSL_CIPHER_LIST CURLOPT_SSL_VERIFYHOST CURLOPT_SSL_VERIFYPEER CURLOPT_STDERR CURLOPT_TELNETOPTIONS CURLOPT_TIMECONDITION CURLOPT_TIMEOUT CURLOPT_TIMEVALUE CURLOPT_TRANSFERTEXT CURLOPT_UNRESTRICTED_AUTH CURLOPT_UPLOAD CURLOPT_URL CURLOPT_USERAGENT CURLOPT_USERPWD CURLOPT_VERBOSE CURLOPT_WRITEFUNCTION CURLOPT_WRITEHEADER CURLCLOSEPOLICY_CALLBACK CURLCLOSEPOLICY_LEAST_RECENTLY_USED CURLCLOSEPOLICY_LEAST_TRAFFIC CURLCLOSEPOLICY_OLDEST CURLCLOSEPOLICY_SLOWEST CURLE_ABORTED_BY_CALLBACK CURLE_BAD_CALLING_ORDER CURLE_BAD_CONTENT_ENCODING CURLE_BAD_DOWNLOAD_RESUME CURLE_BAD_FUNCTION_ARGUMENT CURLE_BAD_PASSWORD_ENTERED CURLE_COULDNT_CONNECT CURLE_COULDNT_RESOLVE_HOST CURLE_COULDNT_RESOLVE_PROXY CURLE_FAILED_INIT CURLE_FILE_COULDNT_READ_FILE CURLE_FTP_ACCESS_DENIED CURLE_FTP_BAD_DOWNLOAD_RESUME CURLE_FTP_CANT_GET_HOST CURLE_FTP_CANT_RECONNECT CURLE_FTP_COULDNT_GET_SIZE CURLE_FTP_COULDNT_RETR_FILE CURLE_FTP_COULDNT_SET_ASCII CURLE_FTP_COULDNT_SET_BINARY CURLE_FTP_COULDNT_STOR_FILE CURLE_FTP_COULDNT_USE_REST CURLE_FTP_PARTIAL_FILE CURLE_FTP_PORT_FAILED CURLE_FTP_QUOTE_ERROR CURLE_FTP_USER_PASSWORD_INCORRECT CURLE_FTP_WEIRD_227_FORMAT CURLE_FTP_WEIRD_PASS_REPLY CURLE_FTP_WEIRD_PASV_REPLY CURLE_FTP_WEIRD_SERVER_REPLY CURLE_FTP_WEIRD_USER_REPLY CURLE_FTP_WRITE_ERROR CURLE_FUNCTION_NOT_FOUND CURLE_GOT_NOTHING CURLE_HTTP_NOT_FOUND CURLE_HTTP_PORT_FAILED CURLE_HTTP_POST_ERROR CURLE_HTTP_RANGE_ERROR CURLE_HTTP_RETURNED_ERROR CURLE_LDAP_CANNOT_BIND CURLE_LDAP_SEARCH_FAILED CURLE_LIBRARY_NOT_FOUND CURLE_MALFORMAT_USER CURLE_OBSOLETE CURLE_OK CURLE_OPERATION_TIMEDOUT CURLE_OPERATION_TIMEOUTED CURLE_OUT_OF_MEMORY CURLE_PARTIAL_FILE CURLE_READ_ERROR CURLE_RECV_ERROR CURLE_SEND_ERROR CURLE_SHARE_IN_USE CURLE_SSL_CACERT CURLE_SSL_CERTPROBLEM CURLE_SSL_CIPHER CURLE_SSL_CONNECT_ERROR CURLE_SSL_ENGINE_NOTFOUND CURLE_SSL_ENGINE_SETFAILED CURLE_SSL_PEER_CERTIFICATE CURLE_TELNET_OPTION_SYNTAX CURLE_TOO_MANY_REDIRECTS CURLE_UNKNOWN_TELNET_OPTION CURLE_UNSUPPORTED_PROTOCOL CURLE_URL_MALFORMAT CURLE_URL_MALFORMAT_USER CURLE_WRITE_ERROR CURLINFO_CONNECT_TIME CURLINFO_CONTENT_LENGTH_DOWNLOAD CURLINFO_CONTENT_LENGTH_UPLOAD CURLINFO_CONTENT_TYPE CURLINFO_EFFECTIVE_URL CURLINFO_FILETIME CURLINFO_HEADER_OUT CURLINFO_HEADER_SIZE CURLINFO_HTTP_CODE CURLINFO_LASTONE CURLINFO_NAMELOOKUP_TIME CURLINFO_PRETRANSFER_TIME CURLINFO_PRIVATE CURLINFO_REDIRECT_COUNT CURLINFO_REDIRECT_TIME CURLINFO_REQUEST_SIZE CURLINFO_SIZE_DOWNLOAD CURLINFO_SIZE_UPLOAD CURLINFO_SPEED_DOWNLOAD CURLINFO_SPEED_UPLOAD CURLINFO_SSL_VERIFYRESULT CURLINFO_STARTTRANSFER_TIME CURLINFO_TOTAL_TIME CURLMSG_DONE CURLVERSION_NOW CURLM_BAD_EASY_HANDLE CURLM_BAD_HANDLE CURLM_CALL_MULTI_PERFORM CURLM_INTERNAL_ERROR CURLM_OK CURLM_OUT_OF_MEMORY CURLPROXY_HTTP CURLPROXY_SOCKS4 CURLPROXY_SOCKS5 CURLSHOPT_NONE CURLSHOPT_SHARE CURLSHOPT_UNSHARE CURL_HTTP_VERSION_1_0 CURL_HTTP_VERSION_1_1 CURL_HTTP_VERSION_NONE CURL_LOCK_DATA_COOKIE CURL_LOCK_DATA_DNS CURL_LOCK_DATA_SSL_SESSION CURL_NETRC_IGNORED CURL_NETRC_OPTIONAL CURL_NETRC_REQUIRED CURL_SSLVERSION_DEFAULT CURL_SSLVERSION_SSLv2 CURL_SSLVERSION_SSLv3 CURL_SSLVERSION_TLSv1 CURL_TIMECOND_IFMODSINCE CURL_TIMECOND_IFUNMODSINCE CURL_TIMECOND_LASTMOD CURL_TIMECOND_NONE CURL_VERSION_IPV6 CURL_VERSION_KERBEROS4 CURL_VERSION_LIBZ CURL_VERSION_SSL CURLOPT_HTTPAUTH CURLAUTH_ANY CURLAUTH_ANYSAFE CURLAUTH_BASIC CURLAUTH_DIGEST CURLAUTH_GSSNEGOTIATE CURLAUTH_NONE CURLAUTH_NTLM CURLINFO_HTTP_CONNECTCODE CURLOPT_FTP_CREATE_MISSING_DIRS CURLOPT_PROXYAUTH CURLE_FILESIZE_EXCEEDED CURLE_LDAP_INVALID_URL CURLINFO_HTTPAUTH_AVAIL CURLINFO_RESPONSE_CODE CURLINFO_PROXYAUTH_AVAIL CURLOPT_FTP_RESPONSE_TIMEOUT CURLOPT_IPRESOLVE CURLOPT_MAXFILESIZE CURL_IPRESOLVE_V4 CURL_IPRESOLVE_V6 CURL_IPRESOLVE_WHATEVER CURLE_FTP_SSL_FAILED CURLFTPSSL_ALL CURLFTPSSL_CONTROL CURLFTPSSL_NONE CURLFTPSSL_TRY CURLOPT_FTP_SSL CURLOPT_NETRC_FILE CURLFTPAUTH_DEFAULT CURLFTPAUTH_SSL CURLFTPAUTH_TLS CURLOPT_FTPSSLAUTH CURLOPT_FTP_ACCOUNT CURLOPT_TCP_NODELAY CURLINFO_OS_ERRNO CURLINFO_NUM_CONNECTS CURLINFO_SSL_ENGINES CURLINFO_COOKIELIST CURLOPT_COOKIELIST CURLOPT_IGNORE_CONTENT_LENGTH CURLOPT_FTP_SKIP_PASV_IP CURLOPT_FTP_FILEMETHOD CURLOPT_CONNECT_ONLY CURLOPT_LOCALPORT CURLOPT_LOCALPORTRANGE CURLFTPMETHOD_MULTICWD CURLFTPMETHOD_NOCWD CURLFTPMETHOD_SINGLECWD CURLINFO_FTP_ENTRY_PATH CURLOPT_FTP_ALTERNATIVE_TO_USER CURLOPT_MAX_RECV_SPEED_LARGE CURLOPT_MAX_SEND_SPEED_LARGE CURLOPT_SSL_SESSIONID_CACHE CURLMOPT_PIPELINING CURLE_SSH CURLOPT_FTP_SSL_CCC CURLOPT_SSH_AUTH_TYPES CURLOPT_SSH_PRIVATE_KEYFILE CURLOPT_SSH_PUBLIC_KEYFILE CURLFTPSSL_CCC_ACTIVE CURLFTPSSL_CCC_NONE CURLFTPSSL_CCC_PASSIVE CURLOPT_CONNECTTIMEOUT_MS CURLOPT_HTTP_CONTENT_DECODING CURLOPT_HTTP_TRANSFER_DECODING CURLOPT_TIMEOUT_MS CURLMOPT_MAXCONNECTS CURLOPT_KRBLEVEL CURLOPT_NEW_DIRECTORY_PERMS CURLOPT_NEW_FILE_PERMS CURLOPT_APPEND CURLOPT_DIRLISTONLY CURLOPT_USE_SSL CURLUSESSL_ALL CURLUSESSL_CONTROL CURLUSESSL_NONE CURLUSESSL_TRY CURLOPT_SSH_HOST_PUBLIC_KEY_MD5 CURLOPT_PROXY_TRANSFER_MODE CURLPAUSE_ALL CURLPAUSE_CONT CURLPAUSE_RECV CURLPAUSE_RECV_CONT CURLPAUSE_SEND CURLPAUSE_SEND_CONT CURL_READFUNC_PAUSE CURL_WRITEFUNC_PAUSE CURLINFO_REDIRECT_URL CURLINFO_APPCONNECT_TIME CURLINFO_PRIMARY_IP CURLOPT_ADDRESS_SCOPE CURLOPT_CRLFILE CURLOPT_ISSUERCERT CURLOPT_KEYPASSWD CURLSSH_AUTH_ANY CURLSSH_AUTH_DEFAULT CURLSSH_AUTH_HOST CURLSSH_AUTH_KEYBOARD CURLSSH_AUTH_NONE CURLSSH_AUTH_PASSWORD CURLSSH_AUTH_PUBLICKEY CURLINFO_CERTINFO CURLOPT_CERTINFO CURLOPT_PASSWORD CURLOPT_POSTREDIR CURLOPT_PROXYPASSWORD CURLOPT_PROXYUSERNAME CURLOPT_USERNAME CURLAUTH_DIGEST_IE CURLINFO_CONDITION_UNMET CURLOPT_NOPROXY CURLOPT_PROTOCOLS CURLOPT_REDIR_PROTOCOLS CURLOPT_SOCKS5_GSSAPI_NEC CURLOPT_SOCKS5_GSSAPI_SERVICE CURLOPT_TFTP_BLKSIZE CURLPROTO_ALL CURLPROTO_DICT CURLPROTO_FILE CURLPROTO_FTP CURLPROTO_FTPS CURLPROTO_HTTP CURLPROTO_HTTPS CURLPROTO_LDAP CURLPROTO_LDAPS CURLPROTO_SCP CURLPROTO_SFTP CURLPROTO_TELNET CURLPROTO_TFTP CURLOPT_SSH_KNOWNHOSTS CURLINFO_RTSP_CLIENT_CSEQ CURLINFO_RTSP_CSEQ_RECV CURLINFO_RTSP_SERVER_CSEQ CURLINFO_RTSP_SESSION_ID CURLOPT_FTP_USE_PRET CURLOPT_MAIL_FROM CURLOPT_MAIL_RCPT CURLOPT_RTSP_CLIENT_CSEQ CURLOPT_RTSP_REQUEST CURLOPT_RTSP_SERVER_CSEQ CURLOPT_RTSP_SESSION_ID CURLOPT_RTSP_STREAM_URI CURLOPT_RTSP_TRANSPORT CURLPROTO_IMAP CURLPROTO_IMAPS CURLPROTO_POP3 CURLPROTO_POP3S CURLPROTO_RTSP CURLPROTO_SMTP CURLPROTO_SMTPS CURL_RTSPREQ_ANNOUNCE CURL_RTSPREQ_DESCRIBE CURL_RTSPREQ_GET_PARAMETER CURL_RTSPREQ_OPTIONS CURL_RTSPREQ_PAUSE CURL_RTSPREQ_PLAY CURL_RTSPREQ_RECEIVE CURL_RTSPREQ_RECORD CURL_RTSPREQ_SETUP CURL_RTSPREQ_SET_PARAMETER CURL_RTSPREQ_TEARDOWN CURLINFO_LOCAL_IP CURLINFO_LOCAL_PORT CURLINFO_PRIMARY_PORT CURLOPT_FNMATCH_FUNCTION CURLOPT_WILDCARDMATCH CURLPROTO_RTMP CURLPROTO_RTMPE CURLPROTO_RTMPS CURLPROTO_RTMPT CURLPROTO_RTMPTE CURLPROTO_RTMPTS CURL_FNMATCHFUNC_FAIL CURL_FNMATCHFUNC_MATCH CURL_FNMATCHFUNC_NOMATCH CURLPROTO_GOPHER CURLAUTH_ONLY CURLOPT_RESOLVE CURLOPT_TLSAUTH_PASSWORD CURLOPT_TLSAUTH_TYPE CURLOPT_TLSAUTH_USERNAME CURL_TLSAUTH_SRP CURLOPT_ACCEPT_ENCODING CURLOPT_TRANSFER_ENCODING CURLGSSAPI_DELEGATION_FLAG CURLGSSAPI_DELEGATION_POLICY_FLAG CURLOPT_GSSAPI_DELEGATION CURLOPT_ACCEPTTIMEOUT_MS CURLOPT_DNS_SERVERS CURLOPT_MAIL_AUTH CURLOPT_SSL_OPTIONS CURLOPT_TCP_KEEPALIVE CURLOPT_TCP_KEEPIDLE CURLOPT_TCP_KEEPINTVL CURLSSLOPT_ALLOW_BEAST CURLOPT_SAFE_UPLOAD contained

" date
syn keyword phpConstants DATE_ATOM DATE_COOKIE DATE_ISO8601 DATE_RFC822 DATE_RFC850 DATE_RFC1036 DATE_RFC1123 DATE_RFC2822 DATE_RFC3339 DATE_RSS DATE_W3C SUNFUNCS_RET_TIMESTAMP SUNFUNCS_RET_STRING SUNFUNCS_RET_DOUBLE ATOM COOKIE ISO8601 RFC822 RFC850 RFC1036 RFC1123 RFC2822 RFC3339 RSS W3C AFRICA AMERICA ANTARCTICA ARCTIC ASIA ATLANTIC AUSTRALIA EUROPE INDIAN PACIFIC UTC ALL ALL_WITH_BC PER_COUNTRY EXCLUDE_START_DATE contained

" dmtx
syn keyword phpConstants SYMBOL_SHAPE_AUTO SYMBOL_SQUARE_AUTO SYMBOL_SQUARE_COUNT SYMBOL_RECT_AUTO SYMBOL_RECT_COUNT TYPE_MATRIX TYPE_MOSAIC SCHEME_ASCII SCHEME_C40 SCHEME_TEXT SCHEME_X12 SCHEME_EDITFACT SCHEME_BASE256 contained

" dom
syn keyword phpConstants XML_ELEMENT_NODE XML_ATTRIBUTE_NODE XML_TEXT_NODE XML_CDATA_SECTION_NODE XML_ENTITY_REF_NODE XML_ENTITY_NODE XML_PI_NODE XML_COMMENT_NODE XML_DOCUMENT_NODE XML_DOCUMENT_TYPE_NODE XML_DOCUMENT_FRAG_NODE XML_NOTATION_NODE XML_HTML_DOCUMENT_NODE XML_DTD_NODE XML_ELEMENT_DECL_NODE XML_ATTRIBUTE_DECL_NODE XML_ENTITY_DECL_NODE XML_NAMESPACE_DECL_NODE XML_LOCAL_NAMESPACE XML_ATTRIBUTE_CDATA XML_ATTRIBUTE_ID XML_ATTRIBUTE_IDREF XML_ATTRIBUTE_IDREFS XML_ATTRIBUTE_ENTITY XML_ATTRIBUTE_NMTOKEN XML_ATTRIBUTE_NMTOKENS XML_ATTRIBUTE_ENUMERATION XML_ATTRIBUTE_NOTATION DOM_PHP_ERR DOM_INDEX_SIZE_ERR DOMSTRING_SIZE_ERR DOM_HIERARCHY_REQUEST_ERR DOM_WRONG_DOCUMENT_ERR DOM_INVALID_CHARACTER_ERR DOM_NO_DATA_ALLOWED_ERR DOM_NO_MODIFICATION_ALLOWED_ERR DOM_NOT_FOUND_ERR DOM_NOT_SUPPORTED_ERR DOM_INUSE_ATTRIBUTE_ERR DOM_INVALID_STATE_ERR DOM_SYNTAX_ERR DOM_INVALID_MODIFICATION_ERR DOM_NAMESPACE_ERR DOM_INVALID_ACCESS_ERR DOM_VALIDATION_ERR contained

" ev
syn keyword phpConstants FLAG_AUTO FLAG_NOENV FLAG_FORKCHECK FLAG_NOINOTIFY FLAG_SIGNALFD FLAG_NOSIGMASK RUN_NOWAIT RUN_ONCE BREAK_CANCEL BREAK_ONE BREAK_ALL MINPRI MAXPRI READ WRITE TIMER PERIODIC SIGNAL CHILD STAT IDLE PREPARE CHECK EMBED CUSTOM ERROR BACKEND_SELECT BACKEND_POLL BACKEND_EPOLL BACKEND_KQUEUE BACKEND_DEVPOLL BACKEND_PORT BACKEND_ALL BACKEND_MASK contained

" exif
syn keyword phpConstants EXIF_USE_MBSTRING contained

" fileinfo
syn keyword phpConstants FILEINFO_NONE FILEINFO_SYMLINK FILEINFO_MIME FILEINFO_MIME_TYPE FILEINFO_MIME_ENCODING FILEINFO_DEVICES FILEINFO_CONTINUE FILEINFO_PRESERVE_ATIME FILEINFO_RAW contained

" filter
syn keyword phpConstants INPUT_POST INPUT_GET INPUT_COOKIE INPUT_ENV INPUT_SERVER INPUT_SESSION INPUT_REQUEST FILTER_FLAG_NONE FILTER_REQUIRE_SCALAR FILTER_REQUIRE_ARRAY FILTER_FORCE_ARRAY FILTER_NULL_ON_FAILURE FILTER_VALIDATE_INT FILTER_VALIDATE_BOOLEAN FILTER_VALIDATE_FLOAT FILTER_VALIDATE_REGEXP FILTER_VALIDATE_URL FILTER_VALIDATE_EMAIL FILTER_VALIDATE_IP FILTER_VALIDATE_MAC FILTER_DEFAULT FILTER_UNSAFE_RAW FILTER_SANITIZE_STRING FILTER_SANITIZE_STRIPPED FILTER_SANITIZE_ENCODED FILTER_SANITIZE_SPECIAL_CHARS FILTER_SANITIZE_FULL_SPECIAL_CHARS FILTER_SANITIZE_EMAIL FILTER_SANITIZE_URL FILTER_SANITIZE_NUMBER_INT FILTER_SANITIZE_NUMBER_FLOAT FILTER_SANITIZE_MAGIC_QUOTES FILTER_CALLBACK FILTER_FLAG_ALLOW_OCTAL FILTER_FLAG_ALLOW_HEX FILTER_FLAG_STRIP_LOW FILTER_FLAG_STRIP_HIGH FILTER_FLAG_STRIP_BACKTICK FILTER_FLAG_ENCODE_LOW FILTER_FLAG_ENCODE_HIGH FILTER_FLAG_ENCODE_AMP FILTER_FLAG_NO_ENCODE_QUOTES FILTER_FLAG_EMPTY_STRING_NULL FILTER_FLAG_ALLOW_FRACTION FILTER_FLAG_ALLOW_THOUSAND FILTER_FLAG_ALLOW_SCIENTIFIC FILTER_FLAG_SCHEME_REQUIRED FILTER_FLAG_HOST_REQUIRED FILTER_FLAG_PATH_REQUIRED FILTER_FLAG_QUERY_REQUIRED FILTER_FLAG_IPV4 FILTER_FLAG_IPV6 FILTER_FLAG_NO_RES_RANGE FILTER_FLAG_NO_PRIV_RANGE contained

" ftp
syn keyword phpConstants FTP_ASCII FTP_TEXT FTP_BINARY FTP_IMAGE FTP_AUTORESUME FTP_TIMEOUT_SEC FTP_AUTOSEEK FTP_FAILED FTP_FINISHED FTP_MOREDATA contained

" gearman
syn keyword phpConstants GEARMAN_DEFAULT_TCP_HOST GEARMAN_DEFAULT_TCP_PORT GEARMAN_DEFAULT_SOCKET_TIMEOUT GEARMAN_DEFAULT_SOCKET_SEND_SIZE GEARMAN_DEFAULT_SOCKET_RECV_SIZE GEARMAN_MAX_ERROR_SIZE GEARMAN_PACKET_HEADER_SIZE GEARMAN_JOB_HANDLE_SIZE GEARMAN_OPTION_SIZE GEARMAN_UNIQUE_SIZE GEARMAN_MAX_COMMAND_ARGS GEARMAN_ARGS_BUFFER_SIZE GEARMAN_SEND_BUFFER_SIZE GEARMAN_RECV_BUFFER_SIZE GEARMAN_WORKER_WAIT_TIMEOUT GEARMAN_SUCCESS GEARMAN_IO_WAIT GEARMAN_SHUTDOWN GEARMAN_SHUTDOWN_GRACEFUL GEARMAN_ERRNO GEARMAN_EVENT GEARMAN_TOO_MANY_ARGS GEARMAN_NO_ACTIVE_FDS GEARMAN_INVALID_MAGIC GEARMAN_INVALID_COMMAND GEARMAN_INVALID_PACKET GEARMAN_UNEXPECTED_PACKET GEARMAN_GETADDRINFO GEARMAN_NO_SERVERS GEARMAN_LOST_CONNECTION GEARMAN_MEMORY_ALLOCATION_FAILURE GEARMAN_JOB_EXISTS GEARMAN_JOB_QUEUE_FULL GEARMAN_SERVER_ERROR GEARMAN_WORK_ERROR GEARMAN_WORK_DATA GEARMAN_WORK_WARNING GEARMAN_WORK_STATUS GEARMAN_WORK_EXCEPTION GEARMAN_WORK_FAIL GEARMAN_NOT_CONNECTED GEARMAN_COULD_NOT_CONNECT GEARMAN_SEND_IN_PROGRESS GEARMAN_RECV_IN_PROGRESS GEARMAN_NOT_FLUSHING GEARMAN_DATA_TOO_LARGE GEARMAN_INVALID_FUNCTION_NAME GEARMAN_INVALID_WORKER_FUNCTION GEARMAN_NO_REGISTERED_FUNCTIONS GEARMAN_NO_JOBS GEARMAN_ECHO_DATA_CORRUPTION GEARMAN_NEED_WORKLOAD_FN GEARMAN_PAUSE GEARMAN_UNKNOWN_STATE GEARMAN_PTHREAD GEARMAN_PIPE_EOF GEARMAN_QUEUE_ERROR GEARMAN_FLUSH_DATA GEARMAN_SEND_BUFFER_TOO_SMALL GEARMAN_IGNORE_PACKET GEARMAN_UNKNOWN_OPTION GEARMAN_TIMEOUT GEARMAN_MAX_RETURN GEARMAN_VERBOSE_FATAL GEARMAN_VERBOSE_ERROR GEARMAN_VERBOSE_INFO GEARMAN_VERBOSE_DEBUG GEARMAN_VERBOSE_CRAZY GEARMAN_VERBOSE_MAX GEARMAN_NON_BLOCKING GEARMAN_DONT_TRACK_PACKETS GEARMAN_CON_READY GEARMAN_CON_PACKET_IN_USE GEARMAN_CON_EXTERNAL_FD GEARMAN_CON_IGNORE_LOST_CONNECTION GEARMAN_CON_CLOSE_AFTER_FLUSH GEARMAN_CON_SEND_STATE_NONE GEARMAN_CON_RECV_STATE_READ_DATA GEARMAN_COMMAND_TEXT GEARMAN_COMMAND_CAN_DO GEARMAN_COMMAND_CANT_DO GEARMAN_COMMAND_RESET_ABILITIES GEARMAN_COMMAND_PRE_SLEEP GEARMAN_COMMAND_UNUSED GEARMAN_COMMAND_NOOP GEARMAN_COMMAND_SUBMIT_JOB GEARMAN_COMMAND_JOB_CREATED GEARMAN_COMMAND_GRAB_JOB GEARMAN_COMMAND_NO_JOB GEARMAN_COMMAND_JOB_ASSIGN GEARMAN_COMMAND_WORK_STATUS GEARMAN_COMMAND_WORK_COMPLETE GEARMAN_COMMAND_WORK_FAIL GEARMAN_COMMAND_GET_STATUS GEARMAN_COMMAND_ECHO_REQ GEARMAN_COMMAND_ECHO_RES GEARMAN_COMMAND_SUBMIT_JOB_BG GEARMAN_COMMAND_ERROR GEARMAN_COMMAND_STATUS_RES GEARMAN_COMMAND_SUBMIT_JOB_HIGH GEARMAN_COMMAND_SET_CLIENT_ID GEARMAN_COMMAND_CAN_DO_TIMEOUT GEARMAN_COMMAND_ALL_YOURS GEARMAN_COMMAND_WORK_EXCEPTION GEARMAN_COMMAND_OPTION_REQ GEARMAN_COMMAND_OPTION_RES GEARMAN_COMMAND_WORK_DATA GEARMAN_COMMAND_WORK_WARNING GEARMAN_COMMAND_GRAB_JOB_UNIQ GEARMAN_COMMAND_JOB_ASSIGN_UNIQ GEARMAN_COMMAND_SUBMIT_JOB_HIGH_BG GEARMAN_COMMAND_SUBMIT_JOB_LOW GEARMAN_COMMAND_SUBMIT_JOB_LOW_BG GEARMAN_COMMAND_SUBMIT_JOB_SCHED GEARMAN_COMMAND_SUBMIT_JOB_EPOCH GEARMAN_COMMAND_MAX GEARMAN_TASK_STATE_NEW GEARMAN_TASK_STATE_SUBMIT GEARMAN_TASK_STATE_WORKLOAD GEARMAN_TASK_STATE_WORK GEARMAN_TASK_STATE_CREATED GEARMAN_TASK_STATE_DATA GEARMAN_TASK_STATE_WARNING GEARMAN_TASK_STATE_STATUS GEARMAN_TASK_STATE_COMPLETE GEARMAN_TASK_STATE_EXCEPTION GEARMAN_TASK_STATE_FAIL GEARMAN_TASK_STATE_FINISHED GEARMAN_JOB_PRIORITY_HIGH GEARMAN_JOB_PRIORITY_NORMAL GEARMAN_JOB_PRIORITY_LOW GEARMAN_JOB_PRIORITY_MAX GEARMAN_CLIENT_ALLOCATED GEARMAN_CLIENT_NON_BLOCKING GEARMAN_CLIENT_TASK_IN_USE GEARMAN_CLIENT_UNBUFFERED_RESULT GEARMAN_CLIENT_NO_NEW GEARMAN_CLIENT_FREE_TASKS GEARMAN_CLIENT_STATE_IDLE GEARMAN_CLIENT_STATE_NEW GEARMAN_CLIENT_STATE_SUBMIT GEARMAN_CLIENT_STATE_PACKET GEARMAN_WORKER_ALLOCATED GEARMAN_WORKER_NON_BLOCKING GEARMAN_WORKER_PACKET_INIT GEARMAN_WORKER_GRAB_JOB_IN_USE GEARMAN_WORKER_PRE_SLEEP_IN_USE GEARMAN_WORKER_WORK_JOB_IN_USE GEARMAN_WORKER_CHANGE GEARMAN_WORKER_GRAB_UNIQ GEARMAN_WORKER_TIMEOUT_RETURN GEARMAN_WORKER_STATE_START GEARMAN_WORKER_STATE_FUNCTION_SEND GEARMAN_WORKER_STATE_CONNECT GEARMAN_WORKER_STATE_GRAB_JOB_SEND GEARMAN_WORKER_STATE_GRAB_JOB_RECV GEARMAN_WORKER_STATE_PRE_SLEEP contained

" gd
syn keyword phpConstants IMG_GIF IMG_JPG IMG_JPEG IMG_PNG IMG_WBMP IMG_XPM IMG_COLOR_TILED IMG_COLOR_STYLED IMG_COLOR_BRUSHED IMG_COLOR_STYLEDBRUSHED IMG_COLOR_TRANSPARENT IMG_ARC_ROUNDED IMG_ARC_PIE IMG_ARC_CHORD IMG_ARC_NOFILL IMG_ARC_EDGED IMG_GD2_RAW IMG_GD2_COMPRESSED IMG_FLIP_HORIZONTAL IMG_FLIP_VERTICAL IMG_FLIP_BOTH IMG_EFFECT_REPLACE IMG_EFFECT_ALPHABLEND IMG_EFFECT_NORMAL IMG_EFFECT_OVERLAY IMG_CROP_DEFAULT IMG_CROP_TRANSPARENT IMG_CROP_BLACK IMG_CROP_WHITE IMG_CROP_SIDES IMG_CROP_THRESHOLD IMG_BELL IMG_BESSEL IMG_BILINEAR_FIXED IMG_BICUBIC IMG_BICUBIC_FIXED IMG_BLACKMAN IMG_BOX IMG_BSPLINE IMG_CATMULLROM IMG_GAUSSIAN IMG_GENERALIZED_CUBIC IMG_HERMITE IMG_HAMMING IMG_HANNING IMG_MITCHELL IMG_POWER IMG_QUADRATIC IMG_SINC IMG_NEAREST_NEIGHBOUR IMG_WEIGHTED4 IMG_TRIANGLE IMG_AFFINE_TRANSLATE IMG_AFFINE_SCALE IMG_AFFINE_ROTATE IMG_AFFINE_SHEAR_HORIZONTAL IMG_AFFINE_SHEAR_VERTICAL GD_BUNDLED IMG_FILTER_NEGATE IMG_FILTER_GRAYSCALE IMG_FILTER_BRIGHTNESS IMG_FILTER_CONTRAST IMG_FILTER_COLORIZE IMG_FILTER_EDGEDETECT IMG_FILTER_GAUSSIAN_BLUR IMG_FILTER_SELECTIVE_BLUR IMG_FILTER_EMBOSS IMG_FILTER_MEAN_REMOVAL IMG_FILTER_SMOOTH IMG_FILTER_PIXELATE GD_VERSION GD_MAJOR_VERSION GD_MINOR_VERSION GD_RELEASE_VERSION GD_EXTRA_VERSION PNG_NO_FILTER PNG_FILTER_NONE PNG_FILTER_SUB PNG_FILTER_UP PNG_FILTER_AVG PNG_FILTER_PAETH PNG_ALL_FILTERS contained

" geoip
syn keyword phpConstants GEOIP_COUNTRY_EDITION GEOIP_REGION_EDITION_REV0 GEOIP_CITY_EDITION_REV0 GEOIP_ORG_EDITION GEOIP_ISP_EDITION GEOIP_CITY_EDITION_REV1 GEOIP_REGION_EDITION_REV1 GEOIP_PROXY_EDITION GEOIP_ASNUM_EDITION GEOIP_NETSPEED_EDITION GEOIP_DOMAIN_EDITION GEOIP_UNKNOWN_SPEED GEOIP_DIALUP_SPEED GEOIP_CABLEDSL_SPEED GEOIP_CORPORATE_SPEED contained

" gmagick
syn keyword phpConstants COLOR_BLACK COLOR_BLUE COLOR_CYAN COLOR_GREEN COLOR_RED COLOR_YELLOW COLOR_MAGENTA COLOR_OPACITY COLOR_ALPHA COLOR_FUZZ GMAGICK_EXTNUM COMPOSITE_DEFAULT COMPOSITE_UNDEFINED COMPOSITE_NO COMPOSITE_ADD COMPOSITE_ATOP COMPOSITE_BUMPMAP COMPOSITE_CLEAR COMPOSITE_COLORIZE COMPOSITE_COPYBLACK COMPOSITE_COPYBLUE COMPOSITE_COPY COMPOSITE_COPYCYAN COMPOSITE_COPYGREEN COMPOSITE_COPYMAGENTA COMPOSITE_COPYOPACITY COMPOSITE_COPYRED COMPOSITE_COPYYELLOW COMPOSITE_DARKEN COMPOSITE_DIFFERENCE COMPOSITE_DISPLACE COMPOSITE_DISSOLVE COMPOSITE_HUE COMPOSITE_IN COMPOSITE_LIGHTEN COMPOSITE_LUMINIZE COMPOSITE_MINUS COMPOSITE_MODULATE COMPOSITE_MULTIPLY COMPOSITE_OUT COMPOSITE_OVER COMPOSITE_OVERLAY COMPOSITE_PLUS COMPOSITE_REPLACE COMPOSITE_SATURATE COMPOSITE_SCREEN COMPOSITE_SUBTRACT COMPOSITE_THRESHOLD COMPOSITE_XOR MONTAGEMODE_FRAME MONTAGEMODE_UNFRAME MONTAGEMODE_CONCATENATE STYLE_NORMAL STYLE_ITALIC STYLE_OBLIQUE STYLE_ANY FILTER_UNDEFINED FILTER_POINT FILTER_BOX FILTER_TRIANGLE FILTER_HERMITE FILTER_HANNING FILTER_HAMMING FILTER_BLACKMAN FILTER_GAUSSIAN FILTER_QUADRATIC FILTER_CUBIC FILTER_CATROM FILTER_MITCHELL FILTER_LANCZOS FILTER_BESSEL FILTER_SINC IMGTYPE_UNDEFINED IMGTYPE_BILEVEL IMGTYPE_GRAYSCALE IMGTYPE_GRAYSCALEMATTE IMGTYPE_PALETTE IMGTYPE_PALETTEMATTE IMGTYPE_TRUECOLOR IMGTYPE_TRUECOLORMATTE IMGTYPE_COLORSEPARATION IMGTYPE_COLORSEPARATIONMATTE IMGTYPE_OPTIMIZE RESOLUTION_UNDEFINED RESOLUTION_PIXELSPERINCH RESOLUTION_PIXELSPERCENTIMETER COMPRESSION_UNDEFINED COMPRESSION_NO COMPRESSION_BZIP COMPRESSION_FAX COMPRESSION_GROUP4 COMPRESSION_JPEG COMPRESSION_LOSSLESSJPEG COMPRESSION_LZW COMPRESSION_RLE COMPRESSION_ZIP PAINT_POINT PAINT_REPLACE PAINT_FLOODFILL PAINT_FILLTOBORDER PAINT_RESET GRAVITY_NORTHWEST GRAVITY_NORTH GRAVITY_NORTHEAST GRAVITY_WEST GRAVITY_CENTER GRAVITY_EAST GRAVITY_SOUTHWEST GRAVITY_SOUTH GRAVITY_SOUTHEAST STRETCH_NORMAL STRETCH_ULTRACONDENSED STRETCH_CONDENSED STRETCH_SEMICONDENSED STRETCH_SEMIEXPANDED STRETCH_EXPANDED STRETCH_EXTRAEXPANDED STRETCH_ULTRAEXPANDED STRETCH_ANY ALIGN_UNDEFINED ALIGN_LEFT ALIGN_CENTER ALIGN_RIGHT DECORATION_NO DECORATION_UNDERLINE DECORATION_OVERLINE DECORATION_LINETROUGH NOISE_UNIFORM NOISE_GAUSSIAN NOISE_MULTIPLICATIVEGAUSSIAN NOISE_IMPULSE NOISE_LAPLACIAN NOISE_POISSON CHANNEL_UNDEFINED CHANNEL_RED CHANNEL_CYAN CHANNEL_GREEN CHANNEL_MAGENTA CHANNEL_BLUE CHANNEL_YELLOW CHANNEL_OPACITY CHANNEL_MATTE CHANNEL_BLACK CHANNEL_INDEX CHANNEL_ALL CHANNEL_DEFAULT METRIC_UNDEFINED METRIC_MEANABSOLUTEERROR METRIC_MEANSQUAREERROR METRIC_PEAKABSOLUTEERROR METRIC_PEAKSIGNALTONOISERATIO METRIC_ROOTMEANSQUAREDERROR PIXEL_CHAR PIXEL_DOUBLE PIXEL_FLOAT PIXEL_INTEGER PIXEL_LONG PIXEL_SHORT COLORSPACE_UNDEFINED COLORSPACE_RGB COLORSPACE_GRAY COLORSPACE_TRANSPARENT COLORSPACE_OHTA COLORSPACE_LAB COLORSPACE_XYZ COLORSPACE_YCBCR COLORSPACE_YCC COLORSPACE_YIQ COLORSPACE_YPBPR COLORSPACE_YUV COLORSPACE_CMYK COLORSPACE_SRGB COLORSPACE_HSL COLORSPACE_HWB VIRTUALPIXELMETHOD_UNDEFINED VIRTUALPIXELMETHOD_CONSTANT VIRTUALPIXELMETHOD_EDGE VIRTUALPIXELMETHOD_MIRROR VIRTUALPIXELMETHOD_TILE PREVIEW_UNDEFINED PREVIEW_ROTATE PREVIEW_SHEAR PREVIEW_ROLL PREVIEW_HUE PREVIEW_SATURATION PREVIEW_BRIGHTNESS PREVIEW_GAMMA PREVIEW_SPIFF PREVIEW_DULL PREVIEW_GRAYSCALE PREVIEW_QUANTIZE PREVIEW_DESPECKLE PREVIEW_REDUCENOISE PREVIEW_ADDNOISE PREVIEW_SHARPEN PREVIEW_BLUR PREVIEW_THRESHOLD PREVIEW_EDGEDETECT PREVIEW_SPREAD PREVIEW_SOLARIZE PREVIEW_SHADE PREVIEW_RAISE PREVIEW_SEGMENT PREVIEW_SWIRL PREVIEW_IMPLODE PREVIEW_WAVE PREVIEW_OILPAINT PREVIEW_CHARCOALDRAWING PREVIEW_JPEG RENDERINGINTENT_UNDEFINED RENDERINGINTENT_SATURATION RENDERINGINTENT_PERCEPTUAL RENDERINGINTENT_ABSOLUTE RENDERINGINTENT_RELATIVE INTERLACE_UNDEFINED INTERLACE_NO INTERLACE_LINE INTERLACE_PLANE INTERLACE_PARTITION FILLRULE_UNDEFINED FILLRULE_EVENODD FILLRULE_NONZERO PATHUNITS_USERSPACE PATHUNITS_USERSPACEONUSE PATHUNITS_OBJECTBOUNDINGBOX LINECAP_UNDEFINED LINECAP_BUTT LINECAP_ROUND LINECAP_SQUARE LINEJOIN_UNDEFINED LINEJOIN_MITER LINEJOIN_ROUND LINEJOIN_BEVEL RESOURCETYPE_UNDEFINED RESOURCETYPE_AREA RESOURCETYPE_DISK RESOURCETYPE_FILE RESOURCETYPE_MAP RESOURCETYPE_MEMORY DISPOSE_UNDEFINED DISPOSE_NONE DISPOSE_BACKGROUND DISPOSE_PREVIOUS QUANTUM_DEPTH VERSION_TXT VERSION_LIB VERSION_NUM contained

" hash
syn keyword phpConstants HASH_HMAC MHASH_CRC32 MHASH_MD5 MHASH_SHA1 MHASH_HAVAL256 MHASH_RIPEMD160 MHASH_TIGER MHASH_GOST MHASH_CRC32B MHASH_HAVAL224 MHASH_HAVAL192 MHASH_HAVAL160 MHASH_HAVAL128 MHASH_TIGER128 MHASH_TIGER160 MHASH_MD4 MHASH_SHA256 MHASH_ADLER32 MHASH_SHA224 MHASH_SHA512 MHASH_SHA384 MHASH_WHIRLPOOL MHASH_RIPEMD128 MHASH_RIPEMD256 MHASH_RIPEMD320 MHASH_SNEFRU256 MHASH_MD2 MHASH_FNV132 MHASH_FNV1A32 MHASH_FNV164 MHASH_FNV1A64 MHASH_JOAAT contained

" http
syn keyword phpConstants http\Client\Curl\HTTP_VERSION_1_0 http\Client\Curl\HTTP_VERSION_1_1 http\Client\Curl\HTTP_VERSION_ANY http\Client\Curl\SSL_VERSION_TLSv1 http\Client\Curl\SSL_VERSION_SSLv2 http\Client\Curl\SSL_VERSION_SSLv3 http\Client\Curl\SSL_VERSION_ANY http\Client\Curl\IPRESOLVE_V4 http\Client\Curl\IPRESOLVE_V6 http\Client\Curl\IPRESOLVE_ANY http\Client\Curl\AUTH_BASIC http\Client\Curl\AUTH_DIGEST http\Client\Curl\AUTH_DIGEST_IE http\Client\Curl\AUTH_NTLM http\Client\Curl\AUTH_GSSNEG http\Client\Curl\AUTH_ANY http\Client\Curl\PROXY_SOCKS4 http\Client\Curl\PROXY_SOCKS4A http\Client\Curl\PROXY_SOCKS5_HOSTNAME http\Client\Curl\PROXY_SOCKS5 http\Client\Curl\PROXY_HTTP http\Client\Curl\PROXY_HTTP_1_0 http\Client\Curl\POSTREDIR_301 http\Client\Curl\POSTREDIR_302 http\Client\Curl\POSTREDIR_ALL PARSE_RAW SECURE HTTPONLY FLUSH_NONE FLUSH_SYNC FLUSH_FULL TYPE_GZIP TYPE_ZLIB TYPE_RAW LEVEL_DEF LEVEL_MIN LEVEL_MAX STRATEGY_DEF STRATEGY_FILT STRATEGY_HUFF STRATEGY_RLE STRATEGY_FIXED MATCH_LOOSE MATCH_CASE MATCH_WORD MATCH_FULL MATCH_STRICT TYPE_NONE TYPE_REQUEST TYPE_RESPONSE TYPE_BOOL TYPE_INT TYPE_FLOAT TYPE_STRING TYPE_ARRAY TYPE_OBJECT REPLACE JOIN_PATH JOIN_QUERY STRIP_USER STRIP_PASS STRIP_AUTH STRIP_PORT STRIP_PATH STRIP_QUERY STRIP_FRAGMENT STRIP_ALL FROM_ENV SANITIZE_PATH CONTENT_ENCODING_NONE CONTENT_ENCODING_GZIP CACHE_NO CACHE_HIT CACHE_MISS DEF_PARAM_SEP DEF_ARG_SEP DEF_VAL_SEP COOKIE_PARAM_SEP PARSE_DEFAULT PARSE_URLENCODED PARSE_DIMENSION PARSE_QUERY contained

" iconv
syn keyword phpConstants ICONV_IMPL ICONV_VERSION ICONV_MIME_DECODE_STRICT ICONV_MIME_DECODE_CONTINUE_ON_ERROR contained

" imagick
syn keyword phpConstants COLOR_BLACK COLOR_BLUE COLOR_CYAN COLOR_GREEN COLOR_RED COLOR_YELLOW COLOR_MAGENTA COLOR_OPACITY COLOR_ALPHA COLOR_FUZZ IMAGICK_EXTNUM IMAGICK_EXTVER COMPOSITE_DEFAULT COMPOSITE_UNDEFINED COMPOSITE_NO COMPOSITE_ADD COMPOSITE_ATOP COMPOSITE_BLEND COMPOSITE_BUMPMAP COMPOSITE_CLEAR COMPOSITE_COLORBURN COMPOSITE_COLORDODGE COMPOSITE_COLORIZE COMPOSITE_COPYBLACK COMPOSITE_COPYBLUE COMPOSITE_COPY COMPOSITE_COPYCYAN COMPOSITE_COPYGREEN COMPOSITE_COPYMAGENTA COMPOSITE_COPYOPACITY COMPOSITE_COPYRED COMPOSITE_COPYYELLOW COMPOSITE_DARKEN COMPOSITE_DSTATOP COMPOSITE_DST COMPOSITE_DSTIN COMPOSITE_DSTOUT COMPOSITE_DSTOVER COMPOSITE_DIFFERENCE COMPOSITE_DISPLACE COMPOSITE_DISSOLVE COMPOSITE_EXCLUSION COMPOSITE_HARDLIGHT COMPOSITE_HUE COMPOSITE_IN COMPOSITE_LIGHTEN COMPOSITE_LUMINIZE COMPOSITE_MINUS COMPOSITE_MODULATE COMPOSITE_MULTIPLY COMPOSITE_OUT COMPOSITE_OVER COMPOSITE_OVERLAY COMPOSITE_PLUS COMPOSITE_REPLACE COMPOSITE_SATURATE COMPOSITE_SCREEN COMPOSITE_SOFTLIGHT COMPOSITE_SRCATOP COMPOSITE_SRC COMPOSITE_SRCIN COMPOSITE_SRCOUT COMPOSITE_SRCOVER COMPOSITE_SUBTRACT COMPOSITE_THRESHOLD COMPOSITE_XOR MONTAGEMODE_FRAME MONTAGEMODE_UNFRAME MONTAGEMODE_CONCATENATE STYLE_NORMAL STYLE_ITALIC STYLE_OBLIQUE STYLE_ANY FILTER_UNDEFINED FILTER_POINT FILTER_BOX FILTER_TRIANGLE FILTER_HERMITE FILTER_HANNING FILTER_HAMMING FILTER_BLACKMAN FILTER_GAUSSIAN FILTER_QUADRATIC FILTER_CUBIC FILTER_CATROM FILTER_MITCHELL FILTER_LANCZOS FILTER_BESSEL FILTER_SINC IMGTYPE_UNDEFINED IMGTYPE_BILEVEL IMGTYPE_GRAYSCALE IMGTYPE_GRAYSCALEMATTE IMGTYPE_PALETTE IMGTYPE_PALETTEMATTE IMGTYPE_TRUECOLOR IMGTYPE_TRUECOLORMATTE IMGTYPE_COLORSEPARATION IMGTYPE_COLORSEPARATIONMATTE IMGTYPE_OPTIMIZE RESOLUTION_UNDEFINED RESOLUTION_PIXELSPERINCH RESOLUTION_PIXELSPERCENTIMETER COMPRESSION_UNDEFINED COMPRESSION_NO COMPRESSION_BZIP COMPRESSION_FAX COMPRESSION_GROUP4 COMPRESSION_JPEG COMPRESSION_JPEG2000 COMPRESSION_LOSSLESSJPEG COMPRESSION_LZW COMPRESSION_RLE COMPRESSION_ZIP COMPRESSION_DXT1 COMPRESSION_DXT3 COMPRESSION_DXT5 PAINT_POINT PAINT_REPLACE PAINT_FLOODFILL PAINT_FILLTOBORDER PAINT_RESET GRAVITY_NORTHWEST GRAVITY_NORTH GRAVITY_NORTHEAST GRAVITY_WEST GRAVITY_CENTER GRAVITY_EAST GRAVITY_SOUTHWEST GRAVITY_SOUTH GRAVITY_SOUTHEAST STRETCH_NORMAL STRETCH_ULTRACONDENSED STRETCH_CONDENSED STRETCH_SEMICONDENSED STRETCH_SEMIEXPANDED STRETCH_EXPANDED STRETCH_EXTRAEXPANDED STRETCH_ULTRAEXPANDED STRETCH_ANY ALIGN_UNDEFINED ALIGN_LEFT ALIGN_CENTER ALIGN_RIGHT DECORATION_NO DECORATION_UNDERLINE DECORATION_OVERLINE DECORATION_LINETROUGH NOISE_UNIFORM NOISE_GAUSSIAN NOISE_MULTIPLICATIVEGAUSSIAN NOISE_IMPULSE NOISE_LAPLACIAN NOISE_POISSON NOISE_RANDOM CHANNEL_UNDEFINED CHANNEL_RED CHANNEL_GRAY CHANNEL_CYAN CHANNEL_GREEN CHANNEL_MAGENTA CHANNEL_BLUE CHANNEL_YELLOW CHANNEL_ALPHA CHANNEL_OPACITY CHANNEL_MATTE CHANNEL_BLACK CHANNEL_INDEX CHANNEL_ALL CHANNEL_DEFAULT METRIC_UNDEFINED METRIC_MEANABSOLUTEERROR METRIC_MEANSQUAREERROR METRIC_PEAKABSOLUTEERROR METRIC_PEAKSIGNALTONOISERATIO METRIC_ROOTMEANSQUAREDERROR PIXEL_CHAR PIXEL_DOUBLE PIXEL_FLOAT PIXEL_INTEGER PIXEL_LONG PIXEL_QUANTUM PIXEL_SHORT EVALUATE_UNDEFINED EVALUATE_ADD EVALUATE_AND EVALUATE_DIVIDE EVALUATE_LEFTSHIFT EVALUATE_MAX EVALUATE_MIN EVALUATE_MULTIPLY EVALUATE_OR EVALUATE_RIGHTSHIFT EVALUATE_SET EVALUATE_SUBTRACT EVALUATE_XOR EVALUATE_POW EVALUATE_LOG EVALUATE_THRESHOLD EVALUATE_THRESHOLDBLACK EVALUATE_THRESHOLDWHITE EVALUATE_GAUSSIANNOISE EVALUATE_IMPULSENOISE EVALUATE_LAPLACIANNOISE EVALUATE_MULTIPLICATIVENOISE EVALUATE_POISSONNOISE EVALUATE_UNIFORMNOISE EVALUATE_COSINE EVALUATE_SINE EVALUATE_ADDMODULUS COLORSPACE_UNDEFINED COLORSPACE_RGB COLORSPACE_GRAY COLORSPACE_TRANSPARENT COLORSPACE_OHTA COLORSPACE_LAB COLORSPACE_XYZ COLORSPACE_YCBCR COLORSPACE_YCC COLORSPACE_YIQ COLORSPACE_YPBPR COLORSPACE_YUV COLORSPACE_CMYK COLORSPACE_SRGB COLORSPACE_HSB COLORSPACE_HSL COLORSPACE_HWB COLORSPACE_REC601LUMA COLORSPACE_REC709LUMA COLORSPACE_LOG COLORSPACE_CMY VIRTUALPIXELMETHOD_UNDEFINED VIRTUALPIXELMETHOD_BACKGROUND VIRTUALPIXELMETHOD_CONSTANT VIRTUALPIXELMETHOD_EDGE VIRTUALPIXELMETHOD_MIRROR VIRTUALPIXELMETHOD_TILE VIRTUALPIXELMETHOD_TRANSPARENT VIRTUALPIXELMETHOD_MASK VIRTUALPIXELMETHOD_BLACK VIRTUALPIXELMETHOD_GRAY VIRTUALPIXELMETHOD_WHITE VIRTUALPIXELMETHOD_HORIZONTALTILE VIRTUALPIXELMETHOD_VERTICALTILE PREVIEW_UNDEFINED PREVIEW_ROTATE PREVIEW_SHEAR PREVIEW_ROLL PREVIEW_HUE PREVIEW_SATURATION PREVIEW_BRIGHTNESS PREVIEW_GAMMA PREVIEW_SPIFF PREVIEW_DULL PREVIEW_GRAYSCALE PREVIEW_QUANTIZE PREVIEW_DESPECKLE PREVIEW_REDUCENOISE PREVIEW_ADDNOISE PREVIEW_SHARPEN PREVIEW_BLUR PREVIEW_THRESHOLD PREVIEW_EDGEDETECT PREVIEW_SPREAD PREVIEW_SOLARIZE PREVIEW_SHADE PREVIEW_RAISE PREVIEW_SEGMENT PREVIEW_SWIRL PREVIEW_IMPLODE PREVIEW_WAVE PREVIEW_OILPAINT PREVIEW_CHARCOALDRAWING PREVIEW_JPEG RENDERINGINTENT_UNDEFINED RENDERINGINTENT_SATURATION RENDERINGINTENT_PERCEPTUAL RENDERINGINTENT_ABSOLUTE RENDERINGINTENT_RELATIVE INTERLACE_UNDEFINED INTERLACE_NO INTERLACE_LINE INTERLACE_PLANE INTERLACE_PARTITION INTERLACE_GIF INTERLACE_JPEG INTERLACE_PNG FILLRULE_UNDEFINED FILLRULE_EVENODD FILLRULE_NONZERO PATHUNITS_UNDEFINED PATHUNITS_USERSPACE PATHUNITS_USERSPACEONUSE PATHUNITS_OBJECTBOUNDINGBOX LINECAP_UNDEFINED LINECAP_BUTT LINECAP_ROUND LINECAP_SQUARE LINEJOIN_UNDEFINED LINEJOIN_MITER LINEJOIN_ROUND LINEJOIN_BEVEL RESOURCETYPE_UNDEFINED RESOURCETYPE_AREA RESOURCETYPE_DISK RESOURCETYPE_FILE RESOURCETYPE_MAP RESOURCETYPE_MEMORY DISPOSE_UNRECOGNIZED DISPOSE_UNDEFINED DISPOSE_NONE DISPOSE_BACKGROUND DISPOSE_PREVIOUS INTERPOLATE_UNDEFINED INTERPOLATE_AVERAGE INTERPOLATE_BICUBIC INTERPOLATE_BILINEAR INTERPOLATE_FILTER INTERPOLATE_INTEGER INTERPOLATE_MESH INTERPOLATE_NEARESTNEIGHBOR INTERPOLATE_SPLINE LAYERMETHOD_UNDEFINED LAYERMETHOD_COALESCE LAYERMETHOD_COMPAREANY LAYERMETHOD_COMPARECLEAR LAYERMETHOD_COMPAREOVERLAY LAYERMETHOD_DISPOSE LAYERMETHOD_OPTIMIZE LAYERMETHOD_OPTIMIZEPLUS LAYERMETHOD_OPTIMIZETRANS LAYERMETHOD_COMPOSITE LAYERMETHOD_OPTIMIZEIMAGE LAYERMETHOD_REMOVEDUPS LAYERMETHOD_REMOVEZERO ORIENTATION_UNDEFINED ORIENTATION_TOPLEFT ORIENTATION_TOPRIGHT ORIENTATION_BOTTOMRIGHT ORIENTATION_BOTTOMLEFT ORIENTATION_LEFTTOP ORIENTATION_RIGHTTOP ORIENTATION_RIGHTBOTTOM ORIENTATION_LEFTBOTTOM DISTORTION_UNDEFINED DISTORTION_AFFINE DISTORTION_AFFINEPROJECTION DISTORTION_ARC DISTORTION_BILINEAR DISTORTION_PERSPECTIVE DISTORTION_PERSPECTIVEPROJECTION DISTORTION_SCALEROTATETRANSLATE DISTORTION_POLYNOMIAL DISTORTION_POLAR DISTORTION_DEPOLAR DISTORTION_BARREL DISTORTION_BARRELINVERSE DISTORTION_SHEPARDS DISTORTION_SENTINEL LAYERMETHOD_MERGE LAYERMETHOD_FLATTEN LAYERMETHOD_MOSAIC ALPHACHANNEL_ACTIVATE ALPHACHANNEL_DEACTIVATE ALPHACHANNEL_RESET ALPHACHANNEL_SET ALPHACHANNEL_UNDEFINED ALPHACHANNEL_COPY ALPHACHANNEL_EXTRACT ALPHACHANNEL_OPAQUE ALPHACHANNEL_SHAPE ALPHACHANNEL_TRANSPARENT SPARSECOLORMETHOD_UNDEFINED SPARSECOLORMETHOD_BARYCENTRIC SPARSECOLORMETHOD_BILINEAR SPARSECOLORMETHOD_POLYNOMIAL SPARSECOLORMETHOD_SPEPARDS SPARSECOLORMETHOD_VORONOI DITHERMETHOD_UNDEFINED DITHERMETHOD_NO DITHERMETHOD_RIEMERSMA DITHERMETHOD_FLOYDSTEINBERG FUNCTION_UNDEFINED FUNCTION_POLYNOMIAL FUNCTION_SINUSOID contained

" intl
syn keyword phpConstants INTL_MAX_LOCALE_LEN INTL_ICU_VERSION INTL_ICU_DATA_VERSION ULOC_ACTUAL_LOCALE ULOC_VALID_LOCALE GRAPHEME_EXTR_COUNT GRAPHEME_EXTR_MAXBYTES GRAPHEME_EXTR_MAXCHARS U_USING_FALLBACK_WARNING U_ERROR_WARNING_START U_USING_DEFAULT_WARNING U_SAFECLONE_ALLOCATED_WARNING U_STATE_OLD_WARNING U_STRING_NOT_TERMINATED_WARNING U_SORT_KEY_TOO_SHORT_WARNING U_AMBIGUOUS_ALIAS_WARNING U_DIFFERENT_UCA_VERSION U_ERROR_WARNING_LIMIT U_ZERO_ERROR U_ILLEGAL_ARGUMENT_ERROR U_MISSING_RESOURCE_ERROR U_INVALID_FORMAT_ERROR U_FILE_ACCESS_ERROR U_INTERNAL_PROGRAM_ERROR U_MESSAGE_PARSE_ERROR U_MEMORY_ALLOCATION_ERROR U_INDEX_OUTOFBOUNDS_ERROR U_PARSE_ERROR U_INVALID_CHAR_FOUND U_TRUNCATED_CHAR_FOUND U_ILLEGAL_CHAR_FOUND U_INVALID_TABLE_FORMAT U_INVALID_TABLE_FILE U_BUFFER_OVERFLOW_ERROR U_UNSUPPORTED_ERROR U_RESOURCE_TYPE_MISMATCH U_ILLEGAL_ESCAPE_SEQUENCE U_UNSUPPORTED_ESCAPE_SEQUENCE U_NO_SPACE_AVAILABLE U_CE_NOT_FOUND_ERROR U_PRIMARY_TOO_LONG_ERROR U_STATE_TOO_OLD_ERROR U_TOO_MANY_ALIASES_ERROR U_ENUM_OUT_OF_SYNC_ERROR U_INVARIANT_CONVERSION_ERROR U_INVALID_STATE_ERROR U_COLLATOR_VERSION_MISMATCH U_USELESS_COLLATOR_ERROR U_NO_WRITE_PERMISSION U_STANDARD_ERROR_LIMIT U_BAD_VARIABLE_DEFINITION U_PARSE_ERROR_START U_MALFORMED_RULE U_MALFORMED_SET U_MALFORMED_SYMBOL_REFERENCE U_MALFORMED_UNICODE_ESCAPE U_MALFORMED_VARIABLE_DEFINITION U_MALFORMED_VARIABLE_REFERENCE U_MISMATCHED_SEGMENT_DELIMITERS U_MISPLACED_ANCHOR_START U_MISPLACED_CURSOR_OFFSET U_MISPLACED_QUANTIFIER U_MISSING_OPERATOR U_MISSING_SEGMENT_CLOSE U_MULTIPLE_ANTE_CONTEXTS U_MULTIPLE_CURSORS U_MULTIPLE_POST_CONTEXTS U_TRAILING_BACKSLASH U_UNDEFINED_SEGMENT_REFERENCE U_UNDEFINED_VARIABLE U_UNQUOTED_SPECIAL U_UNTERMINATED_QUOTE U_RULE_MASK_ERROR U_MISPLACED_COMPOUND_FILTER U_MULTIPLE_COMPOUND_FILTERS U_INVALID_RBT_SYNTAX U_INVALID_PROPERTY_PATTERN U_MALFORMED_PRAGMA U_UNCLOSED_SEGMENT U_ILLEGAL_CHAR_IN_SEGMENT U_VARIABLE_RANGE_EXHAUSTED U_VARIABLE_RANGE_OVERLAP U_ILLEGAL_CHARACTER U_INTERNAL_TRANSLITERATOR_ERROR U_INVALID_ID U_INVALID_FUNCTION U_PARSE_ERROR_LIMIT U_UNEXPECTED_TOKEN U_FMT_PARSE_ERROR_START U_MULTIPLE_DECIMAL_SEPARATORS U_MULTIPLE_DECIMAL_SEPERATORS U_MULTIPLE_EXPONENTIAL_SYMBOLS U_MALFORMED_EXPONENTIAL_PATTERN U_MULTIPLE_PERCENT_SYMBOLS U_MULTIPLE_PERMILL_SYMBOLS U_MULTIPLE_PAD_SPECIFIERS U_PATTERN_SYNTAX_ERROR U_ILLEGAL_PAD_POSITION U_UNMATCHED_BRACES U_UNSUPPORTED_PROPERTY U_UNSUPPORTED_ATTRIBUTE U_FMT_PARSE_ERROR_LIMIT U_BRK_INTERNAL_ERROR U_BRK_ERROR_START U_BRK_HEX_DIGITS_EXPECTED U_BRK_SEMICOLON_EXPECTED U_BRK_RULE_SYNTAX U_BRK_UNCLOSED_SET U_BRK_ASSIGN_ERROR U_BRK_VARIABLE_REDFINITION U_BRK_MISMATCHED_PAREN U_BRK_NEW_LINE_IN_QUOTED_STRING U_BRK_UNDEFINED_VARIABLE U_BRK_INIT_ERROR U_BRK_RULE_EMPTY_SET U_BRK_UNRECOGNIZED_OPTION U_BRK_MALFORMED_RULE_TAG U_BRK_ERROR_LIMIT U_REGEX_INTERNAL_ERROR U_REGEX_ERROR_START U_REGEX_RULE_SYNTAX U_REGEX_INVALID_STATE U_REGEX_BAD_ESCAPE_SEQUENCE U_REGEX_PROPERTY_SYNTAX U_REGEX_UNIMPLEMENTED U_REGEX_MISMATCHED_PAREN U_REGEX_NUMBER_TOO_BIG U_REGEX_BAD_INTERVAL U_REGEX_MAX_LT_MIN U_REGEX_INVALID_BACK_REF U_REGEX_INVALID_FLAG U_REGEX_LOOK_BEHIND_LIMIT U_REGEX_SET_CONTAINS_STRING U_REGEX_ERROR_LIMIT U_IDNA_PROHIBITED_ERROR U_IDNA_ERROR_START U_IDNA_UNASSIGNED_ERROR U_IDNA_CHECK_BIDI_ERROR U_IDNA_STD3_ASCII_RULES_ERROR U_IDNA_ACE_PREFIX_ERROR U_IDNA_VERIFICATION_ERROR U_IDNA_LABEL_TOO_LONG_ERROR U_IDNA_ZERO_LENGTH_LABEL_ERROR U_IDNA_DOMAIN_NAME_TOO_LONG_ERROR U_IDNA_ERROR_LIMIT U_STRINGPREP_PROHIBITED_ERROR U_STRINGPREP_UNASSIGNED_ERROR U_STRINGPREP_CHECK_BIDI_ERROR U_ERROR_LIMIT IDNA_DEFAULT IDNA_ALLOW_UNASSIGNED IDNA_USE_STD3_RULES IDNA_CHECK_BIDI IDNA_CHECK_CONTEXTJ IDNA_NONTRANSITIONAL_TO_ASCII IDNA_NONTRANSITIONAL_TO_UNICODE INTL_IDNA_VARIANT_2003 INTL_IDNA_VARIANT_UTS46 IDNA_ERROR_EMPTY_LABEL IDNA_ERROR_LABEL_TOO_LONG IDNA_ERROR_DOMAIN_NAME_TOO_LONG IDNA_ERROR_LEADING_HYPHEN IDNA_ERROR_TRAILING_HYPHEN IDNA_ERROR_HYPHEN_3_4 IDNA_ERROR_LEADING_COMBINING_MARK IDNA_ERROR_DISALLOWED IDNA_ERROR_PUNYCODE IDNA_ERROR_LABEL_HAS_DOT IDNA_ERROR_INVALID_ACE_LABEL IDNA_ERROR_BIDI IDNA_ERROR_CONTEXTJ DEFAULT_VALUE PRIMARY SECONDARY TERTIARY DEFAULT_STRENGTH QUATERNARY IDENTICAL OFF ON SHIFTED NON_IGNORABLE LOWER_FIRST UPPER_FIRST FRENCH_COLLATION ALTERNATE_HANDLING CASE_FIRST CASE_LEVEL NORMALIZATION_MODE STRENGTH HIRAGANA_QUATERNARY_MODE NUMERIC_COLLATION SORT_REGULAR SORT_STRING SORT_NUMERIC PATTERN_DECIMAL DECIMAL CURRENCY PERCENT SCIENTIFIC SPELLOUT ORDINAL DURATION PATTERN_RULEBASED IGNORE DEFAULT_STYLE ROUND_CEILING ROUND_FLOOR ROUND_DOWN ROUND_UP ROUND_HALFEVEN ROUND_HALFDOWN ROUND_HALFUP PAD_BEFORE_PREFIX PAD_AFTER_PREFIX PAD_BEFORE_SUFFIX PAD_AFTER_SUFFIX PARSE_INT_ONLY GROUPING_USED DECIMAL_ALWAYS_SHOWN MAX_INTEGER_DIGITS MIN_INTEGER_DIGITS INTEGER_DIGITS MAX_FRACTION_DIGITS MIN_FRACTION_DIGITS FRACTION_DIGITS MULTIPLIER GROUPING_SIZE ROUNDING_MODE ROUNDING_INCREMENT FORMAT_WIDTH PADDING_POSITION SECONDARY_GROUPING_SIZE SIGNIFICANT_DIGITS_USED MIN_SIGNIFICANT_DIGITS MAX_SIGNIFICANT_DIGITS LENIENT_PARSE POSITIVE_PREFIX POSITIVE_SUFFIX NEGATIVE_PREFIX NEGATIVE_SUFFIX PADDING_CHARACTER CURRENCY_CODE DEFAULT_RULESET PUBLIC_RULESETS DECIMAL_SEPARATOR_SYMBOL GROUPING_SEPARATOR_SYMBOL PATTERN_SEPARATOR_SYMBOL PERCENT_SYMBOL ZERO_DIGIT_SYMBOL DIGIT_SYMBOL MINUS_SIGN_SYMBOL PLUS_SIGN_SYMBOL CURRENCY_SYMBOL INTL_CURRENCY_SYMBOL MONETARY_SEPARATOR_SYMBOL EXPONENTIAL_SYMBOL PERMILL_SYMBOL PAD_ESCAPE_SYMBOL INFINITY_SYMBOL NAN_SYMBOL SIGNIFICANT_DIGIT_SYMBOL MONETARY_GROUPING_SEPARATOR_SYMBOL TYPE_DEFAULT TYPE_INT32 TYPE_INT64 TYPE_DOUBLE TYPE_CURRENCY NONE FORM_D NFD FORM_KD NFKD FORM_C NFC FORM_KC NFKC ACTUAL_LOCALE VALID_LOCALE DEFAULT_LOCALE LANG_TAG EXTLANG_TAG SCRIPT_TAG REGION_TAG VARIANT_TAG GRANDFATHERED_LANG_TAG PRIVATE_TAG FULL LONG MEDIUM SHORT GREGORIAN TRADITIONAL FORWARD REVERSE DISPLAY_SHORT DISPLAY_LONG DISPLAY_SHORT_GENERIC DISPLAY_LONG_GENERIC DISPLAY_SHORT_GMT DISPLAY_LONG_GMT DISPLAY_SHORT_COMMONLY_USED DISPLAY_GENERIC_LOCATION TYPE_ANY TYPE_CANONICAL TYPE_CANONICAL_LOCATION FIELD_ERA FIELD_YEAR FIELD_MONTH FIELD_WEEK_OF_YEAR FIELD_WEEK_OF_MONTH FIELD_DATE FIELD_DAY_OF_YEAR FIELD_DAY_OF_WEEK FIELD_DAY_OF_WEEK_IN_MONTH FIELD_AM_PM FIELD_HOUR FIELD_HOUR_OF_DAY FIELD_MINUTE FIELD_SECOND FIELD_MILLISECOND FIELD_ZONE_OFFSET FIELD_DST_OFFSET FIELD_YEAR_WOY FIELD_DOW_LOCAL FIELD_EXTENDED_YEAR FIELD_JULIAN_DAY FIELD_MILLISECONDS_IN_DAY FIELD_IS_LEAP_MONTH FIELD_FIELD_COUNT FIELD_DAY_OF_MONTH DOW_SUNDAY DOW_MONDAY DOW_TUESDAY DOW_WEDNESDAY DOW_THURSDAY DOW_FRIDAY DOW_SATURDAY DOW_TYPE_WEEKDAY DOW_TYPE_WEEKEND DOW_TYPE_WEEKEND_OFFSET DOW_TYPE_WEEKEND_CEASE WALLTIME_FIRST WALLTIME_LAST WALLTIME_NEXT_VALID SINGLE_SCRIPT_CONFUSABLE MIXED_SCRIPT_CONFUSABLE WHOLE_SCRIPT_CONFUSABLE ANY_CASE SINGLE_SCRIPT INVISIBLE CHAR_LIMIT DONE WORD_NONE WORD_NONE_LIMIT WORD_NUMBER WORD_NUMBER_LIMIT WORD_LETTER WORD_LETTER_LIMIT WORD_KANA WORD_KANA_LIMIT WORD_IDEO WORD_IDEO_LIMIT LINE_SOFT LINE_SOFT_LIMIT LINE_HARD LINE_HARD_LIMIT SENTENCE_TERM SENTENCE_TERM_LIMIT SENTENCE_SEP SENTENCE_SEP_LIMIT KEY_SEQUENTIAL KEY_LEFT KEY_RIGHT REASON_UNASSIGNED REASON_ILLEGAL REASON_IRREGULAR REASON_RESET REASON_CLOSE REASON_CLONE UNSUPPORTED_CONVERTER SBCS DBCS MBCS LATIN_1 UTF8 UTF16_BigEndian UTF16_LittleEndian UTF32_BigEndian UTF32_LittleEndian EBCDIC_STATEFUL ISO_2022 LMBCS_1 LMBCS_2 LMBCS_3 LMBCS_4 LMBCS_5 LMBCS_6 LMBCS_8 LMBCS_11 LMBCS_16 LMBCS_17 LMBCS_18 LMBCS_19 LMBCS_LAST HZ SCSU ISCII US_ASCII UTF7 BOCU1 UTF16 UTF32 CESU8 IMAP_MAILBOX contained

" jsmin
syn keyword phpConstants JSMIN_ERROR_NONE JSMIN_ERROR_UNTERMINATED_COMMENT JSMIN_ERROR_UNTERMINATED_STRING JSMIN_ERROR_UNTERMINATED_REGEX contained

" json
syn keyword phpConstants JSON_HEX_TAG JSON_HEX_AMP JSON_HEX_APOS JSON_HEX_QUOT JSON_FORCE_OBJECT JSON_NUMERIC_CHECK JSON_UNESCAPED_SLASHES JSON_PRETTY_PRINT JSON_UNESCAPED_UNICODE JSON_PARTIAL_OUTPUT_ON_ERROR JSON_ERROR_NONE JSON_ERROR_DEPTH JSON_ERROR_STATE_MISMATCH JSON_ERROR_CTRL_CHAR JSON_ERROR_SYNTAX JSON_ERROR_UTF8 JSON_ERROR_RECURSION JSON_ERROR_INF_OR_NAN JSON_ERROR_UNSUPPORTED_TYPE JSON_OBJECT_AS_ARRAY JSON_BIGINT_AS_STRING contained

" judy
syn keyword phpConstants BITSET INT_TO_INT INT_TO_MIXED STRING_TO_INT STRING_TO_MIXED contained

" ldap
syn keyword phpConstants LDAP_DEREF_NEVER LDAP_DEREF_SEARCHING LDAP_DEREF_FINDING LDAP_DEREF_ALWAYS LDAP_MODIFY_BATCH_ADD LDAP_MODIFY_BATCH_REMOVE LDAP_MODIFY_BATCH_REMOVE_ALL LDAP_MODIFY_BATCH_REPLACE LDAP_MODIFY_BATCH_ATTRIB LDAP_MODIFY_BATCH_MODTYPE LDAP_MODIFY_BATCH_VALUES LDAP_OPT_DEREF LDAP_OPT_SIZELIMIT LDAP_OPT_TIMELIMIT LDAP_OPT_NETWORK_TIMEOUT LDAP_OPT_PROTOCOL_VERSION LDAP_OPT_ERROR_NUMBER LDAP_OPT_REFERRALS LDAP_OPT_RESTART LDAP_OPT_HOST_NAME LDAP_OPT_ERROR_STRING LDAP_OPT_MATCHED_DN LDAP_OPT_SERVER_CONTROLS LDAP_OPT_CLIENT_CONTROLS LDAP_OPT_DEBUG_LEVEL LDAP_OPT_X_SASL_MECH LDAP_OPT_X_SASL_REALM LDAP_OPT_X_SASL_AUTHCID LDAP_OPT_X_SASL_AUTHZID contained

" leveldb
syn keyword phpConstants LEVELDB_NO_COMPRESSION LEVELDB_SNAPPY_COMPRESSION contained

" libevent
syn keyword phpConstants EV_TIMEOUT EV_READ EV_WRITE EV_SIGNAL EV_PERSIST EVLOOP_NONBLOCK EVLOOP_ONCE EVBUFFER_READ EVBUFFER_WRITE EVBUFFER_EOF EVBUFFER_ERROR EVBUFFER_TIMEOUT contained

" libvirt
syn keyword phpConstants VIR_DOMAIN_XML_SECURE VIR_DOMAIN_XML_INACTIVE VIR_NODE_CPU_STATS_ALL_CPUS VIR_DOMAIN_NOSTATE VIR_DOMAIN_RUNNING VIR_DOMAIN_BLOCKED VIR_DOMAIN_PAUSED VIR_DOMAIN_SHUTDOWN VIR_DOMAIN_SHUTOFF VIR_DOMAIN_CRASHED VIR_SNAPSHOT_DELETE_CHILDREN VIR_MEMORY_VIRTUAL VIR_VERSION_BINDING VIR_VERSION_LIBVIRT VIR_NETWORKS_ACTIVE VIR_NETWORKS_INACTIVE VIR_NETWORKS_ALL VIR_CRED_USERNAME VIR_CRED_AUTHNAME VIR_CRED_LANGUAGE VIR_CRED_CNONCE VIR_CRED_PASSPHRASE VIR_CRED_ECHOPROMPT VIR_CRED_NOECHOPROMP VIR_CRED_REALM VIR_CRED_EXTERNAL VIR_DOMAIN_MEMORY_STAT_SWAP_IN VIR_DOMAIN_MEMORY_STAT_SWAP_OUT VIR_DOMAIN_MEMORY_STAT_MAJOR_FAULT VIR_DOMAIN_MEMORY_STAT_MINOR_FAULT VIR_DOMAIN_MEMORY_STAT_UNUSED VIR_DOMAIN_MEMORY_STAT_AVAILABLE VIR_DOMAIN_MEMORY_STAT_NR VIR_DOMAIN_JOB_NONE VIR_DOMAIN_JOB_BOUNDED VIR_DOMAIN_JOB_UNBOUNDED VIR_DOMAIN_JOB_COMPLETED VIR_DOMAIN_JOB_FAILED VIR_DOMAIN_JOB_CANCELLED VIR_MIGRATE_LIVE VIR_MIGRATE_PEER2PEER VIR_MIGRATE_TUNNELLED VIR_MIGRATE_PERSIST_DEST VIR_MIGRATE_UNDEFINE_SOURCE VIR_MIGRATE_PAUSED VIR_MIGRATE_NON_SHARED_DISK VIR_MIGRATE_NON_SHARED_INC VIR_DOMAIN_DEVICE_MODIFY_CURRENT VIR_DOMAIN_DEVICE_MODIFY_LIVE VIR_DOMAIN_DEVICE_MODIFY_CONFIG VIR_DOMAIN_DEVICE_MODIFY_FORCE VIR_STORAGE_POOL_BUILD_NEW VIR_STORAGE_POOL_BUILD_REPAIR VIR_STORAGE_POOL_BUILD_RESIZE VIR_DOMAIN_FLAG_FEATURE_ACPI VIR_DOMAIN_FLAG_FEATURE_APIC VIR_DOMAIN_FLAG_FEATURE_PAE VIR_DOMAIN_FLAG_CLOCK_LOCALTIME VIR_DOMAIN_FLAG_TEST_LOCAL_VNC VIR_DOMAIN_FLAG_SOUND_AC97 VIR_DOMAIN_DISK_FILE VIR_DOMAIN_DISK_BLOCK VIR_DOMAIN_DISK_ACCESS_ALL contained

" libxml
syn keyword phpConstants LIBXML_VERSION LIBXML_DOTTED_VERSION LIBXML_LOADED_VERSION LIBXML_NOENT LIBXML_DTDLOAD LIBXML_DTDATTR LIBXML_DTDVALID LIBXML_NOERROR LIBXML_NOWARNING LIBXML_NOBLANKS LIBXML_XINCLUDE LIBXML_NSCLEAN LIBXML_NOCDATA LIBXML_NONET LIBXML_PEDANTIC LIBXML_COMPACT LIBXML_NOXMLDECL LIBXML_PARSEHUGE LIBXML_NOEMPTYTAG LIBXML_SCHEMA_CREATE LIBXML_HTML_NOIMPLIED LIBXML_HTML_NODEFDTD LIBXML_ERR_NONE LIBXML_ERR_WARNING LIBXML_ERR_ERROR LIBXML_ERR_FATAL contained

" mailparse
syn keyword phpConstants MAILPARSE_EXTRACT_OUTPUT MAILPARSE_EXTRACT_STREAM MAILPARSE_EXTRACT_RETURN contained

" mbstring
syn keyword phpConstants MB_OVERLOAD_MAIL MB_OVERLOAD_STRING MB_OVERLOAD_REGEX MB_CASE_UPPER MB_CASE_LOWER MB_CASE_TITLE contained

" mcrypt
syn keyword phpConstants MCRYPT_ENCRYPT MCRYPT_DECRYPT MCRYPT_DEV_RANDOM MCRYPT_DEV_URANDOM MCRYPT_RAND MCRYPT_3DES MCRYPT_ARCFOUR_IV MCRYPT_ARCFOUR MCRYPT_BLOWFISH MCRYPT_BLOWFISH_COMPAT MCRYPT_CAST_128 MCRYPT_CAST_256 MCRYPT_CRYPT MCRYPT_DES MCRYPT_ENIGNA MCRYPT_GOST MCRYPT_LOKI97 MCRYPT_PANAMA MCRYPT_RC2 MCRYPT_RIJNDAEL_128 MCRYPT_RIJNDAEL_192 MCRYPT_RIJNDAEL_256 MCRYPT_SAFER64 MCRYPT_SAFER128 MCRYPT_SAFERPLUS MCRYPT_SERPENT MCRYPT_THREEWAY MCRYPT_TRIPLEDES MCRYPT_TWOFISH MCRYPT_WAKE MCRYPT_XTEA MCRYPT_IDEA MCRYPT_MARS MCRYPT_RC6 MCRYPT_SKIPJACK MCRYPT_MODE_CBC MCRYPT_MODE_CFB MCRYPT_MODE_ECB MCRYPT_MODE_NOFB MCRYPT_MODE_OFB MCRYPT_MODE_STREAM contained

" memcache
syn keyword phpConstants MEMCACHE_COMPRESSED MEMCACHE_HAVE_SESSION contained

" memcached
syn keyword phpConstants OPT_COMPRESSION OPT_COMPRESSION_TYPE OPT_PREFIX_KEY OPT_SERIALIZER HAVE_IGBINARY HAVE_JSON HAVE_SESSION HAVE_SASL OPT_HASH HASH_DEFAULT HASH_MD5 HASH_CRC HASH_FNV1_64 HASH_FNV1A_64 HASH_FNV1_32 HASH_FNV1A_32 HASH_HSIEH HASH_MURMUR OPT_DISTRIBUTION DISTRIBUTION_MODULA DISTRIBUTION_CONSISTENT DISTRIBUTION_VIRTUAL_BUCKET OPT_LIBKETAMA_COMPATIBLE OPT_LIBKETAMA_HASH OPT_TCP_KEEPALIVE OPT_BUFFER_WRITES OPT_BINARY_PROTOCOL OPT_NO_BLOCK OPT_TCP_NODELAY OPT_SOCKET_SEND_SIZE OPT_SOCKET_RECV_SIZE OPT_CONNECT_TIMEOUT OPT_RETRY_TIMEOUT OPT_DEAD_TIMEOUT OPT_SEND_TIMEOUT OPT_RECV_TIMEOUT OPT_POLL_TIMEOUT OPT_CACHE_LOOKUPS OPT_SERVER_FAILURE_LIMIT OPT_AUTO_EJECT_HOSTS OPT_HASH_WITH_PREFIX_KEY OPT_NOREPLY OPT_SORT_HOSTS OPT_VERIFY_KEY OPT_USE_UDP OPT_NUMBER_OF_REPLICAS OPT_RANDOMIZE_REPLICA_READ OPT_REMOVE_FAILED_SERVERS RES_SUCCESS RES_FAILURE RES_HOST_LOOKUP_FAILURE RES_UNKNOWN_READ_FAILURE RES_PROTOCOL_ERROR RES_CLIENT_ERROR RES_SERVER_ERROR RES_WRITE_FAILURE RES_DATA_EXISTS RES_NOTSTORED RES_NOTFOUND RES_PARTIAL_READ RES_SOME_ERRORS RES_NO_SERVERS RES_END RES_ERRNO RES_BUFFERED RES_TIMEOUT RES_BAD_KEY_PROVIDED RES_STORED RES_DELETED RES_STAT RES_ITEM RES_NOT_SUPPORTED RES_FETCH_NOTFINISHED RES_SERVER_MARKED_DEAD RES_UNKNOWN_STAT_KEY RES_INVALID_HOST_PROTOCOL RES_MEMORY_ALLOCATION_FAILURE RES_CONNECTION_SOCKET_CREATE_FAILURE RES_PAYLOAD_FAILURE SERIALIZER_PHP SERIALIZER_IGBINARY SERIALIZER_JSON SERIALIZER_JSON_ARRAY COMPRESSION_FASTLZ COMPRESSION_ZLIB GET_PRESERVE_ORDER GET_ERROR_RETURN_VALUE contained

" mongo
syn keyword phpConstants MONGO_STREAMS DEFAULT_HOST DEFAULT_PORT VERSION RP_PRIMARY RP_PRIMARY_PREFERRED RP_SECONDARY RP_SECONDARY_PREFERRED RP_NEAREST PROFILING_OFF PROFILING_SLOW PROFILING_ON ASCENDING DESCENDING FUNC BYTE_ARRAY UUID MD5 CUSTOM NONE WARNING INFO FINE RS POOL PARSE CON IO SERVER ALL contained

" mosquitto
syn keyword phpConstants MOSQ_LOG_INFO MOSQ_LOG_NOTICE MOSQ_LOG_WARNING MOSQ_LOG_ERR MOSQ_LOG_DEBUG 0 1 LOG_INFO LOG_NOTICE LOG_WARNING LOG_ERR LOG_DEBUG SSL_VERIFY_NONE SSL_VERIFY_PEER contained

" msgpack
syn keyword phpConstants OPT_PHPONLY contained

" mysql
syn keyword phpConstants MYSQL_ASSOC MYSQL_NUM MYSQL_BOTH MYSQL_CLIENT_COMPRESS MYSQL_CLIENT_SSL MYSQL_CLIENT_INTERACTIVE MYSQL_CLIENT_IGNORE_SPACE contained

" mysqli
syn keyword phpConstants MYSQLI_READ_DEFAULT_GROUP MYSQLI_READ_DEFAULT_FILE MYSQLI_OPT_CONNECT_TIMEOUT MYSQLI_OPT_LOCAL_INFILE MYSQLI_INIT_COMMAND MYSQLI_OPT_NET_CMD_BUFFER_SIZE MYSQLI_OPT_NET_READ_BUFFER_SIZE MYSQLI_OPT_INT_AND_FLOAT_NATIVE MYSQLI_OPT_SSL_VERIFY_SERVER_CERT MYSQLI_SERVER_PUBLIC_KEY MYSQLI_CLIENT_SSL MYSQLI_CLIENT_COMPRESS MYSQLI_CLIENT_INTERACTIVE MYSQLI_CLIENT_IGNORE_SPACE MYSQLI_CLIENT_NO_SCHEMA MYSQLI_CLIENT_FOUND_ROWS MYSQLI_STORE_RESULT MYSQLI_USE_RESULT MYSQLI_ASYNC MYSQLI_ASSOC MYSQLI_NUM MYSQLI_BOTH MYSQLI_STMT_ATTR_UPDATE_MAX_LENGTH MYSQLI_STMT_ATTR_CURSOR_TYPE MYSQLI_CURSOR_TYPE_NO_CURSOR MYSQLI_CURSOR_TYPE_READ_ONLY MYSQLI_CURSOR_TYPE_FOR_UPDATE MYSQLI_CURSOR_TYPE_SCROLLABLE MYSQLI_STMT_ATTR_PREFETCH_ROWS MYSQLI_NOT_NULL_FLAG MYSQLI_PRI_KEY_FLAG MYSQLI_UNIQUE_KEY_FLAG MYSQLI_MULTIPLE_KEY_FLAG MYSQLI_BLOB_FLAG MYSQLI_UNSIGNED_FLAG MYSQLI_ZEROFILL_FLAG MYSQLI_AUTO_INCREMENT_FLAG MYSQLI_TIMESTAMP_FLAG MYSQLI_SET_FLAG MYSQLI_NUM_FLAG MYSQLI_PART_KEY_FLAG MYSQLI_GROUP_FLAG MYSQLI_ENUM_FLAG MYSQLI_BINARY_FLAG MYSQLI_NO_DEFAULT_VALUE_FLAG MYSQLI_ON_UPDATE_NOW_FLAG MYSQLI_TYPE_DECIMAL MYSQLI_TYPE_TINY MYSQLI_TYPE_SHORT MYSQLI_TYPE_LONG MYSQLI_TYPE_FLOAT MYSQLI_TYPE_DOUBLE MYSQLI_TYPE_NULL MYSQLI_TYPE_TIMESTAMP MYSQLI_TYPE_LONGLONG MYSQLI_TYPE_INT24 MYSQLI_TYPE_DATE MYSQLI_TYPE_TIME MYSQLI_TYPE_DATETIME MYSQLI_TYPE_YEAR MYSQLI_TYPE_NEWDATE MYSQLI_TYPE_ENUM MYSQLI_TYPE_SET MYSQLI_TYPE_TINY_BLOB MYSQLI_TYPE_MEDIUM_BLOB MYSQLI_TYPE_LONG_BLOB MYSQLI_TYPE_BLOB MYSQLI_TYPE_VAR_STRING MYSQLI_TYPE_STRING MYSQLI_TYPE_CHAR MYSQLI_TYPE_INTERVAL MYSQLI_TYPE_GEOMETRY MYSQLI_TYPE_NEWDECIMAL MYSQLI_TYPE_BIT MYSQLI_SET_CHARSET_NAME MYSQLI_SET_CHARSET_DIR MYSQLI_NO_DATA MYSQLI_DATA_TRUNCATED MYSQLI_REPORT_INDEX MYSQLI_REPORT_ERROR MYSQLI_REPORT_STRICT MYSQLI_REPORT_ALL MYSQLI_REPORT_OFF MYSQLI_DEBUG_TRACE_ENABLED MYSQLI_SERVER_QUERY_NO_GOOD_INDEX_USED MYSQLI_SERVER_QUERY_NO_INDEX_USED MYSQLI_SERVER_QUERY_WAS_SLOW MYSQLI_SERVER_PS_OUT_PARAMS MYSQLI_REFRESH_GRANT MYSQLI_REFRESH_LOG MYSQLI_REFRESH_TABLES MYSQLI_REFRESH_HOSTS MYSQLI_REFRESH_STATUS MYSQLI_REFRESH_THREADS MYSQLI_REFRESH_SLAVE MYSQLI_REFRESH_MASTER MYSQLI_REFRESH_BACKUP_LOG MYSQLI_OPT_CAN_HANDLE_EXPIRED_PASSWORDS MYSQLI_TRANS_START_WITH_CONSISTENT_SNAPSHOT MYSQLI_TRANS_START_READ_WRITE MYSQLI_TRANS_START_READ_ONLY MYSQLI_TRANS_COR_AND_CHAIN MYSQLI_TRANS_COR_AND_NO_CHAIN MYSQLI_TRANS_COR_RELEASE MYSQLI_TRANS_COR_NO_RELEASE contained

" mysqlnd_ms
syn keyword phpConstants MYSQLND_MS_VERSION MYSQLND_MS_VERSION_ID MYSQLND_MS_MASTER_SWITCH MYSQLND_MS_SLAVE_SWITCH MYSQLND_MS_LAST_USED_SWITCH MYSQLND_MS_QUERY_USE_MASTER MYSQLND_MS_QUERY_USE_SLAVE MYSQLND_MS_QUERY_USE_LAST_USED MYSQLND_MS_QOS_CONSISTENCY_STRONG MYSQLND_MS_QOS_CONSISTENCY_SESSION MYSQLND_MS_QOS_CONSISTENCY_EVENTUAL MYSQLND_MS_QOS_OPTION_GTID MYSQLND_MS_QOS_OPTION_AGE MYSQLND_MS_QOS_OPTION_CACHE contained

" OAuth
syn keyword phpConstants OAUTH_SIG_METHOD_HMACSHA1 OAUTH_SIG_METHOD_HMACSHA256 OAUTH_SIG_METHOD_RSASHA1 OAUTH_SIG_METHOD_PLAINTEXT OAUTH_AUTH_TYPE_AUTHORIZATION OAUTH_AUTH_TYPE_URI OAUTH_AUTH_TYPE_FORM OAUTH_AUTH_TYPE_NONE OAUTH_HTTP_METHOD_GET OAUTH_HTTP_METHOD_POST OAUTH_HTTP_METHOD_PUT OAUTH_HTTP_METHOD_HEAD OAUTH_HTTP_METHOD_DELETE OAUTH_REQENGINE_STREAMS OAUTH_REQENGINE_CURL OAUTH_SSLCHECK_NONE OAUTH_SSLCHECK_HOST OAUTH_SSLCHECK_PEER OAUTH_SSLCHECK_BOTH OAUTH_OK OAUTH_BAD_NONCE OAUTH_BAD_TIMESTAMP OAUTH_CONSUMER_KEY_UNKNOWN OAUTH_CONSUMER_KEY_REFUSED OAUTH_INVALID_SIGNATURE OAUTH_TOKEN_USED OAUTH_TOKEN_EXPIRED OAUTH_TOKEN_REVOKED OAUTH_TOKEN_REJECTED OAUTH_VERIFIER_INVALID OAUTH_PARAMETER_ABSENT OAUTH_SIGNATURE_METHOD_REJECTED contained

" odbc
syn keyword phpConstants ODBC_TYPE ODBC_BINMODE_PASSTHRU ODBC_BINMODE_RETURN ODBC_BINMODE_CONVERT SQL_ODBC_CURSORS SQL_CUR_USE_DRIVER SQL_CUR_USE_IF_NEEDED SQL_CUR_USE_ODBC SQL_CONCURRENCY SQL_CONCUR_READ_ONLY SQL_CONCUR_LOCK SQL_CONCUR_ROWVER SQL_CONCUR_VALUES SQL_CURSOR_TYPE SQL_CURSOR_FORWARD_ONLY SQL_CURSOR_KEYSET_DRIVEN SQL_CURSOR_DYNAMIC SQL_CURSOR_STATIC SQL_KEYSET_SIZE SQL_FETCH_FIRST SQL_FETCH_NEXT SQL_CHAR SQL_VARCHAR SQL_LONGVARCHAR SQL_DECIMAL SQL_NUMERIC SQL_BIT SQL_TINYINT SQL_SMALLINT SQL_INTEGER SQL_BIGINT SQL_REAL SQL_FLOAT SQL_DOUBLE SQL_BINARY SQL_VARBINARY SQL_LONGVARBINARY SQL_DATE SQL_TIME SQL_TIMESTAMP contained

" openssl
syn keyword phpConstants OPENSSL_VERSION_TEXT OPENSSL_VERSION_NUMBER X509_PURPOSE_SSL_CLIENT X509_PURPOSE_SSL_SERVER X509_PURPOSE_NS_SSL_SERVER X509_PURPOSE_SMIME_SIGN X509_PURPOSE_SMIME_ENCRYPT X509_PURPOSE_CRL_SIGN X509_PURPOSE_ANY OPENSSL_ALGO_SHA1 OPENSSL_ALGO_MD5 OPENSSL_ALGO_MD4 OPENSSL_ALGO_DSS1 OPENSSL_ALGO_SHA224 OPENSSL_ALGO_SHA256 OPENSSL_ALGO_SHA384 OPENSSL_ALGO_SHA512 OPENSSL_ALGO_RMD160 PKCS7_DETACHED PKCS7_TEXT PKCS7_NOINTERN PKCS7_NOVERIFY PKCS7_NOCHAIN PKCS7_NOCERTS PKCS7_NOATTR PKCS7_BINARY PKCS7_NOSIGS OPENSSL_PKCS1_PADDING OPENSSL_SSLV23_PADDING OPENSSL_NO_PADDING OPENSSL_PKCS1_OAEP_PADDING OPENSSL_CIPHER_RC2_40 OPENSSL_CIPHER_RC2_128 OPENSSL_CIPHER_RC2_64 OPENSSL_CIPHER_DES OPENSSL_CIPHER_3DES OPENSSL_CIPHER_AES_128_CBC OPENSSL_CIPHER_AES_192_CBC OPENSSL_CIPHER_AES_256_CBC OPENSSL_KEYTYPE_RSA OPENSSL_KEYTYPE_DSA OPENSSL_KEYTYPE_DH OPENSSL_KEYTYPE_EC OPENSSL_RAW_DATA OPENSSL_ZERO_PADDING OPENSSL_TLSEXT_SERVER_NAME contained

" pcre
syn keyword phpConstants PREG_PATTERN_ORDER PREG_SET_ORDER PREG_OFFSET_CAPTURE PREG_SPLIT_NO_EMPTY PREG_SPLIT_DELIM_CAPTURE PREG_SPLIT_OFFSET_CAPTURE PREG_GREP_INVERT PREG_NO_ERROR PREG_INTERNAL_ERROR PREG_BACKTRACK_LIMIT_ERROR PREG_RECURSION_LIMIT_ERROR PREG_BAD_UTF8_ERROR PREG_BAD_UTF8_OFFSET_ERROR PCRE_VERSION contained

" PDO
syn keyword phpConstants PARAM_BOOL PARAM_NULL PARAM_INT PARAM_STR PARAM_LOB PARAM_STMT PARAM_INPUT_OUTPUT PARAM_EVT_ALLOC PARAM_EVT_FREE PARAM_EVT_EXEC_PRE PARAM_EVT_EXEC_POST PARAM_EVT_FETCH_PRE PARAM_EVT_FETCH_POST PARAM_EVT_NORMALIZE FETCH_LAZY FETCH_ASSOC FETCH_NUM FETCH_BOTH FETCH_OBJ FETCH_BOUND FETCH_COLUMN FETCH_CLASS FETCH_INTO FETCH_FUNC FETCH_GROUP FETCH_UNIQUE FETCH_KEY_PAIR FETCH_CLASSTYPE FETCH_SERIALIZE FETCH_PROPS_LATE FETCH_NAMED ATTR_AUTOCOMMIT ATTR_PREFETCH ATTR_TIMEOUT ATTR_ERRMODE ATTR_SERVER_VERSION ATTR_CLIENT_VERSION ATTR_SERVER_INFO ATTR_CONNECTION_STATUS ATTR_CASE ATTR_CURSOR_NAME ATTR_CURSOR ATTR_ORACLE_NULLS ATTR_PERSISTENT ATTR_STATEMENT_CLASS ATTR_FETCH_TABLE_NAMES ATTR_FETCH_CATALOG_NAMES ATTR_DRIVER_NAME ATTR_STRINGIFY_FETCHES ATTR_MAX_COLUMN_LEN ATTR_EMULATE_PREPARES ATTR_DEFAULT_FETCH_MODE ERRMODE_SILENT ERRMODE_WARNING ERRMODE_EXCEPTION CASE_NATURAL CASE_LOWER CASE_UPPER NULL_NATURAL NULL_EMPTY_STRING NULL_TO_STRING ERR_NONE FETCH_ORI_NEXT FETCH_ORI_PRIOR FETCH_ORI_FIRST FETCH_ORI_LAST FETCH_ORI_ABS FETCH_ORI_REL CURSOR_FWDONLY CURSOR_SCROLL MYSQL_ATTR_USE_BUFFERED_QUERY MYSQL_ATTR_LOCAL_INFILE MYSQL_ATTR_INIT_COMMAND MYSQL_ATTR_COMPRESS MYSQL_ATTR_DIRECT_QUERY MYSQL_ATTR_FOUND_ROWS MYSQL_ATTR_IGNORE_SPACE MYSQL_ATTR_SSL_KEY MYSQL_ATTR_SSL_CERT MYSQL_ATTR_SSL_CA MYSQL_ATTR_SSL_CAPATH MYSQL_ATTR_SSL_CIPHER MYSQL_ATTR_SERVER_PUBLIC_KEY ODBC_ATTR_USE_CURSOR_LIBRARY ODBC_ATTR_ASSUME_UTF8 ODBC_SQL_USE_IF_NEEDED ODBC_SQL_USE_DRIVER ODBC_SQL_USE_ODBC PGSQL_ATTR_DISABLE_NATIVE_PREPARED_STATEMENT PGSQL_TRANSACTION_IDLE PGSQL_TRANSACTION_ACTIVE PGSQL_TRANSACTION_INTRANS PGSQL_TRANSACTION_INERROR PGSQL_TRANSACTION_UNKNOWN contained

" pgsql
syn keyword phpConstants PGSQL_LIBPQ_VERSION PGSQL_LIBPQ_VERSION_STR PGSQL_CONNECT_FORCE_NEW PGSQL_ASSOC PGSQL_NUM PGSQL_BOTH PGSQL_CONNECTION_BAD PGSQL_CONNECTION_OK PGSQL_TRANSACTION_IDLE PGSQL_TRANSACTION_ACTIVE PGSQL_TRANSACTION_INTRANS PGSQL_TRANSACTION_INERROR PGSQL_TRANSACTION_UNKNOWN PGSQL_ERRORS_TERSE PGSQL_ERRORS_DEFAULT PGSQL_ERRORS_VERBOSE PGSQL_SEEK_SET PGSQL_SEEK_CUR PGSQL_SEEK_END PGSQL_STATUS_LONG PGSQL_STATUS_STRING PGSQL_EMPTY_QUERY PGSQL_COMMAND_OK PGSQL_TUPLES_OK PGSQL_COPY_OUT PGSQL_COPY_IN PGSQL_BAD_RESPONSE PGSQL_NONFATAL_ERROR PGSQL_FATAL_ERROR PGSQL_DIAG_SEVERITY PGSQL_DIAG_SQLSTATE PGSQL_DIAG_MESSAGE_PRIMARY PGSQL_DIAG_MESSAGE_DETAIL PGSQL_DIAG_MESSAGE_HINT PGSQL_DIAG_STATEMENT_POSITION PGSQL_DIAG_INTERNAL_POSITION PGSQL_DIAG_INTERNAL_QUERY PGSQL_DIAG_CONTEXT PGSQL_DIAG_SOURCE_FILE PGSQL_DIAG_SOURCE_LINE PGSQL_DIAG_SOURCE_FUNCTION PGSQL_CONV_IGNORE_DEFAULT PGSQL_CONV_FORCE_NULL PGSQL_CONV_IGNORE_NOT_NULL PGSQL_DML_NO_CONV PGSQL_DML_EXEC PGSQL_DML_ASYNC PGSQL_DML_STRING contained

" Phar
syn keyword phpConstants CURRENT_MODE_MASK CURRENT_AS_PATHNAME CURRENT_AS_FILEINFO CURRENT_AS_SELF KEY_MODE_MASK KEY_AS_PATHNAME FOLLOW_SYMLINKS KEY_AS_FILENAME NEW_CURRENT_AND_KEY OTHER_MODE_MASK SKIP_DOTS UNIX_PATHS BZ2 GZ NONE PHAR TAR ZIP COMPRESSED PHP PHPS MD5 OPENSSL SHA1 SHA256 SHA512 contained

" pcntl
syn keyword phpConstants WNOHANG WUNTRACED SIG_IGN SIG_DFL SIG_ERR SIGHUP SIGINT SIGQUIT SIGILL SIGTRAP SIGABRT SIGIOT SIGBUS SIGFPE SIGKILL SIGUSR1 SIGSEGV SIGUSR2 SIGPIPE SIGALRM SIGTERM SIGCHLD SIGCONT SIGSTOP SIGTSTP SIGTTIN SIGTTOU SIGURG SIGXCPU SIGXFSZ SIGVTALRM SIGPROF SIGWINCH SIGIO SIGSYS SIGBABY PRIO_PGRP PRIO_USER PRIO_PROCESS SIG_BLOCK SIG_UNBLOCK SIG_SETMASK PCNTL_EINTR PCNTL_ECHILD PCNTL_EINVAL PCNTL_EAGAIN PCNTL_ESRCH PCNTL_EACCES PCNTL_EPERM PCNTL_ENOMEM PCNTL_E2BIG PCNTL_EFAULT PCNTL_EIO PCNTL_EISDIR PCNTL_ELOOP PCNTL_EMFILE PCNTL_ENAMETOOLONG PCNTL_ENFILE PCNTL_ENOENT PCNTL_ENOEXEC PCNTL_ENOTDIR PCNTL_ETXTBSY contained

" phalcon
syn keyword phpConstants MODELS_ATTRIBUTES MODELS_PRIMARY_KEY MODELS_NON_PRIMARY_KEY MODELS_NOT_NULL MODELS_DATA_TYPES MODELS_DATA_TYPES_NUMERIC MODELS_DATE_AT MODELS_DATE_IN MODELS_IDENTITY_COLUMN MODELS_DATA_TYPES_BIND MODELS_AUTOMATIC_DEFAULT_INSERT MODELS_AUTOMATIC_DEFAULT_UPDATE MODELS_COLUMN_MAP MODELS_REVERSE_COLUMN_MAP TYPE_RESULT_FULL TYPE_RESULT_PARTIAL HYDRATE_RECORDS HYDRATE_OBJECTS HYDRATE_ARRAYS EXCEPTION_NO_DI EXCEPTION_CYCLIC_ROUTING EXCEPTION_HANDLER_NOT_FOUND EXCEPTION_INVALID_HANDLER EXCEPTION_INVALID_PARAMS EXCEPTION_ACTION_NOT_FOUND URI_SOURCE_GET_URL URI_SOURCE_SERVER_REQUEST_URI FETCH_USE_DEFAULT FETCH_LAZY FETCH_ASSOC FETCH_NUM FETCH_BOTH FETCH_OBJ FETCH_BOUND FETCH_COLUMN FETCH_CLASS FETCH_INTO FETCH_FUNC FETCH_NAMED FETCH_KEY_PAIR FETCH_GROUP FETCH_UNIQUE FETCH_CLASSTYPE FETCH_SERIALIZE FETCH_PROPS_LATE ALLOW DENY HTML32 HTML401_STRICT HTML401_TRANSITIONAL HTML401_FRAMESET HTML5 XHTML10_STRICT XHTML10_TRANSITIONAL XHTML10_FRAMESET XHTML11 XHTML20 XHTML5 TYPE_INTEGER TYPE_DATE TYPE_VARCHAR TYPE_DECIMAL TYPE_DATETIME TYPE_CHAR TYPE_TEXT TYPE_FLOAT TYPE_BOOLEAN TYPE_DOUBLE BIND_PARAM_NULL BIND_PARAM_INT BIND_PARAM_STR BIND_PARAM_BOOL BIND_PARAM_DECIMAL BIND_SKIP RANDOM_ALNUM RANDOM_ALPHA RANDOM_HEXDEC RANDOM_NUMERIC RANDOM_NOZERO CRYPT_DEFAULT CRYPT_STD_DES CRYPT_EXT_DES CRYPT_MD5 CRYPT_BLOWFISH CRYPT_BLOWFISH_X CRYPT_BLOWFISH_Y CRYPT_SHA256 CRYPT_SHA512 SPECIAL CUSTOM DEBUG INFO NOTICE WARNING ERROR ALERT CRITICAL EMERGENCE EMERGENCY PADDING_DEFAULT PADDING_ANSI_X_923 PADDING_PKCS7 PADDING_ISO_10126 PADDING_ISO_IEC_7816_4 PADDING_ZERO PADDING_SPACE LEVEL_MAIN_LAYOUT LEVEL_AFTER_TEMPLATE LEVEL_LAYOUT LEVEL_BEFORE_TEMPLATE LEVEL_ACTION_VIEW LEVEL_NO_RENDER OP_NONE OP_CREATE OP_UPDATE OP_DELETE DIRTY_STATE_PERSISTENT DIRTY_STATE_TRANSIENT DIRTY_STATE_DETACHED TYPE_SELECT TYPE_INSERT TYPE_UPDATE TYPE_DELETE BELONGS_TO HAS_ONE HAS_MANY HAS_ONE_THROUGH HAS_MANY_THROUGH NO_ACTION ACTION_RESTRICT ACTION_CASCADE NONE WIDTH HEIGHT AUTO INVERSE PRECISE TENSILE HORIZONTAL VERTICAL GD IMAGICK contained

" posix
syn keyword phpConstants POSIX_F_OK POSIX_X_OK POSIX_W_OK POSIX_R_OK POSIX_S_IFREG POSIX_S_IFCHR POSIX_S_IFBLK POSIX_S_IFIFO POSIX_S_IFSOCK contained

" pspell
syn keyword phpConstants PSPELL_FAST PSPELL_NORMAL PSPELL_BAD_SPELLERS PSPELL_RUN_TOGETHER contained

" readline
syn keyword phpConstants READLINE_LIB contained

" redis
syn keyword phpConstants REDIS_NOT_FOUND REDIS_STRING REDIS_SET REDIS_LIST REDIS_ZSET REDIS_HASH ATOMIC MULTI PIPELINE OPT_SERIALIZER OPT_PREFIX OPT_READ_TIMEOUT SERIALIZER_NONE SERIALIZER_PHP AFTER BEFORE contained

" Reflection
syn keyword phpConstants IS_DEPRECATED IS_STATIC IS_PUBLIC IS_PROTECTED IS_PRIVATE IS_ABSTRACT IS_FINAL IS_IMPLICIT_ABSTRACT IS_EXPLICIT_ABSTRACT contained

" runkit
syn keyword phpConstants RUNKIT_IMPORT_FUNCTIONS RUNKIT_IMPORT_CLASS_METHODS RUNKIT_IMPORT_CLASS_CONSTS RUNKIT_IMPORT_CLASS_PROPS RUNKIT_IMPORT_CLASS_STATIC_PROPS RUNKIT_IMPORT_CLASSES RUNKIT_IMPORT_OVERRIDE RUNKIT_VERSION RUNKIT_ACC_RETURN_REFERENCE RUNKIT_ACC_PUBLIC RUNKIT_ACC_PROTECTED RUNKIT_ACC_PRIVATE RUNKIT_ACC_STATIC RUNKIT_OVERRIDE_OBJECTS RUNKIT_FEATURE_MANIPULATION RUNKIT_FEATURE_SUPERGLOBALS RUNKIT_FEATURE_SANDBOX contained

" session
syn keyword phpConstants PHP_SESSION_DISABLED PHP_SESSION_NONE PHP_SESSION_ACTIVE contained

" snmp
syn keyword phpConstants SNMP_OID_OUTPUT_SUFFIX SNMP_OID_OUTPUT_MODULE SNMP_OID_OUTPUT_FULL SNMP_OID_OUTPUT_NUMERIC SNMP_OID_OUTPUT_UCD SNMP_OID_OUTPUT_NONE SNMP_VALUE_LIBRARY SNMP_VALUE_PLAIN SNMP_VALUE_OBJECT SNMP_BIT_STR SNMP_OCTET_STR SNMP_OPAQUE SNMP_NULL SNMP_OBJECT_ID SNMP_IPADDRESS SNMP_COUNTER SNMP_UNSIGNED SNMP_TIMETICKS SNMP_UINTEGER SNMP_INTEGER SNMP_COUNTER64 VERSION_1 VERSION_2c VERSION_2C VERSION_3 ERRNO_NOERROR ERRNO_ANY ERRNO_GENERIC ERRNO_TIMEOUT ERRNO_ERROR_IN_REPLY ERRNO_OID_NOT_INCREASING ERRNO_OID_PARSING_ERROR ERRNO_MULTIPLE_SET_QUERIES contained

" soap
syn keyword phpConstants SOAP_1_1 SOAP_1_2 SOAP_PERSISTENCE_SESSION SOAP_PERSISTENCE_REQUEST SOAP_FUNCTIONS_ALL SOAP_ENCODED SOAP_LITERAL SOAP_RPC SOAP_DOCUMENT SOAP_ACTOR_NEXT SOAP_ACTOR_NONE SOAP_ACTOR_UNLIMATERECEIVER SOAP_COMPRESSION_ACCEPT SOAP_COMPRESSION_GZIP SOAP_COMPRESSION_DEFLATE SOAP_AUTHENTICATION_BASIC SOAP_AUTHENTICATION_DIGEST UNKNOWN_TYPE XSD_STRING XSD_BOOLEAN XSD_DECIMAL XSD_FLOAT XSD_DOUBLE XSD_DURATION XSD_DATETIME XSD_TIME XSD_DATE XSD_GYEARMONTH XSD_GYEAR XSD_GMONTHDAY XSD_GDAY XSD_GMONTH XSD_HEXBINARY XSD_BASE64BINARY XSD_ANYURI XSD_QNAME XSD_NOTATION XSD_NORMALIZEDSTRING XSD_TOKEN XSD_LANGUAGE XSD_NMTOKEN XSD_NAME XSD_NCNAME XSD_ID XSD_IDREF XSD_IDREFS XSD_ENTITY XSD_ENTITIES XSD_INTEGER XSD_NONPOSITIVEINTEGER XSD_NEGATIVEINTEGER XSD_LONG XSD_INT XSD_SHORT XSD_BYTE XSD_NONNEGATIVEINTEGER XSD_UNSIGNEDLONG XSD_UNSIGNEDINT XSD_UNSIGNEDSHORT XSD_UNSIGNEDBYTE XSD_POSITIVEINTEGER XSD_NMTOKENS XSD_ANYTYPE XSD_ANYXML APACHE_MAP SOAP_ENC_OBJECT SOAP_ENC_ARRAY XSD_1999_TIMEINSTANT XSD_NAMESPACE XSD_1999_NAMESPACE SOAP_SINGLE_ELEMENT_ARRAYS SOAP_WAIT_ONE_WAY_CALLS SOAP_USE_XSI_ARRAY_TYPE WSDL_CACHE_NONE WSDL_CACHE_DISK WSDL_CACHE_MEMORY WSDL_CACHE_BOTH SOAP_SSL_METHOD_TLS SOAP_SSL_METHOD_SSLv2 SOAP_SSL_METHOD_SSLv3 SOAP_SSL_METHOD_SSLv23 contained

" sockets
syn keyword phpConstants AF_UNIX AF_INET AF_INET6 SOCK_STREAM SOCK_DGRAM SOCK_RAW SOCK_SEQPACKET SOCK_RDM MSG_OOB MSG_WAITALL MSG_CTRUNC MSG_TRUNC MSG_PEEK MSG_DONTROUTE MSG_EOR MSG_EOF MSG_DONTWAIT SO_DEBUG SO_REUSEADDR SO_REUSEPORT SO_KEEPALIVE SO_DONTROUTE SO_LINGER SO_BROADCAST SO_OOBINLINE SO_SNDBUF SO_RCVBUF SO_SNDLOWAT SO_RCVLOWAT SO_SNDTIMEO SO_RCVTIMEO SO_TYPE SO_ERROR SOL_SOCKET SOMAXCONN TCP_NODELAY PHP_NORMAL_READ PHP_BINARY_READ MCAST_JOIN_GROUP MCAST_LEAVE_GROUP IP_MULTICAST_IF IP_MULTICAST_TTL IP_MULTICAST_LOOP IPV6_MULTICAST_IF IPV6_MULTICAST_HOPS IPV6_MULTICAST_LOOP SOCKET_EPERM SOCKET_ENOENT SOCKET_EINTR SOCKET_EIO SOCKET_ENXIO SOCKET_E2BIG SOCKET_EBADF SOCKET_EAGAIN SOCKET_ENOMEM SOCKET_EACCES SOCKET_EFAULT SOCKET_ENOTBLK SOCKET_EBUSY SOCKET_EEXIST SOCKET_EXDEV SOCKET_ENODEV SOCKET_ENOTDIR SOCKET_EISDIR SOCKET_EINVAL SOCKET_ENFILE SOCKET_EMFILE SOCKET_ENOTTY SOCKET_ENOSPC SOCKET_ESPIPE SOCKET_EROFS SOCKET_EMLINK SOCKET_EPIPE SOCKET_ENAMETOOLONG SOCKET_ENOLCK SOCKET_ENOSYS SOCKET_ENOTEMPTY SOCKET_ELOOP SOCKET_EWOULDBLOCK SOCKET_ENOMSG SOCKET_EIDRM SOCKET_ENOSTR SOCKET_ENODATA SOCKET_ETIME SOCKET_ENOSR SOCKET_EREMOTE SOCKET_ENOLINK SOCKET_EPROTO SOCKET_EMULTIHOP SOCKET_EBADMSG SOCKET_EUSERS SOCKET_ENOTSOCK SOCKET_EDESTADDRREQ SOCKET_EMSGSIZE SOCKET_EPROTOTYPE SOCKET_ENOPROTOOPT SOCKET_EPROTONOSUPPORT SOCKET_ESOCKTNOSUPPORT SOCKET_EOPNOTSUPP SOCKET_EPFNOSUPPORT SOCKET_EAFNOSUPPORT SOCKET_EADDRINUSE SOCKET_EADDRNOTAVAIL SOCKET_ENETDOWN SOCKET_ENETUNREACH SOCKET_ENETRESET SOCKET_ECONNABORTED SOCKET_ECONNRESET SOCKET_ENOBUFS SOCKET_EISCONN SOCKET_ENOTCONN SOCKET_ESHUTDOWN SOCKET_ETOOMANYREFS SOCKET_ETIMEDOUT SOCKET_ECONNREFUSED SOCKET_EHOSTDOWN SOCKET_EHOSTUNREACH SOCKET_EALREADY SOCKET_EINPROGRESS SOCKET_EDQUOT IPPROTO_IP IPPROTO_IPV6 SOL_TCP SOL_UDP IPV6_UNICAST_HOPS IPV6_RECVTCLASS IPV6_TCLASS SCM_RIGHTS contained

" solr
syn keyword phpConstants SOLR_MAJOR_VERSION SOLR_MINOR_VERSION SOLR_PATCH_VERSION SOLR_EXTENSION_VERSION SORT_DEFAULT SORT_ASC SORT_DESC SORT_FIELD_NAME SORT_FIELD_VALUE_COUNT SORT_FIELD_BOOST_VALUE SEARCH_SERVLET_TYPE UPDATE_SERVLET_TYPE THREADS_SERVLET_TYPE PING_SERVLET_TYPE TERMS_SERVLET_TYPE DEFAULT_SEARCH_SERVLET DEFAULT_UPDATE_SERVLET DEFAULT_THREADS_SERVLET DEFAULT_PING_SERVLET DEFAULT_TERMS_SERVLET ORDER_ASC ORDER_DESC FACET_SORT_INDEX FACET_SORT_COUNT TERMS_SORT_INDEX TERMS_SORT_COUNT PARSE_SOLR_OBJ PARSE_SOLR_DOC contained

" sphinx
syn keyword phpConstants SEARCHD_OK SEARCHD_ERROR SEARCHD_RETRY SEARCHD_WARNING SPH_MATCH_ALL SPH_MATCH_ANY SPH_MATCH_PHRASE SPH_MATCH_BOOLEAN SPH_MATCH_EXTENDED SPH_MATCH_FULLSCAN SPH_MATCH_EXTENDED2 SPH_RANK_PROXIMITY_BM25 SPH_RANK_BM25 SPH_RANK_NONE SPH_RANK_WORDCOUNT SPH_SORT_RELEVANCE SPH_SORT_ATTR_DESC SPH_SORT_ATTR_ASC SPH_SORT_TIME_SEGMENTS SPH_SORT_EXTENDED SPH_SORT_EXPR SPH_FILTER_VALUES SPH_FILTER_RANGE SPH_FILTER_FLOATRANGE SPH_ATTR_INTEGER SPH_ATTR_TIMESTAMP SPH_ATTR_ORDINAL SPH_ATTR_BOOL SPH_ATTR_FLOAT SPH_ATTR_MULTI SPH_GROUPBY_DAY SPH_GROUPBY_WEEK SPH_GROUPBY_MONTH SPH_GROUPBY_YEAR SPH_GROUPBY_ATTR SPH_GROUPBY_ATTRPAIR contained

" SPL
syn keyword phpConstants LEAVES_ONLY SELF_FIRST CHILD_FIRST CATCH_GET_CHILD CALL_TOSTRING TOSTRING_USE_KEY TOSTRING_USE_CURRENT TOSTRING_USE_INNER FULL_CACHE USE_KEY MATCH GET_MATCH ALL_MATCHES SPLIT REPLACE BYPASS_CURRENT BYPASS_KEY PREFIX_LEFT PREFIX_MID_HAS_NEXT PREFIX_MID_LAST PREFIX_END_HAS_NEXT PREFIX_END_LAST PREFIX_RIGHT STD_PROP_LIST ARRAY_AS_PROPS CHILD_ARRAYS_ONLY CURRENT_MODE_MASK CURRENT_AS_PATHNAME CURRENT_AS_FILEINFO CURRENT_AS_SELF KEY_MODE_MASK KEY_AS_PATHNAME FOLLOW_SYMLINKS KEY_AS_FILENAME NEW_CURRENT_AND_KEY OTHER_MODE_MASK SKIP_DOTS UNIX_PATHS DROP_NEW_LINE READ_AHEAD SKIP_EMPTY READ_CSV IT_MODE_LIFO IT_MODE_FIFO IT_MODE_DELETE IT_MODE_KEEP EXTR_BOTH EXTR_PRIORITY EXTR_DATA MIT_NEED_ANY MIT_NEED_ALL MIT_KEYS_NUMERIC MIT_KEYS_ASSOC contained

" sqlite3
syn keyword phpConstants SQLITE3_ASSOC SQLITE3_NUM SQLITE3_BOTH SQLITE3_INTEGER SQLITE3_FLOAT SQLITE3_TEXT SQLITE3_BLOB SQLITE3_NULL SQLITE3_OPEN_READONLY SQLITE3_OPEN_READWRITE SQLITE3_OPEN_CREATE contained

" ssh2
syn keyword phpConstants SSH2_FINGERPRINT_MD5 SSH2_FINGERPRINT_SHA1 SSH2_FINGERPRINT_HEX SSH2_FINGERPRINT_RAW SSH2_TERM_UNIT_CHARS SSH2_TERM_UNIT_PIXELS SSH2_DEFAULT_TERMINAL SSH2_DEFAULT_TERM_WIDTH SSH2_DEFAULT_TERM_HEIGHT SSH2_DEFAULT_TERM_UNIT SSH2_STREAM_STDIO SSH2_STREAM_STDERR SSH2_POLLIN SSH2_POLLEXT SSH2_POLLOUT SSH2_POLLERR SSH2_POLLHUP SSH2_POLLNVAL SSH2_POLL_SESSION_CLOSED SSH2_POLL_CHANNEL_CLOSED SSH2_POLL_LISTENER_CLOSED contained

" standard
syn keyword phpConstants CONNECTION_ABORTED CONNECTION_NORMAL CONNECTION_TIMEOUT INI_USER INI_PERDIR INI_SYSTEM INI_ALL INI_SCANNER_NORMAL INI_SCANNER_RAW PHP_URL_SCHEME PHP_URL_HOST PHP_URL_PORT PHP_URL_USER PHP_URL_PASS PHP_URL_PATH PHP_URL_QUERY PHP_URL_FRAGMENT PHP_QUERY_RFC1738 PHP_QUERY_RFC3986 M_E M_LOG2E M_LOG10E M_LN2 M_LN10 M_PI M_PI_2 M_PI_4 M_1_PI M_2_PI M_SQRTPI M_2_SQRTPI M_LNPI M_EULER M_SQRT2 M_SQRT1_2 M_SQRT3 INF NAN PHP_ROUND_HALF_UP PHP_ROUND_HALF_DOWN PHP_ROUND_HALF_EVEN PHP_ROUND_HALF_ODD INFO_GENERAL INFO_CREDITS INFO_CONFIGURATION INFO_MODULES INFO_ENVIRONMENT INFO_VARIABLES INFO_LICENSE INFO_ALL CREDITS_GROUP CREDITS_GENERAL CREDITS_SAPI CREDITS_MODULES CREDITS_DOCS CREDITS_FULLPAGE CREDITS_QA CREDITS_ALL HTML_SPECIALCHARS HTML_ENTITIES ENT_COMPAT ENT_QUOTES ENT_NOQUOTES ENT_IGNORE ENT_SUBSTITUTE ENT_DISALLOWED ENT_HTML401 ENT_XML1 ENT_XHTML ENT_HTML5 STR_PAD_LEFT STR_PAD_RIGHT STR_PAD_BOTH PATHINFO_DIRNAME PATHINFO_BASENAME PATHINFO_EXTENSION PATHINFO_FILENAME CHAR_MAX LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_ALL LC_MESSAGES SEEK_SET SEEK_CUR SEEK_END LOCK_SH LOCK_EX LOCK_UN LOCK_NB STREAM_NOTIFY_CONNECT STREAM_NOTIFY_AUTH_REQUIRED STREAM_NOTIFY_AUTH_RESULT STREAM_NOTIFY_MIME_TYPE_IS STREAM_NOTIFY_FILE_SIZE_IS STREAM_NOTIFY_REDIRECTED STREAM_NOTIFY_PROGRESS STREAM_NOTIFY_FAILURE STREAM_NOTIFY_COMPLETED STREAM_NOTIFY_RESOLVE STREAM_NOTIFY_SEVERITY_INFO STREAM_NOTIFY_SEVERITY_WARN STREAM_NOTIFY_SEVERITY_ERR STREAM_FILTER_READ STREAM_FILTER_WRITE STREAM_FILTER_ALL STREAM_CLIENT_PERSISTENT STREAM_CLIENT_ASYNC_CONNECT STREAM_CLIENT_CONNECT STREAM_CRYPTO_METHOD_SSLv2_CLIENT STREAM_CRYPTO_METHOD_SSLv3_CLIENT STREAM_CRYPTO_METHOD_SSLv23_CLIENT STREAM_CRYPTO_METHOD_TLS_CLIENT STREAM_CRYPTO_METHOD_SSLv2_SERVER STREAM_CRYPTO_METHOD_SSLv3_SERVER STREAM_CRYPTO_METHOD_SSLv23_SERVER STREAM_CRYPTO_METHOD_TLS_SERVER STREAM_SHUT_RD STREAM_SHUT_WR STREAM_SHUT_RDWR STREAM_PF_INET STREAM_PF_INET6 STREAM_PF_UNIX STREAM_IPPROTO_IP STREAM_IPPROTO_TCP STREAM_IPPROTO_UDP STREAM_IPPROTO_ICMP STREAM_IPPROTO_RAW STREAM_SOCK_STREAM STREAM_SOCK_DGRAM STREAM_SOCK_RAW STREAM_SOCK_SEQPACKET STREAM_SOCK_RDM STREAM_PEEK STREAM_OOB STREAM_SERVER_BIND STREAM_SERVER_LISTEN FILE_USE_INCLUDE_PATH FILE_IGNORE_NEW_LINES FILE_SKIP_EMPTY_LINES FILE_APPEND FILE_NO_DEFAULT_CONTEXT FILE_TEXT FILE_BINARY FNM_NOESCAPE FNM_PATHNAME FNM_PERIOD FNM_CASEFOLD PSFS_PASS_ON PSFS_FEED_ME PSFS_ERR_FATAL PSFS_FLAG_NORMAL PSFS_FLAG_FLUSH_INC PSFS_FLAG_FLUSH_CLOSE PASSWORD_DEFAULT PASSWORD_BCRYPT PASSWORD_BCRYPT_DEFAULT_COST ABDAY_1 ABDAY_2 ABDAY_3 ABDAY_4 ABDAY_5 ABDAY_6 ABDAY_7 DAY_1 DAY_2 DAY_3 DAY_4 DAY_5 DAY_6 DAY_7 ABMON_1 ABMON_2 ABMON_3 ABMON_4 ABMON_5 ABMON_6 ABMON_7 ABMON_8 ABMON_9 ABMON_10 ABMON_11 ABMON_12 MON_1 MON_2 MON_3 MON_4 MON_5 MON_6 MON_7 MON_8 MON_9 MON_10 MON_11 MON_12 AM_STR PM_STR D_T_FMT D_FMT T_FMT T_FMT_AMPM ERA ERA_D_T_FMT ERA_D_FMT ERA_T_FMT ALT_DIGITS CRNCYSTR RADIXCHAR THOUSEP YESEXPR NOEXPR YESSTR NOSTR CODESET CRYPT_SALT_LENGTH CRYPT_STD_DES CRYPT_EXT_DES CRYPT_MD5 CRYPT_BLOWFISH CRYPT_SHA256 CRYPT_SHA512 DIRECTORY_SEPARATOR PATH_SEPARATOR SCANDIR_SORT_ASCENDING SCANDIR_SORT_DESCENDING SCANDIR_SORT_NONE GLOB_BRACE GLOB_MARK GLOB_NOSORT GLOB_NOCHECK GLOB_NOESCAPE GLOB_ERR GLOB_ONLYDIR GLOB_AVAILABLE_FLAGS LOG_EMERG LOG_ALERT LOG_CRIT LOG_ERR LOG_WARNING LOG_NOTICE LOG_INFO LOG_DEBUG LOG_KERN LOG_USER LOG_MAIL LOG_DAEMON LOG_AUTH LOG_SYSLOG LOG_LPR LOG_NEWS LOG_UUCP LOG_CRON LOG_AUTHPRIV LOG_LOCAL0 LOG_LOCAL1 LOG_LOCAL2 LOG_LOCAL3 LOG_LOCAL4 LOG_LOCAL5 LOG_LOCAL6 LOG_LOCAL7 LOG_PID LOG_CONS LOG_ODELAY LOG_NDELAY LOG_NOWAIT LOG_PERROR EXTR_OVERWRITE EXTR_SKIP EXTR_PREFIX_SAME EXTR_PREFIX_ALL EXTR_PREFIX_INVALID EXTR_PREFIX_IF_EXISTS EXTR_IF_EXISTS EXTR_REFS SORT_ASC SORT_DESC SORT_REGULAR SORT_NUMERIC SORT_STRING SORT_LOCALE_STRING SORT_NATURAL SORT_FLAG_CASE CASE_LOWER CASE_UPPER COUNT_NORMAL COUNT_RECURSIVE ASSERT_ACTIVE ASSERT_CALLBACK ASSERT_BAIL ASSERT_WARNING ASSERT_QUIET_EVAL STREAM_USE_PATH STREAM_IGNORE_URL STREAM_REPORT_ERRORS STREAM_MUST_SEEK STREAM_URL_STAT_LINK STREAM_URL_STAT_QUIET STREAM_MKDIR_RECURSIVE STREAM_IS_URL STREAM_OPTION_BLOCKING STREAM_OPTION_READ_TIMEOUT STREAM_OPTION_READ_BUFFER STREAM_OPTION_WRITE_BUFFER STREAM_BUFFER_NONE STREAM_BUFFER_LINE STREAM_BUFFER_FULL STREAM_CAST_AS_STREAM STREAM_CAST_FOR_SELECT STREAM_META_TOUCH STREAM_META_OWNER STREAM_META_OWNER_NAME STREAM_META_GROUP STREAM_META_GROUP_NAME STREAM_META_ACCESS IMAGETYPE_GIF IMAGETYPE_JPEG IMAGETYPE_PNG IMAGETYPE_SWF IMAGETYPE_PSD IMAGETYPE_BMP IMAGETYPE_TIFF_II IMAGETYPE_TIFF_MM IMAGETYPE_JPC IMAGETYPE_JP2 IMAGETYPE_JPX IMAGETYPE_JB2 IMAGETYPE_SWC IMAGETYPE_IFF IMAGETYPE_WBMP IMAGETYPE_JPEG2000 IMAGETYPE_XBM IMAGETYPE_ICO IMAGETYPE_UNKNOWN IMAGETYPE_COUNT DNS_A DNS_NS DNS_CNAME DNS_SOA DNS_PTR DNS_HINFO DNS_MX DNS_TXT DNS_SRV DNS_NAPTR DNS_AAAA DNS_A6 DNS_ANY DNS_ALL contained

" sundown
syn keyword phpConstants Sundown\Render\HTML LIST_ORDERED MKDA_EMAIL MKDA_NORMAL contained

" swoole
syn keyword phpConstants SWOOLE_BASE SWOOLE_THREAD SWOOLE_PROCESS SWOOLE_SOCK_TCP SWOOLE_SOCK_TCP6 SWOOLE_SOCK_UDP SWOOLE_SOCK_UDP6 SWOOLE_RWLOCK SWOOLE_FILELOCK SWOOLE_MUTEX SWOOLE_SEM SWOOLE_SOCK_SYNC SWOOLE_SOCK_ASYNC SWOOLE_VERSION contained

" sysvmsg
syn keyword phpConstants MSG_IPC_NOWAIT MSG_EAGAIN MSG_ENOMSG MSG_NOERROR MSG_EXCEPT contained

" tidy
syn keyword phpConstants TIDY_TAG_UNKNOWN TIDY_TAG_A TIDY_TAG_ABBR TIDY_TAG_ACRONYM TIDY_TAG_ADDRESS TIDY_TAG_ALIGN TIDY_TAG_APPLET TIDY_TAG_AREA TIDY_TAG_B TIDY_TAG_BASE TIDY_TAG_BASEFONT TIDY_TAG_BDO TIDY_TAG_BGSOUND TIDY_TAG_BIG TIDY_TAG_BLINK TIDY_TAG_BLOCKQUOTE TIDY_TAG_BODY TIDY_TAG_BR TIDY_TAG_BUTTON TIDY_TAG_CAPTION TIDY_TAG_CENTER TIDY_TAG_CITE TIDY_TAG_CODE TIDY_TAG_COL TIDY_TAG_COLGROUP TIDY_TAG_COMMENT TIDY_TAG_DD TIDY_TAG_DEL TIDY_TAG_DFN TIDY_TAG_DIR TIDY_TAG_DIV TIDY_TAG_DL TIDY_TAG_DT TIDY_TAG_EM TIDY_TAG_EMBED TIDY_TAG_FIELDSET TIDY_TAG_FONT TIDY_TAG_FORM TIDY_TAG_FRAME TIDY_TAG_FRAMESET TIDY_TAG_H1 TIDY_TAG_H2 TIDY_TAG_H3 TIDY_TAG_H4 TIDY_TAG_H5 TIDY_TAG_H6 TIDY_TAG_HEAD TIDY_TAG_HR TIDY_TAG_HTML TIDY_TAG_I TIDY_TAG_IFRAME TIDY_TAG_ILAYER TIDY_TAG_IMG TIDY_TAG_INPUT TIDY_TAG_INS TIDY_TAG_ISINDEX TIDY_TAG_KBD TIDY_TAG_KEYGEN TIDY_TAG_LABEL TIDY_TAG_LAYER TIDY_TAG_LEGEND TIDY_TAG_LI TIDY_TAG_LINK TIDY_TAG_LISTING TIDY_TAG_MAP TIDY_TAG_MARQUEE TIDY_TAG_MENU TIDY_TAG_META TIDY_TAG_MULTICOL TIDY_TAG_NOBR TIDY_TAG_NOEMBED TIDY_TAG_NOFRAMES TIDY_TAG_NOLAYER TIDY_TAG_NOSAVE TIDY_TAG_NOSCRIPT TIDY_TAG_OBJECT TIDY_TAG_OL TIDY_TAG_OPTGROUP TIDY_TAG_OPTION TIDY_TAG_P TIDY_TAG_PARAM TIDY_TAG_PLAINTEXT TIDY_TAG_PRE TIDY_TAG_Q TIDY_TAG_RB TIDY_TAG_RBC TIDY_TAG_RP TIDY_TAG_RT TIDY_TAG_RTC TIDY_TAG_RUBY TIDY_TAG_S TIDY_TAG_SAMP TIDY_TAG_SCRIPT TIDY_TAG_SELECT TIDY_TAG_SERVER TIDY_TAG_SERVLET TIDY_TAG_SMALL TIDY_TAG_SPACER TIDY_TAG_SPAN TIDY_TAG_STRIKE TIDY_TAG_STRONG TIDY_TAG_STYLE TIDY_TAG_SUB TIDY_TAG_SUP TIDY_TAG_TABLE TIDY_TAG_TBODY TIDY_TAG_TD TIDY_TAG_TEXTAREA TIDY_TAG_TFOOT TIDY_TAG_TH TIDY_TAG_THEAD TIDY_TAG_TITLE TIDY_TAG_TR TIDY_TAG_TT TIDY_TAG_U TIDY_TAG_UL TIDY_TAG_VAR TIDY_TAG_WBR TIDY_TAG_XMP TIDY_NODETYPE_ROOT TIDY_NODETYPE_DOCTYPE TIDY_NODETYPE_COMMENT TIDY_NODETYPE_PROCINS TIDY_NODETYPE_TEXT TIDY_NODETYPE_START TIDY_NODETYPE_END TIDY_NODETYPE_STARTEND TIDY_NODETYPE_CDATA TIDY_NODETYPE_SECTION TIDY_NODETYPE_ASP TIDY_NODETYPE_JSTE TIDY_NODETYPE_PHP TIDY_NODETYPE_XMLDECL contained

" tokenizer
syn keyword phpConstants T_REQUIRE_ONCE T_REQUIRE T_EVAL T_INCLUDE_ONCE T_INCLUDE T_LOGICAL_OR T_LOGICAL_XOR T_LOGICAL_AND T_PRINT T_SR_EQUAL T_SL_EQUAL T_XOR_EQUAL T_OR_EQUAL T_AND_EQUAL T_MOD_EQUAL T_CONCAT_EQUAL T_DIV_EQUAL T_MUL_EQUAL T_MINUS_EQUAL T_PLUS_EQUAL T_BOOLEAN_OR T_BOOLEAN_AND T_IS_NOT_IDENTICAL T_IS_IDENTICAL T_IS_NOT_EQUAL T_IS_EQUAL T_IS_GREATER_OR_EQUAL T_IS_SMALLER_OR_EQUAL T_SR T_SL T_INSTANCEOF T_UNSET_CAST T_BOOL_CAST T_OBJECT_CAST T_ARRAY_CAST T_STRING_CAST T_DOUBLE_CAST T_INT_CAST T_DEC T_INC T_CLONE T_NEW T_EXIT T_IF T_ELSEIF T_ELSE T_ENDIF T_LNUMBER T_DNUMBER T_STRING T_STRING_VARNAME T_VARIABLE T_NUM_STRING T_INLINE_HTML T_CHARACTER T_BAD_CHARACTER T_ENCAPSED_AND_WHITESPACE T_CONSTANT_ENCAPSED_STRING T_ECHO T_DO T_WHILE T_ENDWHILE T_FOR T_ENDFOR T_FOREACH T_ENDFOREACH T_DECLARE T_ENDDECLARE T_AS T_SWITCH T_ENDSWITCH T_CASE T_DEFAULT T_BREAK T_CONTINUE T_GOTO T_FUNCTION T_CONST T_RETURN T_YIELD T_TRY T_CATCH T_FINALLY T_THROW T_USE T_INSTEADOF T_GLOBAL T_PUBLIC T_PROTECTED T_PRIVATE T_FINAL T_ABSTRACT T_STATIC T_VAR T_UNSET T_ISSET T_EMPTY T_HALT_COMPILER T_CLASS T_TRAIT T_INTERFACE T_EXTENDS T_IMPLEMENTS T_OBJECT_OPERATOR T_DOUBLE_ARROW T_LIST T_ARRAY T_CALLABLE T_CLASS_C T_TRAIT_C T_METHOD_C T_FUNC_C T_LINE T_FILE T_COMMENT T_DOC_COMMENT T_OPEN_TAG T_OPEN_TAG_WITH_ECHO T_CLOSE_TAG T_WHITESPACE T_START_HEREDOC T_END_HEREDOC T_DOLLAR_OPEN_CURLY_BRACES T_CURLY_OPEN T_PAAMAYIM_NEKUDOTAYIM T_NAMESPACE T_NS_C T_DIR T_NS_SEPARATOR T_DOUBLE_COLON contained

" tokyo_tyrant
syn keyword phpConstants RDBDEF_PORT RDBREC_INT RDBREC_DBL RDBQC_STREQ RDBQC_STRINC RDBQC_STRBW RDBQC_STREW RDBQC_STRAND RDBQC_STROR RDBQC_STROREQ RDBQC_STRRX RDBQC_NUMEQ RDBQC_NUMGT RDBQC_NUMGE RDBQC_NUMLT RDBQC_NUMLE RDBQC_NUMBT RDBQC_NUMOREQ RDBQC_NEGATE RDBQC_NOIDX RDBQCFTS_PH RDBQCFTS_AND RDBQCFTS_OR RDBQCFTS_EX RDBXOLCK_REC RDBXOLCK_GLB RDBQO_STRASC RDBQO_STRDESC RDBQO_NUMASC RDBQO_NUMDESC RDBIT_LEXICAL RDBIT_DECIMAL RDBIT_OPT RDBIT_VOID RDBIT_KEEP RDBIT_TOKEN RDBIT_QGRAM TTE_SUCCESS TTE_INVALID TTE_NOHOST TTE_REFUSED TTE_SEND TTE_RECV TTE_KEEP TTE_NOREC TTE_MISC RDBMS_UNION RDBMS_ISECT RDBMS_DIFF RDBT_RECON contained

" uuid
syn keyword phpConstants UUID_TYPE_DEFAULT UUID_TYPE_TIME UUID_TYPE_DCE UUID_TYPE_NAME UUID_TYPE_RANDOM UUID_TYPE_NULL UUID_TYPE_INVALID contained

" varnish
syn keyword phpConstants VARNISH_STATUS_SYNTAX VARNISH_STATUS_UNKNOWN VARNISH_STATUS_UNIMPL VARNISH_STATUS_TOOFEW VARNISH_STATUS_TOOMANY VARNISH_STATUS_PARAM VARNISH_STATUS_AUTH VARNISH_STATUS_OK VARNISH_STATUS_CANT VARNISH_STATUS_COMMS VARNISH_STATUS_CLOSE VARNISH_CONFIG_IDENT VARNISH_CONFIG_HOST VARNISH_CONFIG_PORT VARNISH_CONFIG_TIMEOUT VARNISH_CONFIG_SECRET VARNISH_CONFIG_COMPAT VARNISH_COMPAT_2 VARNISH_COMPAT_3 TAG_Debug TAG_Error TAG_CLI TAG_StatSess TAG_ReqEnd TAG_SessionOpen TAG_SessionClose TAG_BackendOpen TAG_BackendXID TAG_BackendReuse TAG_BackendClose TAG_HttpGarbage TAG_Backend TAG_Length TAG_FetchError TAG_RxRequest TAG_RxResponse TAG_RxStatus TAG_RxURL TAG_RxProtocol TAG_RxHeader TAG_TxRequest TAG_TxResponse TAG_TxStatus TAG_TxURL TAG_TxProtocol TAG_TxHeader TAG_ObjRequest TAG_ObjResponse TAG_ObjStatus TAG_ObjURL TAG_ObjProtocol TAG_ObjHeader TAG_LostHeader TAG_TTL TAG_Fetch_Body TAG_VCL_acl TAG_VCL_call TAG_VCL_trace TAG_VCL_return TAG_VCL_error TAG_ReqStart TAG_Hit TAG_HitPass TAG_ExpBan TAG_ExpKill TAG_WorkThread TAG_ESI_xmlerror TAG_Hash TAG_Backend_health TAG_VCL_Log TAG_Gzip contained

" wbxml
syn keyword phpConstants WBXML_VERSION_10 WBXML_VERSION_11 WBXML_VERSION_12 WBXML_VERSION_13 WBXML_LANG_UNKNOWN WBXML_LANG_WML10 WBXML_LANG_WML11 WBXML_LANG_WML12 WBXML_LANG_WML13 WBXML_LANG_WTA10 WBXML_LANG_WTAWML12 WBXML_LANG_CHANNEL11 WBXML_LANG_CHANNEL12 WBXML_LANG_SI10 WBXML_LANG_SL10 WBXML_LANG_CO10 WBXML_LANG_PROV10 WBXML_LANG_EMN10 WBXML_LANG_DRMREL10 WBXML_LANG_OTA_SETTINGS WBXML_LANG_SYNCML_SYNCML10 WBXML_LANG_SYNCML_DEVINF10 WBXML_LANG_SYNCML_METINF10 WBXML_LANG_SYNCML_SYNCML11 WBXML_LANG_SYNCML_DEVINF11 WBXML_LANG_SYNCML_METINF11 WBXML_LANG_SYNCML_SYNCML12 WBXML_LANG_SYNCML_DEVINF12 WBXML_LANG_SYNCML_METINF12 WBXML_LANG_WV_CSP11 WBXML_LANG_WV_CSP12 WBXML_LANG_AIRSYNC WBXML_GEN_XML_COMPACT WBXML_GEN_XML_INDENT WBXML_GEN_XML_CANONICAL contained

" XCache
syn keyword phpConstants XC_NULL? XC_IS_CONST XC_IS_TMP_VAR XC_IS_VAR XC_IS_UNUSED XC_IS_CV XC_IS_NULL XC_IS_LONG XC_IS_DOUBLE XC_IS_BOOL XC_IS_ARRAY XC_IS_OBJECT XC_IS_STRING XC_IS_RESOURCE XC_IS_CONSTANT XC_IS_CONSTANT_ARRAY XC_IS_UNICODE XC_NOP XC_ADD XC_SUB XC_MUL XC_DIV XC_MOD XC_SL XC_SR XC_CONCAT XC_BW_OR XC_BW_AND XC_BW_XOR XC_BW_NOT XC_BOOL_NOT XC_BOOL_XOR XC_IS_IDENTICAL XC_IS_NOT_IDENTICAL XC_IS_EQUAL XC_IS_NOT_EQUAL XC_IS_SMALLER XC_IS_SMALLER_OR_EQUAL XC_CAST XC_QM_ASSIGN XC_ASSIGN_ADD XC_ASSIGN_SUB XC_ASSIGN_MUL XC_ASSIGN_DIV XC_ASSIGN_MOD XC_ASSIGN_SL XC_ASSIGN_SR XC_ASSIGN_CONCAT XC_ASSIGN_BW_OR XC_ASSIGN_BW_AND XC_ASSIGN_BW_XOR XC_PRE_INC XC_PRE_DEC XC_POST_INC XC_POST_DEC XC_ASSIGN XC_ASSIGN_REF XC_ECHO XC_PRINT XC_JMP XC_JMPZ XC_JMPNZ XC_JMPZNZ XC_JMPZ_EX XC_JMPNZ_EX XC_CASE XC_SWITCH_FREE XC_BRK XC_CONT XC_BOOL XC_INIT_STRING XC_ADD_CHAR XC_ADD_STRING XC_ADD_VAR XC_BEGIN_SILENCE XC_END_SILENCE XC_INIT_FCALL_BY_NAME XC_DO_FCALL XC_DO_FCALL_BY_NAME XC_RETURN XC_RECV XC_RECV_INIT XC_SEND_VAL XC_SEND_VAR XC_SEND_REF XC_NEW XC_INIT_NS_FCALL_BY_NAME XC_FREE XC_INIT_ARRAY XC_ADD_ARRAY_ELEMENT XC_INCLUDE_OR_EVAL XC_UNSET_VAR XC_UNSET_DIM XC_UNSET_OBJ XC_FE_RESET XC_FE_FETCH XC_EXIT XC_FETCH_R XC_FETCH_DIM_R XC_FETCH_OBJ_R XC_FETCH_W XC_FETCH_DIM_W XC_FETCH_OBJ_W XC_FETCH_RW XC_FETCH_DIM_RW XC_FETCH_OBJ_RW XC_FETCH_IS XC_FETCH_DIM_IS XC_FETCH_OBJ_IS XC_FETCH_FUNC_ARG XC_FETCH_DIM_FUNC_ARG XC_FETCH_OBJ_FUNC_ARG XC_FETCH_UNSET XC_FETCH_DIM_UNSET XC_FETCH_OBJ_UNSET XC_FETCH_DIM_TMP_VAR XC_FETCH_CONSTANT XC_GOTO XC_EXT_STMT XC_EXT_FCALL_BEGIN XC_EXT_FCALL_END XC_EXT_NOP XC_TICKS XC_SEND_VAR_NO_REF XC_CATCH XC_THROW XC_FETCH_CLASS XC_CLONE XC_RETURN_BY_REF XC_INIT_METHOD_CALL XC_INIT_STATIC_METHOD_CALL XC_ISSET_ISEMPTY_VAR XC_ISSET_ISEMPTY_DIM_OBJ XC_UNDEF XC_PRE_INC_OBJ XC_PRE_DEC_OBJ XC_POST_INC_OBJ XC_POST_DEC_OBJ XC_ASSIGN_OBJ XC_OP_DATA XC_INSTANCEOF XC_DECLARE_CLASS XC_DECLARE_INHERITED_CLASS XC_DECLARE_FUNCTION XC_RAISE_ABSTRACT_ERROR XC_DECLARE_CONST XC_ADD_INTERFACE XC_DECLARE_INHERITED_CLASS_DELAYED XC_VERIFY_ABSTRACT_CLASS XC_ASSIGN_DIM XC_ISSET_ISEMPTY_PROP_OBJ XC_HANDLE_EXCEPTION XC_USER_OPCODE XC_JMP_SET XC_DECLARE_LAMBDA_FUNCTION XC_ADD_TRAIT XC_BIND_TRAITS XC_SEPARATE XC_QM_ASSIGN_VAR XC_JMP_SET_VAR XC_DISCARD_EXCEPTION XC_YIELD XC_GENERATOR_RETURN XC_FAST_CALL XC_FAST_RET XC_OPSPEC_STD XC_OPSPEC_UNUSED XC_OPSPEC_OPLINE XC_OPSPEC_FCALL XC_OPSPEC_INIT_FCALL XC_OPSPEC_ARG XC_OPSPEC_CAST XC_OPSPEC_FETCH XC_OPSPEC_DECLARE XC_OPSPEC_SEND XC_OPSPEC_SEND_NOREF XC_OPSPEC_FCLASS XC_OPSPEC_UCLASS XC_OPSPEC_CLASS XC_OPSPEC_FE XC_OPSPEC_IFACE XC_OPSPEC_ISSET XC_OPSPEC_BIT XC_OPSPEC_VAR XC_OPSPEC_TMP XC_OPSPEC_JMPADDR XC_OPSPEC_BRK XC_OPSPEC_CONT XC_OPSPEC_INCLUDE XC_OPSPEC_ASSIGN XC_OPSPEC_FETCHTYPE XC_SIZEOF_TEMP_VARIABLE XCACHE_VERSION XCACHE_MODULES contained

" xdebug
syn keyword phpConstants XDEBUG_TRACE_APPEND XDEBUG_TRACE_COMPUTERIZED XDEBUG_TRACE_HTML XDEBUG_CC_UNUSED XDEBUG_CC_DEAD_CODE contained

" xml
syn keyword phpConstants XML_ERROR_NONE XML_ERROR_NO_MEMORY XML_ERROR_SYNTAX XML_ERROR_NO_ELEMENTS XML_ERROR_INVALID_TOKEN XML_ERROR_UNCLOSED_TOKEN XML_ERROR_PARTIAL_CHAR XML_ERROR_TAG_MISMATCH XML_ERROR_DUPLICATE_ATTRIBUTE XML_ERROR_JUNK_AFTER_DOC_ELEMENT XML_ERROR_PARAM_ENTITY_REF XML_ERROR_UNDEFINED_ENTITY XML_ERROR_RECURSIVE_ENTITY_REF XML_ERROR_ASYNC_ENTITY XML_ERROR_BAD_CHAR_REF XML_ERROR_BINARY_ENTITY_REF XML_ERROR_ATTRIBUTE_EXTERNAL_ENTITY_REF XML_ERROR_MISPLACED_XML_PI XML_ERROR_UNKNOWN_ENCODING XML_ERROR_INCORRECT_ENCODING XML_ERROR_UNCLOSED_CDATA_SECTION XML_ERROR_EXTERNAL_ENTITY_HANDLING XML_OPTION_CASE_FOLDING XML_OPTION_TARGET_ENCODING XML_OPTION_SKIP_TAGSTART XML_OPTION_SKIP_WHITE XML_SAX_IMPL contained

" xmlreader
syn keyword phpConstants NONE ELEMENT ATTRIBUTE TEXT CDATA ENTITY_REF ENTITY PI COMMENT DOC DOC_TYPE DOC_FRAGMENT NOTATION WHITESPACE SIGNIFICANT_WHITESPACE END_ELEMENT END_ENTITY XML_DECLARATION LOADDTD DEFAULTATTRS VALIDATE SUBST_ENTITIES contained

" xsl
syn keyword phpConstants XSL_CLONE_AUTO XSL_CLONE_NEVER XSL_CLONE_ALWAYS XSL_SECPREF_NONE XSL_SECPREF_READ_FILE XSL_SECPREF_WRITE_FILE XSL_SECPREF_CREATE_DIRECTORY XSL_SECPREF_READ_NETWORK XSL_SECPREF_WRITE_NETWORK XSL_SECPREF_DEFAULT LIBXSLT_VERSION LIBXSLT_DOTTED_VERSION LIBEXSLT_VERSION LIBEXSLT_DOTTED_VERSION contained

" yaf
syn keyword phpConstants PHP_YAF_VERSION YAF_ENVIRON YAF_ERR_STARTUP_FAILED YAF_ERR_ROUTE_FAILED YAF_ERR_DISPATCH_FAILED YAF_ERR_AUTOLOAD_FAILED YAF_ERR_NOTFOUND_MODULE YAF_ERR_NOTFOUND_CONTROLLER YAF_ERR_NOTFOUND_ACTION YAF_ERR_NOTFOUND_VIEW YAF_ERR_CALL_FAILED YAF_ERR_TYPE_ERROR SCHEME_HTTP SCHEME_HTTPS DEFAULT_BODY contained

" yaml
syn keyword phpConstants YAML_ANY_SCALAR_STYLE YAML_PLAIN_SCALAR_STYLE YAML_SINGLE_QUOTED_SCALAR_STYLE YAML_DOUBLE_QUOTED_SCALAR_STYLE YAML_LITERAL_SCALAR_STYLE YAML_FOLDED_SCALAR_STYLE YAML_NULL_TAG YAML_BOOL_TAG YAML_STR_TAG YAML_INT_TAG YAML_FLOAT_TAG YAML_TIMESTAMP_TAG YAML_SEQ_TAG YAML_MAP_TAG YAML_PHP_TAG YAML_MERGE_TAG YAML_BINARY_TAG YAML_ANY_ENCODING YAML_UTF8_ENCODING YAML_UTF16LE_ENCODING YAML_UTF16BE_ENCODING YAML_ANY_BREAK YAML_CR_BREAK YAML_LN_BREAK YAML_CRLN_BREAK contained

" yar
syn keyword phpConstants PHP_YAR_VERSION YAR_OPT_PACKAGER YAR_OPT_PERSISTENT YAR_OPT_TIMEOUT YAR_OPT_CONNECT_TIMEOUT YAR_CLIENT_PROTOCOL_HTTP YAR_CLIENT_PROTOCOL_TCP YAR_CLIENT_PROTOCOL_UNIX YAR_PACKAGER_PHP YAR_PACKAGER_JSON YAR_ERR_OKEY YAR_ERR_OUTPUT YAR_ERR_TRANSPORT YAR_ERR_REQUEST YAR_ERR_PROTOCOL YAR_ERR_PACKAGER YAR_ERR_EXCEPTION contained

" yaz
syn keyword phpConstants ZOOM_EVENT_NONE ZOOM_EVENT_CONNECT ZOOM_EVENT_SEND_DATA ZOOM_EVENT_RECV_DATA ZOOM_EVENT_TIMEOUT ZOOM_EVENT_UNKNOWN ZOOM_EVENT_SEND_APDU ZOOM_EVENT_RECV_APDU ZOOM_EVENT_RECV_RECORD ZOOM_EVENT_RECV_SEARCH contained

" zip
syn keyword phpConstants CREATE EXCL CHECKCONS OVERWRITE FL_NOCASE FL_NODIR FL_COMPRESSED FL_UNCHANGED CM_DEFAULT CM_STORE CM_SHRINK CM_REDUCE_1 CM_REDUCE_2 CM_REDUCE_3 CM_REDUCE_4 CM_IMPLODE CM_DEFLATE CM_DEFLATE64 CM_PKWARE_IMPLODE CM_BZIP2 CM_LZMA CM_TERSE CM_LZ77 CM_WAVPACK CM_PPMD ER_OK ER_MULTIDISK ER_RENAME ER_CLOSE ER_SEEK ER_READ ER_WRITE ER_CRC ER_ZIPCLOSED ER_NOENT ER_EXISTS ER_OPEN ER_TMPOPEN ER_ZLIB ER_MEMORY ER_CHANGED ER_COMPNOTSUPP ER_EOF ER_INVAL ER_NOZIP ER_INTERNAL ER_INCONS ER_REMOVE ER_DELETED contained

" zlib
syn keyword phpConstants FORCE_GZIP FORCE_DEFLATE ZLIB_ENCODING_RAW ZLIB_ENCODING_GZIP ZLIB_ENCODING_DEFLATE contained

" zookeeper
syn keyword phpConstants PERM_READ PERM_WRITE PERM_CREATE PERM_DELETE PERM_ALL PERM_ADMIN EPHEMERAL SEQUENCE EXPIRED_SESSION_STATE AUTH_FAILED_STATE CONNECTING_STATE ASSOCIATING_STATE CONNECTED_STATE NOTCONNECTED_STATE CREATED_EVENT DELETED_EVENT CHANGED_EVENT CHILD_EVENT SESSION_EVENT NOTWATCHING_EVENT LOG_LEVEL_ERROR LOG_LEVEL_WARN LOG_LEVEL_INFO LOG_LEVEL_DEBUG SYSTEMERROR RUNTIMEINCONSISTENCY DATAINCONSISTENCY CONNECTIONLOSS MARSHALLINGERROR UNIMPLEMENTED OPERATIONTIMEOUT BADARGUMENTS INVALIDSTATE OK APIERROR NONODE NOAUTH BADVERSION NOCHILDRENFOREPHEMERALS NODEEXISTS NOTEMPTY SESSIONEXPIRED INVALIDCALLBACK INVALIDACL AUTHFAILED CLOSING NOTHING SESSIONMOVED contained

syn case ignore

" amqp
syn keyword phpClasses AMQPConnection AMQPChannel AMQPQueue AMQPExchange AMQPEnvelope AMQPException AMQPConnectionException AMQPChannelException AMQPQueueException AMQPExchangeException contained

" apcu
syn keyword phpFunctions apcu_cache_info apcu_clear_cache apcu_sma_info apcu_key_info apcu_store apcu_fetch apcu_delete apcu_add apcu_inc apcu_dec apcu_cas apcu_exists apcu_bin_dump apcu_bin_load apcu_bin_dumpfile apcu_bin_loadfile contained
syn keyword phpClasses APCIterator contained

" bcmath
syn keyword phpFunctions bcadd bcsub bcmul bcdiv bcmod bcpow bcsqrt bcscale bccomp bcpowmod contained
" blitz
syn keyword phpClasses blitz contained

" boxwood
syn keyword phpFunctions boxwood_new boxwood_add_text boxwood_replace_text boxwood_set_word_boundary_bytes contained
" bz2
syn keyword phpFunctions bzopen bzread bzwrite bzflush bzclose bzerrno bzerrstr bzerror bzcompress bzdecompress contained
" calendar
syn keyword phpFunctions jdtogregorian gregoriantojd jdtojulian juliantojd jdtojewish jewishtojd jdtofrench frenchtojd jddayofweek jdmonthname easter_date easter_days unixtojd jdtounix cal_to_jd cal_from_jd cal_days_in_month cal_info contained
" chdb
syn keyword phpFunctions chdb_create contained
syn keyword phpClasses chdb contained

" Core
syn keyword phpFunctions zend_version func_num_args func_get_arg func_get_args strlen strcmp strncmp strcasecmp strncasecmp each error_reporting define defined get_class get_called_class get_parent_class method_exists property_exists class_exists interface_exists trait_exists function_exists class_alias get_included_files get_required_files is_subclass_of is_a get_class_vars get_object_vars get_class_methods trigger_error user_error set_error_handler restore_error_handler set_exception_handler restore_exception_handler get_declared_classes get_declared_traits get_declared_interfaces get_defined_functions get_defined_vars create_function get_resource_type get_loaded_extensions extension_loaded get_extension_funcs get_defined_constants debug_backtrace debug_print_backtrace gc_collect_cycles gc_enabled gc_enable gc_disable contained
syn keyword phpClasses stdClass Traversable IteratorAggregate Iterator ArrayAccess Serializable Exception ErrorException Closure Generator contained

" couchbase
syn keyword phpFunctions couchbase_connect couchbase_add couchbase_set couchbase_set_multi couchbase_replace couchbase_prepend couchbase_append couchbase_cas couchbase_get couchbase_get_multi couchbase_get_delayed couchbase_get_and_lock couchbase_get_and_lock_multi couchbase_get_and_touch couchbase_get_and_touch_multi couchbase_unlock couchbase_touch couchbase_touch_multi couchbase_fetch couchbase_fetch_all couchbase_view couchbase_view_gen_query couchbase_increment couchbase_decrement couchbase_get_stats couchbase_delete couchbase_flush couchbase_get_result_code couchbase_get_result_message couchbase_set_option couchbase_get_option couchbase_get_servers couchbase_get_num_replicas couchbase_get_version couchbase_get_client_version couchbase_observe couchbase_observe_multi couchbase_key_durability couchbase_key_durability_multi couchbase_get_design_doc couchbase_set_design_doc couchbase_delete_design_doc couchbase_list_design_docs couchbase_get_timeout couchbase_set_timeout contained
syn keyword phpClasses Couchbase CouchbaseClusterManager CouchbaseException CouchbaseIllegalKeyException CouchbaseNoSuchKeyException CouchbaseAuthenticationException CouchbaseLibcouchbaseException CouchbaseServerException CouchbaseKeyMutatedException CouchbaseTimeoutException CouchbaseNotEnoughNodesException CouchbaseIllegalOptionException CouchbaseIllegalValueException CouchbaseIllegalArgumentsException CouchbaseNotSupportedException contained

" crypto
syn keyword phpClasses Crypto\Algorithm Crypto\AlgorithmException Crypto\Cipher Crypto\Hash Crypto\HMAC Crypto\Base64 Crypto\Base64Exception Crypto\Rand Crypto\RandException contained

" ctype
syn keyword phpFunctions ctype_alnum ctype_alpha ctype_cntrl ctype_digit ctype_lower ctype_graph ctype_print ctype_punct ctype_space ctype_upper ctype_xdigit contained
" curl
syn keyword phpFunctions curl_init curl_copy_handle curl_version curl_setopt curl_setopt_array curl_exec curl_getinfo curl_error curl_errno curl_close curl_strerror curl_multi_strerror curl_reset curl_escape curl_unescape curl_pause curl_multi_init curl_multi_add_handle curl_multi_remove_handle curl_multi_select curl_multi_exec curl_multi_getcontent curl_multi_info_read curl_multi_close curl_multi_setopt curl_share_init curl_share_close curl_share_setopt curl_file_create contained
syn keyword phpClasses CURLFile contained

" date
syn keyword phpFunctions strtotime date idate gmdate mktime gmmktime checkdate strftime gmstrftime time localtime getdate date_create date_create_immutable date_create_from_format date_create_immutable_from_format date_parse date_parse_from_format date_get_last_errors date_format date_modify date_add date_sub date_timezone_get date_timezone_set date_offset_get date_diff date_time_set date_date_set date_isodate_set date_timestamp_set date_timestamp_get timezone_open timezone_name_get timezone_name_from_abbr timezone_offset_get timezone_transitions_get timezone_location_get timezone_identifiers_list timezone_abbreviations_list timezone_version_get date_interval_create_from_date_string date_interval_format date_default_timezone_set date_default_timezone_get date_sunrise date_sunset date_sun_info contained
syn keyword phpClasses DateTimeInterface DateTime DateTimeImmutable DateTimeZone DateInterval DatePeriod contained

" dba
syn keyword phpFunctions dba_open dba_popen dba_close dba_delete dba_exists dba_fetch dba_insert dba_replace dba_firstkey dba_nextkey dba_optimize dba_sync dba_handlers dba_list dba_key_split contained
" dbase
syn keyword phpFunctions dbase_open dbase_create dbase_close dbase_numrecords dbase_numfields dbase_add_record dbase_replace_record dbase_get_record dbase_get_record_with_names dbase_delete_record dbase_pack dbase_get_header_info contained
" dmtx
syn keyword phpClasses dmtxException dmtx dmtxRead dmtxWrite contained

" dom
syn keyword phpFunctions dom_import_simplexml contained
syn keyword phpClasses DOMException DOMStringList DOMNameList DOMImplementationList DOMImplementationSource DOMImplementation DOMNode DOMNameSpaceNode DOMDocumentFragment DOMDocument DOMNodeList DOMNamedNodeMap DOMCharacterData DOMAttr DOMElement DOMText DOMComment DOMTypeinfo DOMUserDataHandler DOMDomError DOMErrorHandler DOMLocator DOMConfiguration DOMCdataSection DOMDocumentType DOMNotation DOMEntity DOMEntityReference DOMProcessingInstruction DOMStringExtend DOMXPath contained

" ereg
syn keyword phpFunctions ereg ereg_replace eregi eregi_replace split spliti sql_regcase contained
" ev
syn keyword phpClasses Ev EvLoop EvWatcher EvIo EvTimer EvPeriodic EvSignal EvChild EvStat EvIdle EvCheck EvPrepare EvEmbed EvFork contained

" exif
syn keyword phpFunctions exif_read_data read_exif_data exif_tagname exif_thumbnail exif_imagetype contained
" fileinfo
syn keyword phpFunctions finfo_open finfo_close finfo_set_flags finfo_file finfo_buffer mime_content_type contained
syn keyword phpClasses finfo contained

" filter
syn keyword phpFunctions filter_input filter_var filter_input_array filter_var_array filter_list filter_has_var filter_id contained
" ftp
syn keyword phpFunctions ftp_connect ftp_ssl_connect ftp_login ftp_pwd ftp_cdup ftp_chdir ftp_exec ftp_raw ftp_mkdir ftp_rmdir ftp_chmod ftp_alloc ftp_nlist ftp_rawlist ftp_systype ftp_pasv ftp_get ftp_fget ftp_put ftp_fput ftp_size ftp_mdtm ftp_rename ftp_delete ftp_site ftp_close ftp_set_option ftp_get_option ftp_nb_fget ftp_nb_get ftp_nb_continue ftp_nb_put ftp_nb_fput ftp_quit contained
" gearman
syn keyword phpFunctions gearman_version gearman_bugreport gearman_verbose_name gearman_client_return_code gearman_client_create gearman_client_clone gearman_client_error gearman_client_errno gearman_client_options gearman_client_set_options gearman_client_add_options gearman_client_remove_options gearman_client_timeout gearman_client_set_timeout gearman_client_context gearman_client_set_context gearman_client_add_server gearman_client_add_servers gearman_client_wait gearman_client_do gearman_client_do_normal gearman_client_do_high gearman_client_do_low gearman_client_do_job_handle gearman_client_do_status gearman_client_do_background gearman_client_do_high_background gearman_client_do_low_background gearman_client_job_status gearman_client_job_status_by_unique_key gearman_client_echo gearman_client_ping gearman_client_add_task gearman_client_add_task_high gearman_client_add_task_low gearman_client_add_task_background gearman_client_add_task_high_background gearman_client_add_task_low_background gearman_client_add_task_status gearman_client_set_workload_fn gearman_client_set_created_fn gearman_client_set_data_fn gearman_client_set_warning_fn gearman_client_set_status_fn gearman_client_set_complete_fn gearman_client_set_exception_fn gearman_client_set_fail_fn gearman_client_clear_fn gearman_client_run_tasks gearman_task_return_code gearman_task_function_name gearman_task_unique gearman_task_job_handle gearman_task_is_known gearman_task_is_running gearman_task_numerator gearman_task_denominator gearman_task_send_workload gearman_task_data gearman_task_data_size gearman_task_recv_data gearman_worker_return_code gearman_worker_create gearman_worker_clone gearman_worker_error gearman_worker_errno gearman_worker_options gearman_worker_set_options gearman_worker_add_options gearman_worker_remove_options gearman_worker_timeout gearman_worker_set_timeout gearman_worker_set_id gearman_worker_add_server gearman_worker_add_servers gearman_worker_wait gearman_worker_register gearman_worker_unregister gearman_worker_unregister_all gearman_worker_grab_job gearman_worker_add_function gearman_worker_work gearman_worker_echo gearman_job_return_code gearman_job_send_data gearman_job_send_warning gearman_job_send_status gearman_job_send_complete gearman_job_send_exception gearman_job_send_fail gearman_job_handle gearman_job_function_name gearman_job_unique gearman_job_workload gearman_job_workload_size contained
syn keyword phpClasses GearmanClient GearmanTask GearmanWorker GearmanJob GearmanException contained

" gd
syn keyword phpFunctions gd_info imagearc imageellipse imagechar imagecharup imagecolorat imagecolorallocate imagepalettecopy imagecreatefromstring imagecolorclosest imagecolorclosesthwb imagecolordeallocate imagecolorresolve imagecolorexact imagecolorset imagecolortransparent imagecolorstotal imagecolorsforindex imagecopy imagecopymerge imagecopymergegray imagecopyresized imagecreate imagecreatetruecolor imageistruecolor imagetruecolortopalette imagepalettetotruecolor imagesetthickness imagefilledarc imagefilledellipse imagealphablending imagesavealpha imagecolorallocatealpha imagecolorresolvealpha imagecolorclosestalpha imagecolorexactalpha imagecopyresampled imagerotate imageflip imageantialias imagecrop imagecropauto imagescale imageaffine imageaffinematrixconcat imageaffinematrixget imagesetinterpolation imagesettile imagesetbrush imagesetstyle imagecreatefrompng imagecreatefromgif imagecreatefromjpeg imagecreatefromwbmp imagecreatefromxbm imagecreatefromgd imagecreatefromgd2 imagecreatefromgd2part imagepng imagegif imagejpeg imagewbmp imagegd imagegd2 imagedestroy imagegammacorrect imagefill imagefilledpolygon imagefilledrectangle imagefilltoborder imagefontwidth imagefontheight imageinterlace imageline imageloadfont imagepolygon imagerectangle imagesetpixel imagestring imagestringup imagesx imagesy imagedashedline imagettfbbox imagettftext imageftbbox imagefttext imagetypes jpeg2wbmp png2wbmp image2wbmp imagelayereffect imagexbm imagecolormatch imagefilter imageconvolution contained
" geoip
syn keyword phpFunctions geoip_database_info geoip_country_code_by_name geoip_country_code3_by_name geoip_country_name_by_name geoip_continent_code_by_name geoip_org_by_name geoip_record_by_name geoip_id_by_name geoip_region_by_name geoip_isp_by_name geoip_db_avail geoip_db_get_all_info geoip_db_filename geoip_region_name_by_code geoip_time_zone_by_country_and_region contained
" gettext
syn keyword phpFunctions textdomain gettext _ dgettext dcgettext bindtextdomain ngettext dngettext dcngettext bind_textdomain_codeset contained
" gmagick
syn keyword phpClasses GmagickException GmagickPixelException Gmagick GmagickDraw GmagickPixel contained

" graphdat
syn keyword phpFunctions graphdat_begin graphdat_end contained
" hash
syn keyword phpFunctions hash hash_file hash_hmac hash_hmac_file hash_init hash_update hash_update_stream hash_update_file hash_final hash_copy hash_algos hash_pbkdf2 mhash_keygen_s2k mhash_get_block_size mhash_get_hash_name mhash_count mhash contained
" http
syn keyword phpClasses http\Exception http\Exception\RuntimeException http\Exception\UnexpectedValueException http\Exception\BadMethodCallException http\Exception\InvalidArgumentException http\Exception\BadHeaderException http\Exception\BadUrlException http\Exception\BadMessageException http\Exception\BadConversionException http\Exception\BadQueryStringException http\Cookie http\Encoding\Stream http\Encoding\Stream\Deflate http\Encoding\Stream\Inflate http\Encoding\Stream\Dechunk http\Header http\Message http\Message\Body http\QueryString http\Client http\Client\Request http\Client\Response http\Url http\Env http\Env\Request http\Env\Response http\Params contained

" iconv
syn keyword phpFunctions iconv iconv_get_encoding iconv_set_encoding iconv_strlen iconv_substr iconv_strpos iconv_strrpos iconv_mime_encode iconv_mime_decode iconv_mime_decode_headers contained
" igbinary
syn keyword phpFunctions igbinary_serialize igbinary_unserialize contained
" imagick
syn keyword phpClasses ImagickException ImagickDrawException ImagickPixelIteratorException ImagickPixelException Imagick ImagickDraw ImagickPixelIterator ImagickPixel contained

" intl
syn keyword phpFunctions collator_create collator_compare collator_get_attribute collator_set_attribute collator_get_strength collator_set_strength collator_sort collator_sort_with_sort_keys collator_asort collator_get_locale collator_get_error_code collator_get_error_message collator_get_sort_key numfmt_create numfmt_format numfmt_parse numfmt_format_currency numfmt_parse_currency numfmt_set_attribute numfmt_get_attribute numfmt_set_text_attribute numfmt_get_text_attribute numfmt_set_symbol numfmt_get_symbol numfmt_set_pattern numfmt_get_pattern numfmt_get_locale numfmt_get_error_code numfmt_get_error_message normalizer_normalize normalizer_is_normalized locale_get_default locale_set_default locale_get_primary_language locale_get_script locale_get_region locale_get_keywords locale_get_display_script locale_get_display_region locale_get_display_name locale_get_display_language locale_get_display_variant locale_compose locale_parse locale_get_all_variants locale_filter_matches locale_canonicalize locale_lookup locale_accept_from_http msgfmt_create msgfmt_format msgfmt_format_message msgfmt_parse msgfmt_parse_message msgfmt_set_pattern msgfmt_get_pattern msgfmt_get_locale msgfmt_get_error_code msgfmt_get_error_message datefmt_create datefmt_get_datetype datefmt_get_timetype datefmt_get_calendar datefmt_get_calendar_object datefmt_set_calendar datefmt_get_locale datefmt_get_timezone_id datefmt_set_timezone_id datefmt_get_timezone datefmt_set_timezone datefmt_get_pattern datefmt_set_pattern datefmt_is_lenient datefmt_set_lenient datefmt_format datefmt_format_object datefmt_parse datefmt_localtime datefmt_get_error_code datefmt_get_error_message grapheme_strlen grapheme_strpos grapheme_stripos grapheme_strrpos grapheme_strripos grapheme_substr grapheme_strstr grapheme_stristr grapheme_extract idn_to_ascii idn_to_utf8 resourcebundle_create resourcebundle_get resourcebundle_count resourcebundle_locales resourcebundle_get_error_code resourcebundle_get_error_message transliterator_create transliterator_create_from_rules transliterator_list_ids transliterator_create_inverse transliterator_transliterate transliterator_get_error_code transliterator_get_error_message intltz_create_time_zone intltz_from_date_time_zone intltz_create_default intltz_get_id intltz_get_gmt intltz_get_unknown intltz_create_enumeration intltz_count_equivalent_ids intltz_create_time_zone_id_enumeration intltz_get_canonical_id intltz_get_region intltz_get_tz_data_version intltz_get_equivalent_id intltz_use_daylight_time intltz_get_offset intltz_get_raw_offset intltz_has_same_rules intltz_get_display_name intltz_get_dst_savings intltz_to_date_time_zone intltz_get_error_code intltz_get_error_message intlcal_create_instance intlcal_get_keyword_values_for_locale intlcal_get_now intlcal_get_available_locales intlcal_get intlcal_get_time intlcal_set_time intlcal_add intlcal_set_time_zone intlcal_after intlcal_before intlcal_set intlcal_roll intlcal_clear intlcal_field_difference intlcal_get_actual_maximum intlcal_get_actual_minimum intlcal_get_day_of_week_type intlcal_get_first_day_of_week intlcal_get_greatest_minimum intlcal_get_least_maximum intlcal_get_locale intlcal_get_maximum intlcal_get_minimal_days_in_first_week intlcal_get_minimum intlcal_get_time_zone intlcal_get_type intlcal_get_weekend_transition intlcal_in_daylight_time intlcal_is_equivalent_to intlcal_is_lenient intlcal_is_set intlcal_is_weekend intlcal_set_first_day_of_week intlcal_set_lenient intlcal_set_minimal_days_in_first_week intlcal_equals intlcal_from_date_time intlcal_to_date_time intlcal_get_repeated_wall_time_option intlcal_get_skipped_wall_time_option intlcal_set_repeated_wall_time_option intlcal_set_skipped_wall_time_option intlcal_get_error_code intlcal_get_error_message intlgregcal_create_instance intlgregcal_set_gregorian_change intlgregcal_get_gregorian_change intlgregcal_is_leap_year intl_get_error_code intl_get_error_message intl_is_failure intl_error_name contained
syn keyword phpClasses Collator NumberFormatter Normalizer Locale MessageFormatter IntlDateFormatter ResourceBundle Transliterator IntlTimeZone IntlCalendar IntlGregorianCalendar Spoofchecker IntlException IntlIterator IntlBreakIterator IntlRuleBasedBreakIterator IntlCodePointBreakIterator IntlPartsIterator UConverter contained

" jsmin
syn keyword phpFunctions jsmin jsmin_last_error jsmin_last_error_msg contained
" json
syn keyword phpFunctions json_encode json_decode json_last_error json_last_error_msg contained
syn keyword phpClasses JsonSerializable contained

" judy
syn keyword phpFunctions judy_version judy_type contained
syn keyword phpClasses Judy contained

" ldap
syn keyword phpFunctions ldap_connect ldap_close ldap_bind ldap_sasl_bind ldap_unbind ldap_read ldap_list ldap_search ldap_free_result ldap_count_entries ldap_first_entry ldap_next_entry ldap_get_entries ldap_first_attribute ldap_next_attribute ldap_get_attributes ldap_get_values ldap_get_values_len ldap_get_dn ldap_explode_dn ldap_dn2ufn ldap_add ldap_delete ldap_modify_batch ldap_modify ldap_mod_add ldap_mod_replace ldap_mod_del ldap_errno ldap_err2str ldap_error ldap_compare ldap_sort ldap_rename ldap_get_option ldap_set_option ldap_first_reference ldap_next_reference ldap_parse_reference ldap_parse_result ldap_start_tls ldap_set_rebind_proc ldap_control_paged_result ldap_control_paged_result_response contained
" leveldb
syn keyword phpClasses LevelDB LevelDBWriteBatch LevelDBIterator LevelDBSnapshot LevelDBException contained

" libevent
syn keyword phpFunctions event_base_new event_base_free event_base_loop event_base_loopbreak event_base_loopexit event_base_set event_base_priority_init event_new event_free event_add event_set event_del event_priority_set event_buffer_new event_buffer_free event_buffer_base_set event_buffer_priority_set event_buffer_write event_buffer_read event_buffer_enable event_buffer_disable event_buffer_timeout_set event_buffer_watermark_set event_buffer_fd_set event_buffer_set_callback event_timer_new event_timer_set event_timer_pending event_timer_add event_timer_del contained
" libvirt
syn keyword phpFunctions libvirt_get_last_error libvirt_connect libvirt_connect_get_uri libvirt_connect_get_hostname libvirt_connect_get_capabilities libvirt_connect_get_emulator libvirt_connect_get_information libvirt_connect_get_hypervisor libvirt_connect_get_sysinfo libvirt_connect_get_maxvcpus libvirt_connect_get_encrypted libvirt_connect_get_secure libvirt_domain_new libvirt_domain_new_get_vnc libvirt_domain_get_counts libvirt_domain_lookup_by_name libvirt_domain_get_xml_desc libvirt_domain_get_disk_devices libvirt_domain_get_interface_devices libvirt_domain_change_vcpus libvirt_domain_change_memory libvirt_domain_change_boot_devices libvirt_domain_disk_add libvirt_domain_disk_remove libvirt_domain_nic_add libvirt_domain_nic_remove libvirt_domain_get_info libvirt_domain_get_name libvirt_domain_get_uuid libvirt_domain_get_uuid_string libvirt_domain_get_id libvirt_domain_lookup_by_id libvirt_domain_lookup_by_uuid libvirt_domain_lookup_by_uuid_string libvirt_domain_destroy libvirt_domain_create libvirt_domain_resume libvirt_domain_core_dump libvirt_domain_shutdown libvirt_domain_suspend libvirt_domain_managedsave libvirt_domain_undefine libvirt_domain_reboot libvirt_domain_define_xml libvirt_domain_create_xml libvirt_domain_memory_peek libvirt_domain_memory_stats libvirt_domain_block_stats libvirt_domain_interface_stats libvirt_domain_get_connect libvirt_domain_migrate libvirt_domain_migrate_to_uri libvirt_domain_migrate_to_uri2 libvirt_domain_get_job_info libvirt_domain_xml_xpath libvirt_domain_get_block_info libvirt_domain_get_network_info libvirt_domain_get_autostart libvirt_domain_set_autostart libvirt_domain_is_active libvirt_domain_get_next_dev_ids libvirt_domain_get_screenshot libvirt_domain_get_screenshot_api libvirt_domain_get_screen_dimensions libvirt_domain_send_keys libvirt_domain_send_pointer_event libvirt_domain_update_device libvirt_domain_has_current_snapshot libvirt_domain_snapshot_create libvirt_domain_snapshot_get_xml libvirt_domain_snapshot_revert libvirt_domain_snapshot_delete libvirt_domain_snapshot_lookup_by_name libvirt_storagepool_lookup_by_name libvirt_storagepool_lookup_by_volume libvirt_storagepool_get_info libvirt_storagevolume_lookup_by_name libvirt_storagevolume_lookup_by_path libvirt_storagevolume_get_name libvirt_storagevolume_get_path libvirt_storagevolume_get_info libvirt_storagevolume_get_xml_desc libvirt_storagevolume_create_xml libvirt_storagevolume_create_xml_from libvirt_storagevolume_delete libvirt_storagepool_get_uuid_string libvirt_storagepool_get_name libvirt_storagepool_lookup_by_uuid_string libvirt_storagepool_get_xml_desc libvirt_storagepool_define_xml libvirt_storagepool_undefine libvirt_storagepool_create libvirt_storagepool_destroy libvirt_storagepool_is_active libvirt_storagepool_get_volume_count libvirt_storagepool_refresh libvirt_storagepool_set_autostart libvirt_storagepool_get_autostart libvirt_storagepool_build libvirt_storagepool_delete libvirt_network_define_xml libvirt_network_undefine libvirt_network_get libvirt_network_get_xml_desc libvirt_network_get_bridge libvirt_network_get_information libvirt_network_get_active libvirt_network_set_active libvirt_node_get_info libvirt_node_get_cpu_stats libvirt_node_get_cpu_stats_for_each_cpu libvirt_node_get_mem_stats libvirt_nodedev_get libvirt_nodedev_capabilities libvirt_nodedev_get_xml_desc libvirt_nodedev_get_information libvirt_list_domains libvirt_list_domain_snapshots libvirt_list_domain_resources libvirt_list_nodedevs libvirt_list_networks libvirt_list_storagepools libvirt_list_active_storagepools libvirt_list_inactive_storagepools libvirt_storagepool_list_volumes libvirt_list_active_domains libvirt_list_active_domain_ids libvirt_list_inactive_domains libvirt_version libvirt_check_version libvirt_has_feature libvirt_get_iso_images libvirt_image_create libvirt_image_remove libvirt_logfile_set libvirt_print_binding_resources contained
" libxml
syn keyword phpFunctions libxml_set_streams_context libxml_use_internal_errors libxml_get_last_error libxml_clear_errors libxml_get_errors libxml_disable_entity_loader libxml_set_external_entity_loader contained
syn keyword phpClasses LibXMLError contained

" lzf
syn keyword phpFunctions lzf_compress lzf_decompress lzf_optimized_for contained
" mailparse
syn keyword phpFunctions mailparse_msg_parse_file mailparse_msg_get_part mailparse_msg_get_structure mailparse_msg_get_part_data mailparse_msg_extract_part mailparse_msg_extract_part_file mailparse_msg_extract_whole_part_file mailparse_msg_create mailparse_msg_free mailparse_msg_parse mailparse_rfc822_parse_addresses mailparse_determine_best_xfer_encoding mailparse_stream_encode mailparse_uudecode_all mailparse_test contained
syn keyword phpClasses mimemessage contained

" mbstring
syn keyword phpFunctions mb_convert_case mb_strtoupper mb_strtolower mb_language mb_internal_encoding mb_http_input mb_http_output mb_detect_order mb_substitute_character mb_parse_str mb_output_handler mb_preferred_mime_name mb_strlen mb_strpos mb_strrpos mb_stripos mb_strripos mb_strstr mb_strrchr mb_stristr mb_strrichr mb_substr_count mb_substr mb_strcut mb_strwidth mb_strimwidth mb_convert_encoding mb_detect_encoding mb_list_encodings mb_encoding_aliases mb_convert_kana mb_encode_mimeheader mb_decode_mimeheader mb_convert_variables mb_encode_numericentity mb_decode_numericentity mb_send_mail mb_get_info mb_check_encoding mb_regex_encoding mb_regex_set_options mb_ereg mb_eregi mb_ereg_replace mb_eregi_replace mb_ereg_replace_callback mb_split mb_ereg_match mb_ereg_search mb_ereg_search_pos mb_ereg_search_regs mb_ereg_search_init mb_ereg_search_getregs mb_ereg_search_getpos mb_ereg_search_setpos mbregex_encoding mbereg mberegi mbereg_replace mberegi_replace mbsplit mbereg_match mbereg_search mbereg_search_pos mbereg_search_regs mbereg_search_init mbereg_search_getregs mbereg_search_getpos mbereg_search_setpos contained
" mcrypt
syn keyword phpFunctions mcrypt_ecb mcrypt_cbc mcrypt_cfb mcrypt_ofb mcrypt_get_key_size mcrypt_get_block_size mcrypt_get_cipher_name mcrypt_create_iv mcrypt_list_algorithms mcrypt_list_modes mcrypt_get_iv_size mcrypt_encrypt mcrypt_decrypt mcrypt_module_open mcrypt_generic_init mcrypt_generic mdecrypt_generic mcrypt_generic_end mcrypt_generic_deinit mcrypt_enc_self_test mcrypt_enc_is_block_algorithm_mode mcrypt_enc_is_block_algorithm mcrypt_enc_is_block_mode mcrypt_enc_get_block_size mcrypt_enc_get_key_size mcrypt_enc_get_supported_key_sizes mcrypt_enc_get_iv_size mcrypt_enc_get_algorithms_name mcrypt_enc_get_modes_name mcrypt_module_self_test mcrypt_module_is_block_algorithm_mode mcrypt_module_is_block_algorithm mcrypt_module_is_block_mode mcrypt_module_get_algo_block_size mcrypt_module_get_algo_key_size mcrypt_module_get_supported_key_sizes mcrypt_module_close contained
" memcache
syn keyword phpFunctions memcache_connect memcache_pconnect memcache_add_server memcache_set_server_params memcache_get_server_status memcache_get_version memcache_add memcache_set memcache_replace memcache_get memcache_delete memcache_debug memcache_get_stats memcache_get_extended_stats memcache_set_compress_threshold memcache_increment memcache_decrement memcache_close memcache_flush memcache_setoptimeout contained
syn keyword phpClasses Memcache contained

" memcached
syn keyword phpClasses Memcached MemcachedException contained

" mhash
" mongo
syn keyword phpFunctions bson_encode bson_decode contained
syn keyword phpClasses MongoClient Mongo MongoDB MongoCollection MongoCursor MongoGridFS MongoGridFSFile MongoGridFSCursor MongoId MongoCode MongoRegex MongoDate MongoBinData MongoDBRef MongoException MongoConnectionException MongoCursorException MongoCursorTimeoutException MongoGridFSException MongoResultException MongoTimestamp MongoInt32 MongoInt64 MongoLog MongoPool MongoMaxKey MongoMinKey contained

" mosquitto
syn keyword phpClasses Mosquitto\Client Mosquitto\Exception Mosquitto\Message contained

" msgpack
syn keyword phpFunctions msgpack_serialize msgpack_unserialize msgpack_pack msgpack_unpack contained
syn keyword phpClasses MessagePack MessagePackUnpacker contained

" mysql
syn keyword phpFunctions mysql_connect mysql_pconnect mysql_close mysql_select_db mysql_query mysql_unbuffered_query mysql_db_query mysql_list_dbs mysql_list_tables mysql_list_fields mysql_list_processes mysql_error mysql_errno mysql_affected_rows mysql_insert_id mysql_result mysql_num_rows mysql_num_fields mysql_fetch_row mysql_fetch_array mysql_fetch_assoc mysql_fetch_object mysql_data_seek mysql_fetch_lengths mysql_fetch_field mysql_field_seek mysql_free_result mysql_field_name mysql_field_table mysql_field_len mysql_field_type mysql_field_flags mysql_escape_string mysql_real_escape_string mysql_stat mysql_thread_id mysql_client_encoding mysql_ping mysql_get_client_info mysql_get_host_info mysql_get_proto_info mysql_get_server_info mysql_info mysql_set_charset mysql mysql_fieldname mysql_fieldtable mysql_fieldlen mysql_fieldtype mysql_fieldflags mysql_selectdb mysql_freeresult mysql_numfields mysql_numrows mysql_listdbs mysql_listtables mysql_listfields mysql_db_name mysql_dbname mysql_tablename mysql_table_name contained
" mysqli
syn keyword phpFunctions mysqli_affected_rows mysqli_autocommit mysqli_begin_transaction mysqli_change_user mysqli_character_set_name mysqli_close mysqli_commit mysqli_connect mysqli_connect_errno mysqli_connect_error mysqli_data_seek mysqli_dump_debug_info mysqli_debug mysqli_errno mysqli_error mysqli_error_list mysqli_stmt_execute mysqli_execute mysqli_fetch_field mysqli_fetch_fields mysqli_fetch_field_direct mysqli_fetch_lengths mysqli_fetch_all mysqli_fetch_array mysqli_fetch_assoc mysqli_fetch_object mysqli_fetch_row mysqli_field_count mysqli_field_seek mysqli_field_tell mysqli_free_result mysqli_get_connection_stats mysqli_get_client_stats mysqli_get_charset mysqli_get_client_info mysqli_get_client_version mysqli_get_host_info mysqli_get_proto_info mysqli_get_server_info mysqli_get_server_version mysqli_get_warnings mysqli_init mysqli_info mysqli_insert_id mysqli_kill mysqli_more_results mysqli_multi_query mysqli_next_result mysqli_num_fields mysqli_num_rows mysqli_options mysqli_ping mysqli_poll mysqli_prepare mysqli_report mysqli_query mysqli_real_connect mysqli_real_escape_string mysqli_real_query mysqli_reap_async_query mysqli_release_savepoint mysqli_rollback mysqli_savepoint mysqli_select_db mysqli_set_charset mysqli_stmt_affected_rows mysqli_stmt_attr_get mysqli_stmt_attr_set mysqli_stmt_bind_param mysqli_stmt_bind_result mysqli_stmt_close mysqli_stmt_data_seek mysqli_stmt_errno mysqli_stmt_error mysqli_stmt_error_list mysqli_stmt_fetch mysqli_stmt_field_count mysqli_stmt_free_result mysqli_stmt_get_result mysqli_stmt_get_warnings mysqli_stmt_init mysqli_stmt_insert_id mysqli_stmt_more_results mysqli_stmt_next_result mysqli_stmt_num_rows mysqli_stmt_param_count mysqli_stmt_prepare mysqli_stmt_reset mysqli_stmt_result_metadata mysqli_stmt_send_long_data mysqli_stmt_store_result mysqli_stmt_sqlstate mysqli_sqlstate mysqli_ssl_set mysqli_stat mysqli_store_result mysqli_thread_id mysqli_thread_safe mysqli_use_result mysqli_warning_count mysqli_refresh mysqli_escape_string mysqli_set_opt contained
syn keyword phpClasses mysqli_sql_exception mysqli_driver mysqli mysqli_warning mysqli_result mysqli_stmt contained

" mysqlnd_ms
syn keyword phpFunctions mysqlnd_ms_match_wild mysqlnd_ms_query_is_select mysqlnd_ms_get_stats mysqlnd_ms_get_last_used_connection mysqlnd_ms_get_last_gtid mysqlnd_ms_set_qos contained
" OAuth
syn keyword phpFunctions oauth_urlencode oauth_get_sbs contained
syn keyword phpClasses OAuth OAuthException OAuthProvider contained

" odbc
syn keyword phpFunctions odbc_autocommit odbc_binmode odbc_close odbc_close_all odbc_columns odbc_commit odbc_connect odbc_cursor odbc_data_source odbc_execute odbc_error odbc_errormsg odbc_exec odbc_fetch_array odbc_fetch_object odbc_fetch_row odbc_fetch_into odbc_field_len odbc_field_scale odbc_field_name odbc_field_type odbc_field_num odbc_free_result odbc_gettypeinfo odbc_longreadlen odbc_next_result odbc_num_fields odbc_num_rows odbc_pconnect odbc_prepare odbc_result odbc_result_all odbc_rollback odbc_setoption odbc_specialcolumns odbc_statistics odbc_tables odbc_primarykeys odbc_columnprivileges odbc_tableprivileges odbc_foreignkeys odbc_procedures odbc_procedurecolumns odbc_do odbc_field_precision contained
" openssl
syn keyword phpFunctions openssl_pkey_free openssl_pkey_new openssl_pkey_export openssl_pkey_export_to_file openssl_pkey_get_private openssl_pkey_get_public openssl_pkey_get_details openssl_free_key openssl_get_privatekey openssl_get_publickey openssl_x509_read openssl_x509_free openssl_x509_parse openssl_x509_checkpurpose openssl_x509_check_private_key openssl_x509_export openssl_x509_export_to_file openssl_pkcs12_export openssl_pkcs12_export_to_file openssl_pkcs12_read openssl_csr_new openssl_csr_export openssl_csr_export_to_file openssl_csr_sign openssl_csr_get_subject openssl_csr_get_public_key openssl_digest openssl_encrypt openssl_decrypt openssl_cipher_iv_length openssl_sign openssl_verify openssl_seal openssl_open openssl_pkcs7_verify openssl_pkcs7_decrypt openssl_pkcs7_sign openssl_pkcs7_encrypt openssl_private_encrypt openssl_private_decrypt openssl_public_encrypt openssl_public_decrypt openssl_get_md_methods openssl_get_cipher_methods openssl_dh_compute_key openssl_random_pseudo_bytes openssl_error_string contained
" pcre
syn keyword phpFunctions preg_match preg_match_all preg_replace preg_replace_callback preg_filter preg_split preg_quote preg_grep preg_last_error contained
" PDO
syn keyword phpFunctions pdo_drivers contained
syn keyword phpClasses PDOException PDO PDOStatement PDORow contained

" pgsql
syn keyword phpFunctions pg_connect pg_pconnect pg_close pg_connection_status pg_connection_busy pg_connection_reset pg_host pg_dbname pg_port pg_tty pg_options pg_version pg_ping pg_parameter_status pg_transaction_status pg_query pg_query_params pg_prepare pg_execute pg_send_query pg_send_query_params pg_send_prepare pg_send_execute pg_cancel_query pg_fetch_result pg_fetch_row pg_fetch_assoc pg_fetch_array pg_fetch_object pg_fetch_all pg_fetch_all_columns pg_affected_rows pg_get_result pg_result_seek pg_result_status pg_free_result pg_last_oid pg_num_rows pg_num_fields pg_field_name pg_field_num pg_field_size pg_field_type pg_field_type_oid pg_field_prtlen pg_field_is_null pg_field_table pg_get_notify pg_get_pid pg_result_error pg_result_error_field pg_last_error pg_last_notice pg_put_line pg_end_copy pg_copy_to pg_copy_from pg_trace pg_untrace pg_lo_create pg_lo_unlink pg_lo_open pg_lo_close pg_lo_read pg_lo_write pg_lo_read_all pg_lo_import pg_lo_export pg_lo_seek pg_lo_tell pg_escape_string pg_escape_bytea pg_unescape_bytea pg_escape_literal pg_escape_identifier pg_set_error_verbosity pg_client_encoding pg_set_client_encoding pg_meta_data pg_convert pg_insert pg_update pg_delete pg_select pg_exec pg_getlastoid pg_cmdtuples pg_errormessage pg_numrows pg_numfields pg_fieldname pg_fieldsize pg_fieldtype pg_fieldnum pg_fieldprtlen pg_fieldisnull pg_freeresult pg_result pg_loreadall pg_locreate pg_lounlink pg_loopen pg_loclose pg_loread pg_lowrite pg_loimport pg_loexport pg_clientencoding pg_setclientencoding contained
" Phar
syn keyword phpClasses PharException Phar PharData PharFileInfo contained

" pcntl
syn keyword phpFunctions pcntl_fork pcntl_waitpid pcntl_wait pcntl_signal pcntl_signal_dispatch pcntl_wifexited pcntl_wifstopped pcntl_wifsignaled pcntl_wexitstatus pcntl_wtermsig pcntl_wstopsig pcntl_exec pcntl_alarm pcntl_get_last_error pcntl_errno pcntl_strerror pcntl_getpriority pcntl_setpriority pcntl_sigprocmask contained
" phalcon
syn keyword phpClasses Phalcon\Exception Phalcon\Acl\Exception Phalcon\Annotations\Exception Phalcon\Assets\Exception Phalcon\Cache\Exception Phalcon\Crypt\Exception Phalcon\CLI\Console\Exception Phalcon\CLI\Dispatcher\Exception Phalcon\CLI\Router\Exception Phalcon\Db\Exception Phalcon\DI\Exception Phalcon\Escaper\Exception Phalcon\Events\Exception Phalcon\Filter\Exception Phalcon\Flash\Exception Phalcon\Forms\Exception Phalcon\Http\Cookie\Exception Phalcon\Http\Request\Exception Phalcon\Http\Response\Exception Phalcon\Image\Exception Phalcon\Mvc\Application\Exception Phalcon\Mvc\Collection\Exception Phalcon\Mvc\Dispatcher\Exception Phalcon\Mvc\Model\Exception Phalcon\Mvc\Model\Transaction\Exception Phalcon\Mvc\Router\Exception Phalcon\Mvc\Url\Exception Phalcon\Mvc\View\Exception Phalcon\Paginator\Exception Phalcon\Tag\Exception Phalcon\Validation\Exception Phalcon\Security\Exception Phalcon\Session\Exception Phalcon\Config\Exception Phalcon\Loader\Exception Phalcon\Logger\Exception Phalcon\Translate\Exception Phalcon\DiInterface Phalcon\DI\InjectionAwareInterface Phalcon\Events\EventsAwareInterface Phalcon\Acl\AdapterInterface Phalcon\Acl\ResourceInterface Phalcon\Acl\RoleInterface Phalcon\Annotations\AdapterInterface Phalcon\Annotations\ReaderInterface Phalcon\Assets\FilterInterface Phalcon\Cache\BackendInterface Phalcon\Cache\FrontendInterface Phalcon\CryptInterface Phalcon\Db\AdapterInterface Phalcon\Db\ColumnInterface Phalcon\Db\DialectInterface Phalcon\Db\IndexInterface Phalcon\Db\ReferenceInterface Phalcon\Db\ResultInterface Phalcon\DispatcherInterface Phalcon\DI\ServiceInterface Phalcon\EscaperInterface Phalcon\Events\ManagerInterface Phalcon\FlashInterface Phalcon\FilterInterface Phalcon\Filter\UserFilterInterface Phalcon\Forms\ElementInterface Phalcon\Http\RequestInterface Phalcon\Http\Request\FileInterface Phalcon\Http\ResponseInterface Phalcon\Http\Response\CookiesInterface Phalcon\Http\Response\HeadersInterface Phalcon\Image\AdapterInterface Phalcon\Logger\AdapterInterface Phalcon\Logger\FormatterInterface Phalcon\Mvc\CollectionInterface Phalcon\Mvc\Collection\ManagerInterface Phalcon\Mvc\ControllerInterface Phalcon\Mvc\DispatcherInterface Phalcon\Mvc\Micro\CollectionInterface Phalcon\Mvc\Micro\MiddlewareInterface Phalcon\Mvc\ModelInterface Phalcon\Mvc\Model\BehaviorInterface Phalcon\Mvc\Model\CriteriaInterface Phalcon\Mvc\Model\ManagerInterface Phalcon\Mvc\Model\MessageInterface Phalcon\Mvc\Model\MetaDataInterface Phalcon\Mvc\Model\QueryInterface Phalcon\Mvc\Model\Query\BuilderInterface Phalcon\Mvc\Model\Query\StatusInterface Phalcon\Mvc\Model\RelationInterface Phalcon\Mvc\Model\ResultInterface Phalcon\Mvc\Model\ResultsetInterface Phalcon\Mvc\Model\TransactionInterface Phalcon\Mvc\Model\Transaction\ManagerInterface Phalcon\Mvc\Model\ValidatorInterface Phalcon\Mvc\ModuleDefinitionInterface Phalcon\Mvc\RouterInterface Phalcon\Mvc\Router\RouteInterface Phalcon\Mvc\UrlInterface Phalcon\Mvc\ViewInterface Phalcon\Mvc\View\EngineInterface Phalcon\Paginator\AdapterInterface Phalcon\Session\AdapterInterface Phalcon\Session\BagInterface Phalcon\Translate\AdapterInterface Phalcon\Validation\ValidatorInterface Phalcon\Db\Adapter Phalcon\DI\Injectable Phalcon\DI Phalcon\Forms\Element Phalcon\Validation\Validator Phalcon\Mvc\Model\Validator Phalcon\Cache\Backend Phalcon\Mvc\Model\MetaData Phalcon\Db\Adapter\Pdo Phalcon\Db\Dialect Phalcon\Annotations\Adapter Phalcon\Logger\Adapter Phalcon\Logger\Formatter Phalcon\Mvc\Model\Resultset Phalcon\Mvc\Model\Behavior Phalcon\Assets\Resource Phalcon\Flash Phalcon\Dispatcher Phalcon\Mvc\View\Engine Phalcon\Translate\Adapter Phalcon\Cache\Frontend\Data Phalcon\DI\FactoryDefault Phalcon\Config Phalcon\Mvc\Router Phalcon\Acl\Adapter Phalcon\Session\Adapter Phalcon\Db Phalcon\Acl Phalcon\Tag Phalcon\Cache\Multiple Phalcon\Cache\Backend\Apc Phalcon\Cache\Backend\File Phalcon\Cache\Backend\Memory Phalcon\Cache\Backend\Xcache Phalcon\Cache\Backend\Mongo Phalcon\Cache\Backend\Memcache Phalcon\Cache\Backend\Libmemcached Phalcon\Cache\Frontend\Json Phalcon\Cache\Frontend\Output Phalcon\Cache\Frontend\None Phalcon\Cache\Frontend\Base64 Phalcon\Cache\Frontend\Igbinary Phalcon\Tag\Select Phalcon\Paginator\Adapter\Model Phalcon\Paginator\Adapter\NativeArray Phalcon\Paginator\Adapter\QueryBuilder Phalcon\Validation Phalcon\Validation\Message Phalcon\Validation\Message\Group Phalcon\Validation\Validator\Regex Phalcon\Validation\Validator\Email Phalcon\Validation\Validator\Between Phalcon\Validation\Validator\Identical Phalcon\Validation\Validator\PresenceOf Phalcon\Validation\Validator\InclusionIn Phalcon\Validation\Validator\StringLength Phalcon\Validation\Validator\ExclusionIn Phalcon\Validation\Validator\Confirmation Phalcon\Validation\Validator\Url Phalcon\Db\Index Phalcon\Db\Column Phalcon\Db\Adapter\Pdo\Sqlite Phalcon\Db\Adapter\Pdo\Mysql Phalcon\Db\Adapter\Pdo\Oracle Phalcon\Db\Adapter\Pdo\Postgresql Phalcon\Db\Dialect\Sqlite Phalcon\Db\Dialect\Mysql Phalcon\Db\Dialect\Oracle Phalcon\Db\Dialect\Postgresql Phalcon\Db\Profiler Phalcon\Db\Profiler\Item Phalcon\Db\RawValue Phalcon\Db\Reference Phalcon\Db\Result\Pdo Phalcon\Acl\Role Phalcon\Acl\Resource Phalcon\Acl\Adapter\Memory Phalcon\Kernel Phalcon\Debug Phalcon\Text Phalcon\Security Phalcon\Version Phalcon\Session\Bag Phalcon\Session\Adapter\Files Phalcon\Filter Phalcon\DI\FactoryDefault\CLI Phalcon\DI\Service Phalcon\DI\Service\Builder Phalcon\Flash\Direct Phalcon\Flash\Session Phalcon\CLI\Task Phalcon\CLI\Router Phalcon\CLI\Console Phalcon\CLI\Dispatcher Phalcon\Annotations\Reader Phalcon\Annotations\Annotation Phalcon\Annotations\Adapter\Apc Phalcon\Annotations\Collection Phalcon\Annotations\Reflection Phalcon\Annotations\Adapter\Xcache Phalcon\Annotations\Adapter\Files Phalcon\Annotations\Adapter\Memory Phalcon\Loader Phalcon\Logger Phalcon\Logger\Item Phalcon\Logger\Multiple Phalcon\Logger\Formatter\Json Phalcon\Logger\Formatter\Line Phalcon\Logger\Formatter\Firephp Phalcon\Logger\Adapter\Stream Phalcon\Logger\Adapter\Syslog Phalcon\Logger\Adapter\File Phalcon\Logger\Adapter\Firephp Phalcon\Logger\Formatter\Syslog Phalcon\Config\Adapter\Ini Phalcon\Config\Adapter\Json Phalcon\Config\Adapter\Php Phalcon\Forms\Form Phalcon\Forms\Manager Phalcon\Forms\Element\Text Phalcon\Forms\Element\Date Phalcon\Forms\Element\File Phalcon\Forms\Element\Hidden Phalcon\Forms\Element\Select Phalcon\Forms\Element\Check Phalcon\Forms\Element\Numeric Phalcon\Forms\Element\Email Phalcon\Forms\Element\Submit Phalcon\Forms\Element\Password Phalcon\Forms\Element\TextArea Phalcon\Forms\Element\Radio Phalcon\Crypt Phalcon\Translate\Adapter\NativeArray Phalcon\Escaper Phalcon\Assets\Manager Phalcon\Assets\Resource\Js Phalcon\Assets\Collection Phalcon\Assets\Filters\None Phalcon\Assets\Filters\Cssmin Phalcon\Assets\Filters\Jsmin Phalcon\Assets\Resource\Css Phalcon\Http\Request Phalcon\Http\Cookie Phalcon\Http\Response Phalcon\Http\Request\File Phalcon\Http\Response\Cookies Phalcon\Http\Response\Headers Phalcon\Queue\Beanstalk Phalcon\Queue\Beanstalk\Job Phalcon\Mvc\View Phalcon\Mvc\Url Phalcon\Mvc\Model Phalcon\Mvc\Micro Phalcon\Mvc\Application Phalcon\Mvc\Collection Phalcon\Mvc\Controller Phalcon\Mvc\Collection\Document Phalcon\Mvc\Collection\Manager Phalcon\Mvc\Dispatcher Phalcon\Mvc\Model\Row Phalcon\Mvc\Model\Query Phalcon\Mvc\Micro\Collection Phalcon\Mvc\Micro\Exception Phalcon\Mvc\Micro\LazyLoader Phalcon\Mvc\Model\Criteria Phalcon\Mvc\Model\Manager Phalcon\Mvc\Model\Message Phalcon\Mvc\Model\Relation Phalcon\Mvc\Model\Transaction Phalcon\Mvc\Model\Query\Lang Phalcon\Mvc\Model\Validator\Url Phalcon\Mvc\Model\Query\Status Phalcon\Mvc\Model\MetaData\Apc Phalcon\Mvc\Model\MetaData\Files Phalcon\Mvc\Model\Query\Builder Phalcon\Mvc\Model\Validator\Regex Phalcon\Mvc\Model\ValidationFailed Phalcon\Mvc\Model\Resultset\Simple Phalcon\Mvc\Model\Resultset\Complex Phalcon\Mvc\Model\MetaData\Memory Phalcon\Mvc\Model\MetaData\Xcache Phalcon\Mvc\Model\Validator\Email Phalcon\Mvc\Model\MetaData\Session Phalcon\Mvc\Model\Validator\Uniqueness Phalcon\Mvc\Model\Validator\PresenceOf Phalcon\Mvc\Model\Transaction\Failed Phalcon\Mvc\Model\Behavior\SoftDelete Phalcon\Mvc\Model\Transaction\Manager Phalcon\Mvc\Model\Behavior\Timestampable Phalcon\Mvc\Model\MetaData\Strategy\Annotations Phalcon\Mvc\Model\MetaData\Strategy\Introspection Phalcon\Mvc\Model\Validator\Inclusionin Phalcon\Mvc\Model\Validator\Numericality Phalcon\Mvc\Model\Validator\Exclusionin Phalcon\Mvc\Model\Validator\StringLength Phalcon\Mvc\Router\Route Phalcon\Mvc\Router\Group Phalcon\Mvc\Router\Annotations Phalcon\Mvc\User\Module Phalcon\Mvc\User\Plugin Phalcon\Mvc\User\Component Phalcon\Mvc\View\Simple Phalcon\Mvc\View\Engine\Volt Phalcon\Mvc\View\Engine\Php Phalcon\Mvc\View\Engine\Volt\Compiler Phalcon\Events\Event Phalcon\Events\Manager Phalcon\Image Phalcon\Image\Adapter Phalcon\Image\Adapter\GD Phalcon\Image\Adapter\Imagick Phalcon\Registry contained

" posix
syn keyword phpFunctions posix_kill posix_getpid posix_getppid posix_getuid posix_setuid posix_geteuid posix_seteuid posix_getgid posix_setgid posix_getegid posix_setegid posix_getgroups posix_getlogin posix_getpgrp posix_setsid posix_setpgid posix_getpgid posix_getsid posix_uname posix_times posix_ctermid posix_ttyname posix_isatty posix_getcwd posix_mkfifo posix_mknod posix_access posix_getgrnam posix_getgrgid posix_getpwnam posix_getpwuid posix_getrlimit posix_get_last_error posix_errno posix_strerror posix_initgroups contained
" proctitle
syn keyword phpFunctions setproctitle contained
" propro
syn keyword phpClasses php\PropertyProxy contained

" pspell
syn keyword phpFunctions pspell_new pspell_new_personal pspell_new_config pspell_check pspell_suggest pspell_store_replacement pspell_add_to_personal pspell_add_to_session pspell_clear_session pspell_save_wordlist pspell_config_create pspell_config_runtogether pspell_config_mode pspell_config_ignore pspell_config_personal pspell_config_dict_dir pspell_config_data_dir pspell_config_repl pspell_config_save_repl contained
" raphf
syn keyword phpFunctions raphf\stat_persistent_handles raphf\clean_persistent_handles contained
" readline
syn keyword phpFunctions readline readline_info readline_add_history readline_clear_history readline_read_history readline_write_history readline_completion_function readline_callback_handler_install readline_callback_read_char readline_callback_handler_remove readline_redisplay readline_on_new_line contained
" redis
syn keyword phpClasses Redis RedisArray RedisException contained

" redland
syn keyword phpFunctions librdf_new_digest librdf_free_digest librdf_digest_init librdf_digest_update librdf_digest_update_string librdf_digest_final librdf_digest_to_string librdf_new_hash librdf_new_hash_from_string librdf_new_hash_from_array_of_strings librdf_hash_to_string librdf_free_hash librdf_new_world librdf_free_world librdf_world_open librdf_world_get_feature librdf_world_set_feature librdf_parser_get_accept_header librdf_world_set_logger librdf_free_iterator librdf_iterator_end librdf_iterator_get_object librdf_iterator_get_context librdf_iterator_next librdf_new_uri librdf_new_uri_from_uri librdf_new_uri_from_filename librdf_free_uri librdf_uri_to_string librdf_uri_equals librdf_uri_compare librdf_new_node librdf_new_node_from_uri_string librdf_new_node_from_uri librdf_new_node_from_uri_local_name librdf_new_node_from_normalised_uri_string librdf_new_node_from_literal librdf_new_node_from_typed_literal librdf_new_node_from_node librdf_new_node_from_blank_identifier librdf_free_node librdf_node_get_uri librdf_node_get_type librdf_node_get_literal_value librdf_node_get_literal_value_as_latin1 librdf_node_get_literal_value_language librdf_node_get_literal_value_datatype_uri librdf_node_get_literal_value_is_wf_xml librdf_node_get_li_ordinal librdf_node_to_string librdf_node_get_blank_identifier librdf_node_is_resource librdf_node_is_literal librdf_node_is_blank librdf_node_equals librdf_new_statement librdf_new_statement_from_statement librdf_new_statement_from_nodes librdf_free_statement librdf_statement_get_subject librdf_statement_set_subject librdf_statement_get_predicate librdf_statement_set_predicate librdf_statement_get_object librdf_statement_set_object librdf_statement_equals librdf_statement_match librdf_statement_to_string librdf_statement_is_complete librdf_new_model librdf_new_model_with_options librdf_new_model_from_model librdf_free_model librdf_model_size librdf_model_add librdf_model_add_string_literal_statement librdf_model_add_typed_literal_statement librdf_model_add_statement librdf_model_add_statements librdf_model_remove_statement librdf_model_contains_statement librdf_model_as_stream librdf_model_find_statements librdf_model_find_statements_in_context librdf_model_get_sources librdf_model_get_arcs librdf_model_get_targets librdf_model_get_source librdf_model_get_arc librdf_model_get_arcs_out librdf_model_get_arcs_in librdf_model_has_arc_in librdf_model_has_arc_out librdf_model_get_target librdf_model_context_add_statement librdf_model_context_add_statements librdf_model_context_remove_statement librdf_model_context_remove_statements librdf_model_context_as_stream librdf_model_sync librdf_model_get_contexts librdf_model_contains_context librdf_model_get_feature librdf_model_set_feature librdf_model_load librdf_model_query_execute librdf_model_to_string librdf_model_transaction_start librdf_model_transaction_commit librdf_model_transaction_rollback librdf_new_storage librdf_new_storage_from_storage librdf_free_storage librdf_parser_check_name librdf_new_parser librdf_free_parser librdf_parser_parse_as_stream librdf_parser_parse_into_model librdf_parser_parse_string_as_stream librdf_parser_parse_string_into_model librdf_parser_parse_counted_string_as_stream librdf_parser_parse_counted_string_into_model librdf_parser_get_feature librdf_parser_set_feature librdf_parser_guess_name librdf_parser_guess_name2 librdf_parser_get_namespaces_seen_prefix librdf_parser_get_namespaces_seen_uri librdf_parser_get_namespaces_seen_count librdf_new_query librdf_new_query_from_query librdf_free_query librdf_query_execute librdf_query_get_limit librdf_query_set_limit librdf_query_get_offset librdf_query_set_offset librdf_query_results_as_stream librdf_query_results_get_count librdf_query_results_next librdf_query_results_finished librdf_query_results_get_binding_value librdf_query_results_get_binding_name librdf_query_results_get_binding_value_by_name librdf_query_results_get_bindings_count librdf_query_results_to_file librdf_query_results_to_file2 librdf_query_results_to_string librdf_query_results_to_string2 librdf_free_query_results librdf_query_results_is_bindings librdf_query_results_is_boolean librdf_query_results_is_graph librdf_query_results_is_syntax librdf_query_results_get_boolean librdf_serializer_check_name librdf_new_serializer librdf_free_serializer librdf_serializer_serialize_stream_to_file librdf_serializer_serialize_model_to_file librdf_serializer_serialize_stream_to_string librdf_serializer_serialize_model_to_string librdf_serializer_get_feature librdf_serializer_set_feature librdf_serializer_set_namespace librdf_free_stream librdf_stream_end librdf_stream_next librdf_stream_get_object librdf_stream_get_context librdf_log_message_code librdf_log_message_level librdf_log_message_facility librdf_log_message_message librdf_log_message_locator raptor_locator_line raptor_locator_column raptor_locator_byte raptor_locator_file raptor_locator_uri librdf_internal_test_error librdf_internal_test_warning librdf_short_copyright_string_get librdf_copyright_string_get librdf_version_string_get librdf_version_major_get librdf_version_minor_get librdf_version_release_get librdf_version_decimal_get raptor_version_string_get raptor_version_major_get raptor_version_minor_get raptor_version_release_get raptor_version_decimal_get rasqal_version_string_get rasqal_version_major_get rasqal_version_minor_get rasqal_version_release_get rasqal_version_decimal_get librdf_php_get_world librdf_php_world_set_logger librdf_php_world_finish librdf_php_get_null_node librdf_php_get_null_uri librdf_php_last_log_level librdf_php_last_log_code librdf_php_last_log_message librdf_php_free_last_log swig_redland_alter_newobject swig_redland_get_newobject contained
syn keyword phpClasses RedlandException contained

" Reflection
syn keyword phpClasses ReflectionException Reflection Reflector ReflectionFunctionAbstract ReflectionFunction ReflectionParameter ReflectionMethod ReflectionClass ReflectionObject ReflectionProperty ReflectionExtension ReflectionZendExtension contained

" riak
syn keyword phpClasses Riak\Connection Riak\Object Riak\Link Riak\Bucket Riak\BucketPropertyList Riak\Property\ModuleFunction Riak\Property\CommitHook Riak\Property\CommitHookList Riak\Property\ReplicationMode\ReplicationMode Riak\Property\ReplicationMode\FullSyncOnly Riak\Property\ReplicationMode\Disabled Riak\Property\ReplicationMode\RealTimeAndFullSync Riak\Property\ReplicationMode\RealTimeOnly Riak\MapReduce\MapReduce Riak\MapReduce\Phase\Phase Riak\MapReduce\Phase\MapPhase Riak\MapReduce\Phase\ReducePhase Riak\MapReduce\Input\Input Riak\MapReduce\Input\BucketInput Riak\MapReduce\Input\KeyDataListInput Riak\MapReduce\Input\KeyListInput Riak\MapReduce\Output\Output Riak\MapReduce\Output\StreamOutput Riak\MapReduce\Functions\BaseFunction Riak\MapReduce\Functions\ErlangFunction Riak\MapReduce\Functions\JavascriptFunction Riak\Input\Input Riak\Input\DeleteInput Riak\Input\GetInput Riak\Input\GetResolverInput Riak\Input\PutInput Riak\Input\IndexInput Riak\Query\IndexQuery Riak\Output\Output Riak\Output\GetOutput Riak\Output\PutOutput Riak\Output\KeyStreamOutput Riak\ObjectList Riak\Output\IndexResult Riak\Output\IndexResultList Riak\Output\IndexOutput Riak\Output\ConflictResolver Riak\Output\YoungestSiblingResolver Riak\Exception\RiakException Riak\Exception\BadArgumentsException Riak\Exception\ConnectionException Riak\Exception\CommunicationException Riak\Exception\UnexpectedResponseException Riak\Exception\NonUniqueException Riak\Exception\UnresolvedConflictException Riak\PoolInfo Riak\Search\Search Riak\Search\Input\ParameterBag Riak\Search\Output\Output Riak\Search\Output\DocumentOutput Riak\Crdt\Counter Riak\Crdt\Input\GetInput Riak\Crdt\Input\UpdateInput Riak\ServerInfo contained

" runkit
syn keyword phpFunctions runkit_zval_inspect runkit_object_id runkit_return_value_used runkit_superglobals runkit_class_emancipate runkit_class_adopt runkit_import runkit_function_add runkit_function_remove runkit_function_rename runkit_function_redefine runkit_function_copy runkit_method_add runkit_method_redefine runkit_method_remove runkit_method_rename runkit_method_copy runkit_constant_redefine runkit_constant_remove runkit_constant_add runkit_default_property_add runkit_default_property_remove contained
" session
syn keyword phpFunctions session_name session_module_name session_save_path session_id session_regenerate_id session_decode session_encode session_start session_destroy session_unset session_set_save_handler session_cache_limiter session_cache_expire session_set_cookie_params session_get_cookie_params session_write_close session_status session_register_shutdown session_commit contained
syn keyword phpClasses SessionHandlerInterface SessionIdInterface SessionHandler contained

" shmop
syn keyword phpFunctions shmop_open shmop_read shmop_close shmop_size shmop_write shmop_delete contained
" SimpleXML
syn keyword phpFunctions simplexml_load_file simplexml_load_string simplexml_import_dom contained
syn keyword phpClasses SimpleXMLElement SimpleXMLIterator contained

" snappy
syn keyword phpFunctions snappy_compress snappy_uncompress contained
" snmp
syn keyword phpFunctions snmpget snmpgetnext snmpwalk snmprealwalk snmpwalkoid snmpset snmp_get_quick_print snmp_set_quick_print snmp_set_enum_print snmp_set_oid_output_format snmp_set_oid_numeric_print snmp2_get snmp2_getnext snmp2_walk snmp2_real_walk snmp2_set snmp3_get snmp3_getnext snmp3_walk snmp3_real_walk snmp3_set snmp_set_valueretrieval snmp_get_valueretrieval snmp_read_mib contained
syn keyword phpClasses SNMP SNMPException contained

" soap
syn keyword phpFunctions use_soap_error_handler is_soap_fault contained
syn keyword phpClasses SoapClient SoapVar SoapServer SoapFault SoapParam SoapHeader contained

" sockets
syn keyword phpFunctions socket_select socket_create socket_create_listen socket_create_pair socket_accept socket_set_nonblock socket_set_block socket_listen socket_close socket_write socket_read socket_getsockname socket_getpeername socket_connect socket_strerror socket_bind socket_recv socket_send socket_recvfrom socket_sendto socket_get_option socket_set_option socket_shutdown socket_last_error socket_clear_error socket_import_stream socket_sendmsg socket_recvmsg socket_cmsg_space socket_getopt socket_setopt contained
" solr
syn keyword phpFunctions solr_get_version contained
syn keyword phpClasses SolrObject SolrDocument SolrDocumentField SolrInputDocument SolrClient SolrParams SolrModifiableParams SolrQuery SolrResponse SolrQueryResponse SolrUpdateResponse SolrPingResponse SolrGenericResponse SolrUtils SolrException SolrIllegalOperationException SolrIllegalArgumentException SolrClientException contained

" sphinx
syn keyword phpClasses SphinxClient contained

" SPL
syn keyword phpFunctions spl_classes spl_autoload spl_autoload_extensions spl_autoload_register spl_autoload_unregister spl_autoload_functions spl_autoload_call class_parents class_implements class_uses spl_object_hash iterator_to_array iterator_count iterator_apply contained
syn keyword phpClasses LogicException BadFunctionCallException BadMethodCallException DomainException InvalidArgumentException LengthException OutOfRangeException RuntimeException OutOfBoundsException OverflowException RangeException UnderflowException UnexpectedValueException RecursiveIterator RecursiveIteratorIterator OuterIterator IteratorIterator FilterIterator RecursiveFilterIterator CallbackFilterIterator RecursiveCallbackFilterIterator ParentIterator Countable SeekableIterator LimitIterator CachingIterator RecursiveCachingIterator NoRewindIterator AppendIterator InfiniteIterator RegexIterator RecursiveRegexIterator EmptyIterator RecursiveTreeIterator ArrayObject ArrayIterator RecursiveArrayIterator SplFileInfo DirectoryIterator FilesystemIterator RecursiveDirectoryIterator GlobIterator SplFileObject SplTempFileObject SplDoublyLinkedList SplQueue SplStack SplHeap SplMinHeap SplMaxHeap SplPriorityQueue SplFixedArray SplObserver SplSubject SplObjectStorage MultipleIterator contained

" sqlite3
syn keyword phpClasses SQLite3 SQLite3Stmt SQLite3Result contained

" ssh2
syn keyword phpFunctions ssh2_connect ssh2_methods_negotiated ssh2_fingerprint ssh2_auth_none ssh2_auth_password ssh2_auth_pubkey_file ssh2_auth_hostbased_file ssh2_forward_listen ssh2_forward_accept ssh2_shell ssh2_exec ssh2_tunnel ssh2_scp_recv ssh2_scp_send ssh2_fetch_stream ssh2_poll ssh2_sftp ssh2_sftp_rename ssh2_sftp_unlink ssh2_sftp_mkdir ssh2_sftp_rmdir ssh2_sftp_chmod ssh2_sftp_stat ssh2_sftp_lstat ssh2_sftp_symlink ssh2_sftp_readlink ssh2_sftp_realpath ssh2_publickey_init ssh2_publickey_add ssh2_publickey_remove ssh2_publickey_list ssh2_auth_agent contained
" standard
syn keyword phpFunctions constant bin2hex hex2bin sleep usleep time_nanosleep time_sleep_until strptime flush wordwrap htmlspecialchars htmlentities html_entity_decode htmlspecialchars_decode get_html_translation_table sha1 sha1_file md5 md5_file crc32 iptcparse iptcembed getimagesize getimagesizefromstring image_type_to_mime_type image_type_to_extension phpinfo phpversion phpcredits php_sapi_name php_uname php_ini_scanned_files php_ini_loaded_file strnatcmp strnatcasecmp substr_count strspn strcspn strtok strtoupper strtolower strpos stripos strrpos strripos strrev hebrev hebrevc nl2br basename dirname pathinfo stripslashes stripcslashes strstr stristr strrchr str_shuffle str_word_count str_split strpbrk substr_compare strcoll money_format substr substr_replace quotemeta ucfirst lcfirst ucwords strtr addslashes addcslashes rtrim str_replace str_ireplace str_repeat count_chars chunk_split trim ltrim strip_tags similar_text explode implode join setlocale localeconv nl_langinfo soundex levenshtein chr ord parse_str str_getcsv str_pad chop strchr sprintf printf vprintf vsprintf fprintf vfprintf sscanf fscanf parse_url urlencode urldecode rawurlencode rawurldecode http_build_query readlink linkinfo symlink link unlink exec system escapeshellcmd escapeshellarg passthru shell_exec proc_open proc_close proc_terminate proc_get_status proc_nice rand srand getrandmax mt_rand mt_srand mt_getrandmax getservbyname getservbyport getprotobyname getprotobynumber getmyuid getmygid getmypid getmyinode getlastmod base64_decode base64_encode password_hash password_get_info password_needs_rehash password_verify convert_uuencode convert_uudecode abs ceil floor round sin cos tan asin acos atan atanh atan2 sinh cosh tanh asinh acosh expm1 log1p pi is_finite is_nan is_infinite pow exp log log10 sqrt hypot deg2rad rad2deg bindec hexdec octdec decbin decoct dechex base_convert number_format fmod inet_ntop inet_pton ip2long long2ip getenv putenv getopt sys_getloadavg microtime gettimeofday getrusage uniqid quoted_printable_decode quoted_printable_encode convert_cyr_string get_current_user set_time_limit header_register_callback get_cfg_var magic_quotes_runtime set_magic_quotes_runtime get_magic_quotes_gpc get_magic_quotes_runtime error_log error_get_last call_user_func call_user_func_array call_user_method call_user_method_array forward_static_call forward_static_call_array serialize unserialize var_dump var_export debug_zval_dump print_r memory_get_usage memory_get_peak_usage register_shutdown_function register_tick_function unregister_tick_function highlight_file show_source highlight_string php_strip_whitespace ini_get ini_get_all ini_set ini_alter ini_restore get_include_path set_include_path restore_include_path setcookie setrawcookie header header_remove headers_sent headers_list http_response_code connection_aborted connection_status ignore_user_abort parse_ini_file parse_ini_string is_uploaded_file move_uploaded_file gethostbyaddr gethostbyname gethostbynamel gethostname dns_check_record checkdnsrr dns_get_mx getmxrr dns_get_record intval floatval doubleval strval boolval gettype settype is_null is_resource is_bool is_long is_float is_int is_integer is_double is_real is_numeric is_string is_array is_object is_scalar is_callable pclose popen readfile rewind rmdir umask fclose feof fgetc fgets fgetss fread fopen fpassthru ftruncate fstat fseek ftell fflush fwrite fputs mkdir rename copy tempnam tmpfile file file_get_contents file_put_contents stream_select stream_context_create stream_context_set_params stream_context_get_params stream_context_set_option stream_context_get_options stream_context_get_default stream_context_set_default stream_filter_prepend stream_filter_append stream_filter_remove stream_socket_client stream_socket_server stream_socket_accept stream_socket_get_name stream_socket_recvfrom stream_socket_sendto stream_socket_enable_crypto stream_socket_shutdown stream_socket_pair stream_copy_to_stream stream_get_contents stream_supports_lock fgetcsv fputcsv flock get_meta_tags stream_set_read_buffer stream_set_write_buffer set_file_buffer stream_set_chunk_size set_socket_blocking stream_set_blocking socket_set_blocking stream_get_meta_data stream_get_line stream_wrapper_register stream_register_wrapper stream_wrapper_unregister stream_wrapper_restore stream_get_wrappers stream_get_transports stream_resolve_include_path stream_is_local get_headers stream_set_timeout socket_set_timeout socket_get_status realpath fnmatch fsockopen pfsockopen pack unpack get_browser crypt opendir closedir chdir getcwd rewinddir readdir dir scandir glob fileatime filectime filegroup fileinode filemtime fileowner fileperms filesize filetype file_exists is_writable is_writeable is_readable is_executable is_file is_dir is_link stat lstat chown chgrp lchown lchgrp chmod touch clearstatcache disk_total_space disk_free_space diskfreespace realpath_cache_size realpath_cache_get mail ezmlm_hash openlog syslog closelog lcg_value metaphone ob_start ob_flush ob_clean ob_end_flush ob_end_clean ob_get_flush ob_get_clean ob_get_length ob_get_level ob_get_status ob_get_contents ob_implicit_flush ob_list_handlers ksort krsort natsort natcasesort asort arsort sort rsort usort uasort uksort shuffle array_walk array_walk_recursive count end prev next reset current key min max in_array array_search extract compact array_fill array_fill_keys range array_multisort array_push array_pop array_shift array_unshift array_splice array_slice array_merge array_merge_recursive array_replace array_replace_recursive array_keys array_values array_count_values array_column array_reverse array_reduce array_pad array_flip array_change_key_case array_rand array_unique array_intersect array_intersect_key array_intersect_ukey array_uintersect array_intersect_assoc array_uintersect_assoc array_intersect_uassoc array_uintersect_uassoc array_diff array_diff_key array_diff_ukey array_udiff array_diff_assoc array_udiff_assoc array_diff_uassoc array_udiff_uassoc array_sum array_product array_filter array_map array_chunk array_combine array_key_exists pos sizeof key_exists assert assert_options version_compare ftok str_rot13 stream_get_filters stream_filter_register stream_bucket_make_writeable stream_bucket_prepend stream_bucket_append stream_bucket_new output_add_rewrite_var output_reset_rewrite_vars sys_get_temp_dir dl cli_set_process_title cli_get_process_title contained
syn keyword phpClasses __PHP_Incomplete_Class php_user_filter Directory contained

" stats
syn keyword phpFunctions stats_cdf_t stats_cdf_normal stats_cdf_gamma stats_cdf_chisquare stats_cdf_beta stats_cdf_binomial stats_cdf_noncentral_chisquare stats_cdf_f stats_cdf_noncentral_f stats_cdf_noncentral_t stats_cdf_negative_binomial stats_cdf_poisson stats_cdf_laplace stats_cdf_cauchy stats_cdf_logistic stats_cdf_weibull stats_cdf_uniform stats_cdf_exponential stats_rand_setall stats_rand_getsd stats_rand_gen_iuniform stats_rand_gen_funiform stats_rand_ignlgi stats_rand_ranf stats_rand_gen_beta stats_rand_gen_chisquare stats_rand_gen_exponential stats_rand_gen_f stats_rand_gen_gamma stats_rand_gen_noncentral_chisquare stats_rand_gen_noncenral_f stats_rand_gen_normal stats_rand_phrase_to_seeds stats_rand_ibinomial stats_rand_ibinomial_negative stats_rand_gen_ipoisson stats_rand_gen_noncentral_t stats_rand_gen_t stats_dens_normal stats_dens_cauchy stats_dens_laplace stats_dens_logistic stats_dens_beta stats_dens_weibull stats_dens_uniform stats_dens_chisquare stats_dens_t stats_dens_gamma stats_dens_exponential stats_dens_f stats_dens_pmf_binomial stats_dens_pmf_poisson stats_dens_pmf_negative_binomial stats_dens_pmf_hypergeometric stats_stat_powersum stats_stat_innerproduct stats_stat_independent_t stats_stat_paired_t stats_stat_percentile stats_stat_correlation stats_stat_binomial_coef stats_stat_factorial stats_standard_deviation stats_absolute_deviation stats_variance stats_harmonic_mean stats_skew stats_kurtosis stats_covariance contained
" sundown
syn keyword phpClasses Sundown Sundown\Render\Base Sundown\Render\HTML Sundown\Render\XHTML Sundown\Render\HTML_TOC Sundown\Markdown contained

" swoole
syn keyword phpFunctions swoole_version swoole_server_create swoole_server_set swoole_server_start swoole_server_send swoole_server_close swoole_server_handler swoole_server_on swoole_server_addlisten swoole_server_addtimer swoole_server_deltimer swoole_server_task swoole_server_taskwait swoole_server_finish swoole_server_reload swoole_server_shutdown swoole_connection_info swoole_connection_list swoole_event_add swoole_event_del swoole_event_exit swoole_event_wait swoole_client_select swoole_set_process_name contained
syn keyword phpClasses swoole_client swoole_server swoole_lock contained

" sysvmsg
syn keyword phpFunctions msg_get_queue msg_send msg_receive msg_remove_queue msg_stat_queue msg_set_queue msg_queue_exists contained
" sysvsem
syn keyword phpFunctions sem_get sem_acquire sem_release sem_remove contained
" sysvshm
syn keyword phpFunctions shm_attach shm_remove shm_detach shm_put_var shm_has_var shm_get_var shm_remove_var contained
" test_helpers
syn keyword phpFunctions unset_new_overload set_new_overload unset_exit_overload set_exit_overload rename_method rename_function contained
" tidy
syn keyword phpFunctions tidy_getopt tidy_parse_string tidy_parse_file tidy_get_output tidy_get_error_buffer tidy_clean_repair tidy_repair_string tidy_repair_file tidy_diagnose tidy_get_release tidy_get_config tidy_get_status tidy_get_html_ver tidy_is_xhtml tidy_is_xml tidy_error_count tidy_warning_count tidy_access_count tidy_config_count tidy_get_opt_doc tidy_get_root tidy_get_head tidy_get_html tidy_get_body contained
syn keyword phpClasses tidy tidyNode contained

" timezonedb
" tokenizer
syn keyword phpFunctions token_get_all token_name contained
" tokyo_tyrant
syn keyword phpClasses tokyotyrant tokyotyranttable tokyotyrantquery tokyotyrantiterator tokyotyrantexception contained

" uploadprogress
syn keyword phpFunctions uploadprogress_get_info uploadprogress_get_contents contained
" uuid
syn keyword phpFunctions uuid_create uuid_is_valid uuid_compare uuid_is_null uuid_parse uuid_unparse contained
" varnish
syn keyword phpClasses VarnishAdmin VarnishStat VarnishLog VarnishException contained

" wbxml
syn keyword phpFunctions wbxml_encode wbxml_decode contained
" wddx
syn keyword phpFunctions wddx_serialize_value wddx_serialize_vars wddx_packet_start wddx_packet_end wddx_add_vars wddx_deserialize contained
" XCache
syn keyword phpFunctions xcache_coredump xcache_get_special_value xcache_get_type xcache_get_op_type xcache_get_data_type xcache_get_opcode xcache_get_opcode_spec xcache_is_autoglobal xcache_get_refcount xcache_get_isref contained
" xdebug
syn keyword phpFunctions xdebug_get_stack_depth xdebug_get_function_stack xdebug_get_formatted_function_stack xdebug_print_function_stack xdebug_get_declared_vars xdebug_call_class xdebug_call_function xdebug_call_file xdebug_call_line xdebug_var_dump xdebug_debug_zval xdebug_debug_zval_stdout xdebug_enable xdebug_disable xdebug_is_enabled xdebug_break xdebug_start_trace xdebug_stop_trace xdebug_get_tracefile_name xdebug_get_profiler_filename xdebug_dump_aggr_profiling_data xdebug_clear_aggr_profiling_data xdebug_memory_usage xdebug_peak_memory_usage xdebug_time_index xdebug_start_error_collection xdebug_stop_error_collection xdebug_get_collected_errors xdebug_start_code_coverage xdebug_stop_code_coverage xdebug_get_code_coverage xdebug_get_function_count xdebug_dump_superglobals xdebug_get_headers contained
" xml
syn keyword phpFunctions xml_parser_create xml_parser_create_ns xml_set_object xml_set_element_handler xml_set_character_data_handler xml_set_processing_instruction_handler xml_set_default_handler xml_set_unparsed_entity_decl_handler xml_set_notation_decl_handler xml_set_external_entity_ref_handler xml_set_start_namespace_decl_handler xml_set_end_namespace_decl_handler xml_parse xml_parse_into_struct xml_get_error_code xml_error_string xml_get_current_line_number xml_get_current_column_number xml_get_current_byte_index xml_parser_free xml_parser_set_option xml_parser_get_option utf8_encode utf8_decode contained
" xmldiff
syn keyword phpClasses XMLDiff\Base XMLDiff\DOM XMLDiff\File XMLDiff\Memory XMLDiff\Exception contained

" xmlreader
syn keyword phpClasses XMLReader contained

" xmlrpc
syn keyword phpFunctions xmlrpc_encode xmlrpc_decode xmlrpc_decode_request xmlrpc_encode_request xmlrpc_get_type xmlrpc_set_type xmlrpc_is_fault xmlrpc_server_create xmlrpc_server_destroy xmlrpc_server_register_method xmlrpc_server_call_method xmlrpc_parse_method_descriptions xmlrpc_server_add_introspection_data xmlrpc_server_register_introspection_callback contained
" xmlwriter
syn keyword phpFunctions xmlwriter_open_uri xmlwriter_open_memory xmlwriter_set_indent xmlwriter_set_indent_string xmlwriter_start_comment xmlwriter_end_comment xmlwriter_start_attribute xmlwriter_end_attribute xmlwriter_write_attribute xmlwriter_start_attribute_ns xmlwriter_write_attribute_ns xmlwriter_start_element xmlwriter_end_element xmlwriter_full_end_element xmlwriter_start_element_ns xmlwriter_write_element xmlwriter_write_element_ns xmlwriter_start_pi xmlwriter_end_pi xmlwriter_write_pi xmlwriter_start_cdata xmlwriter_end_cdata xmlwriter_write_cdata xmlwriter_text xmlwriter_write_raw xmlwriter_start_document xmlwriter_end_document xmlwriter_write_comment xmlwriter_start_dtd xmlwriter_end_dtd xmlwriter_write_dtd xmlwriter_start_dtd_element xmlwriter_end_dtd_element xmlwriter_write_dtd_element xmlwriter_start_dtd_attlist xmlwriter_end_dtd_attlist xmlwriter_write_dtd_attlist xmlwriter_start_dtd_entity xmlwriter_end_dtd_entity xmlwriter_write_dtd_entity xmlwriter_output_memory xmlwriter_flush contained
syn keyword phpClasses XMLWriter contained

" xsl
syn keyword phpClasses XSLTProcessor contained

" yaf
syn keyword phpClasses Yaf_Application Yaf_Bootstrap_Abstract Yaf_Dispatcher Yaf_Loader Yaf_Request_Abstract Yaf_Request_Http Yaf_Request_Simple Yaf_Response_Abstract Yaf_Response_Http Yaf_Response_Cli Yaf_Controller_Abstract Yaf_Action_Abstract Yaf_Config_Abstract Yaf_Config_Ini Yaf_Config_Simple Yaf_View_Interface Yaf_View_Simple Yaf_Router Yaf_Route_Interface Yaf_Route_Static Yaf_Route_Simple Yaf_Route_Supervar Yaf_Route_Rewrite Yaf_Route_Regex Yaf_Route_Map Yaf_Plugin_Abstract Yaf_Registry Yaf_Session Yaf_Exception Yaf_Exception_StartupError Yaf_Exception_RouterFailed Yaf_Exception_DispatchFailed Yaf_Exception_LoadFailed Yaf_Exception_LoadFailed_Module Yaf_Exception_LoadFailed_Controller Yaf_Exception_LoadFailed_Action Yaf_Exception_LoadFailed_View Yaf_Exception_TypeError contained

" yaml
syn keyword phpFunctions yaml_parse yaml_parse_file yaml_parse_url yaml_emit yaml_emit_file contained
" yar
syn keyword phpClasses Yar_Server Yar_Client Yar_Concurrent_Client Yar_Server_Exception Yar_Server_Request_Exception Yar_Server_Protocol_Exception Yar_Server_Packager_Exception Yar_Server_Output_Exception Yar_Client_Exception Yar_Client_Transport_Exception Yar_Client_Packager_Exception Yar_Client_Protocol_Exception contained

" yaz
syn keyword phpFunctions yaz_connect yaz_close yaz_search yaz_wait yaz_errno yaz_error yaz_addinfo yaz_hits yaz_record yaz_syntax yaz_element yaz_range yaz_itemorder yaz_es_result yaz_scan yaz_scan_result yaz_present yaz_ccl_conf yaz_ccl_parse yaz_database yaz_sort yaz_schema yaz_set_option yaz_get_option yaz_es contained
" zip
syn keyword phpFunctions zip_open zip_close zip_read zip_entry_open zip_entry_close zip_entry_read zip_entry_filesize zip_entry_name zip_entry_compressedsize zip_entry_compressionmethod contained
syn keyword phpClasses ZipArchive contained

" zlib
syn keyword phpFunctions readgzfile gzrewind gzclose gzeof gzgetc gzgets gzgetss gzread gzopen gzpassthru gzseek gztell gzwrite gzputs gzfile gzcompress gzuncompress gzdeflate gzinflate gzencode gzdecode zlib_encode zlib_decode zlib_get_coding_type ob_gzhandler contained
" zookeeper
syn keyword phpClasses Zookeeper contained



" === END BUILTIN FUNCTIONS, CLASSES, AND CONSTANTS =====================================

" The following is needed afterall it seems.
syntax keyword phpClasses containedin=ALLBUT,phpComment,phpDocComment,phpStringDouble,phpStringSingle,phpIdentifier,phpMethodsVar

" Control Structures
syn keyword phpKeyword if echo else elseif while do for foreach function break switch case default continue return goto as endif endwhile endfor endforeach endswitch declare endeclare print new clone yield contained

" Exception Keywords
syn keyword phpKeyword try catch finally throw contained

" Class Keywords
syn keyword phpType class abstract extends interface implements static final var public private protected const trait contained

" Magic Methods
syn keyword phpStatement __construct __destruct __call __callStatic __get __set __isset __unset __sleep __wakeup __toString __invoke __set_state __clone contained

" Language Constructs
syn keyword phpKeyword die exit eval empty isset unset list instanceof insteadof contained

" Include & friends
syn keyword phpInclude include include_once require require_once namespace use contained

" Types
syn keyword phpType bool[ean] int[eger] real double float string array object null self parent global this stdClass callable contained

" Operator
syn match phpOperator       "[-=+%^&|*!.~?:]" contained display
syn match phpOperator       "[-+*/%^&|.]="  contained display
syn match phpOperator       "/[^*/]"me=e-1  contained display
syn match phpOperator       "\$"  contained display
syn match phpOperator       "&&\|\<and\>" contained display
syn match phpOperator       "||\|\<x\=or\>" contained display
syn match phpOperator       "[!=<>]=" contained display
syn match phpOperator       "[<>]"  contained display
syn match phpMemberSelector "->"  contained display
syn match phpVarSelector    "\$"  contained display
" highlight object variables inside strings
syn match phpMethodsVar     "->\h\w*" contained contains=phpMethods,phpMemberSelector display containedin=phpStringDouble
syn match phpClasses        "\v\h\w+(::)@=" contained display

" Identifier
syn match  phpIdentifier         "$\h\w*"  contained contains=phpSuperglobals,phpVarSelector display
syn match  phpIdentifierSimply   "${\h\w*}"  contains=phpOperator,phpParent  contained display
syn region phpIdentifierComplex  matchgroup=phpParent start="{\$"rs=e-1 end="}"  contains=phpIdentifier,phpMemberSelector,phpVarSelector,phpIdentifierArray contained extend
syn region phpIdentifierArray    matchgroup=phpParent start="\[" end="]" contains=@phpClInside contained

" Boolean
syn keyword phpBoolean true false  contained

" Number
syn match phpNumber "-\=\<\d\+\>" contained display
syn match phpNumber "\<0x\x\{1,8}\>"  contained display
syn match phpNumber "\<0b[01]\+\>"    contained display

" Float
syn match phpNumber "\(-\=\<\d+\|-\=\)\.\d\+\>" contained display

" SpecialChar
syn match phpSpecialChar "\\[fnrtv\\]" contained display
syn match phpSpecialChar "\\\d\{3}"  contained contains=phpOctalError display
syn match phpSpecialChar "\\x\x\{2}" contained display
" corrected highlighting for an escaped '\$' inside a double-quoted string
syn match phpSpecialChar "\\\$"  contained display
syn match phpSpecialChar +\\"+   contained display
syn match phpStrEsc      "\\\\"  contained display
syn match phpStrEsc      "\\'"   contained display

" Format specifiers (printf)
" See https://github.com/aantonello/php.vim/commit/9d24eab4ea4b3752a54aebf14d3491b6d8edb6d8
syn match phpSpecialChar display contained /%\(\d\+\$\)\=[-+' #0*]*\(\d*\|\*\|\*\d\+\$\)\(\.\(\d*\|\*\|\*\d\+\$\)\)\=\([aAbBdiouxXDOUfFeEgGcCsSpnmMyYhH]\|\[\^\=.[^]]*\]\)/ containedin=phpStringSingle,phpStringDouble,phpHereDoc
syn match phpSpecialChar display contained /%%/ containedin=phpStringSingle,phpStringDouble,phpHereDoc

" Error
syn match phpOctalError "[89]"  contained display
if exists("php_parent_error_close")
  syn match phpParentError "[)\]}]"  contained display
endif

" Todo
syn keyword phpTodo todo fixme xxx note contained
syn match phpCommentSelector "\v\@(return|var|param|abstract|access|author|copyright|deprecated|example|global|ignore|internal|link|name|magic|package|see|since|static|staticvar|subpackage|todo|version|usage|license)" contained

" Comment
if exists("php_parent_error_open")
  syn region phpComment start="/\*" end="\*/" contained contains=phpTodo,phpCommentSelector,@Spell
else
  syn region phpComment start="/\*" end="\*/" contained contains=phpTodo,phpCommentSelector,@Spell extend
endif

if version >= 600
  syn match phpComment  "#.\{-}\(?>\|$\)\@="  contained contains=phpTodo,@Spell
  syn match phpComment  "//.\{-}\(?>\|$\)\@=" contained contains=phpTodo,@Spell
else
  syn match phpComment  "#.\{-}$" contained contains=phpTodo,@Spell
  syn match phpComment  "#.\{-}?>"me=e-2  contained contains=phpTodo,@Spell
  syn match phpComment  "//.\{-}$"  contained contains=phpTodo,@Spell
  syn match phpComment  "//.\{-}?>"me=e-2 contained contains=phpTodo,@Spell
endif

" String
if exists("php_parent_error_open")
  syn region phpStringDouble matchgroup=phpStringDelimiter start=+"+ skip=+\\\\\|\\"+ end=+"+  contains=@Spell,@phpAddStrings,phpIdentifier,phpSpecialChar,phpIdentifierSimply,phpIdentifierComplex,phpStrEsc contained keepend
  syn region phpBacktick matchgroup=phpStringDelimiter start=+`+ skip=+\\\\\|\\"+ end=+`+  contains=@Spell,@phpAddStrings,phpIdentifier,phpSpecialChar,phpIdentifierSimply,phpIdentifierComplex,phpStrEsc contained keepend
  syn region phpStringSingle matchgroup=phpStringDelimiter start=+'+ skip=+\\\\\|\\'+ end=+'+  contains=@Spell,@phpAddStrings,phpStrEsc contained keepend
else
  syn region phpStringDouble matchgroup=phpStringDelimiter start=+"+ skip=+\\\\\|\\"+ end=+"+  contains=@Spell,@phpAddStrings,phpIdentifier,phpSpecialChar,phpIdentifierSimply,phpIdentifierComplex,phpStrEsc contained extend keepend
  syn region phpBacktick matchgroup=phpStringDelimiter start=+`+ skip=+\\\\\|\\"+ end=+`+  contains=@Spell,@phpAddStrings,phpIdentifier,phpSpecialChar,phpIdentifierSimply,phpIdentifierComplex,phpStrEsc contained extend keepend
  syn region phpStringSingle matchgroup=phpStringDelimiter start=+'+ skip=+\\\\\|\\'+ end=+'+  contains=@Spell,@phpAddStrings,phpStrEsc contained keepend extend
endif

" HereDoc
  syn case match
  syn region phpHereDoc matchgroup=Delimiter start="\(<<<\)\@<=\z(\I\i*\)$" end="^\z1\(;\=$\)\@=" contained contains=@Spell,phpIdentifier,phpIdentifierSimply,phpIdentifierComplex,phpSpecialChar,phpMethodsVar,phpStrEsc keepend extend
  syn region phpHereDoc matchgroup=Delimiter start=+\(<<<\)\@<="\z(\I\i*\)"$+ end="^\z1\(;\=$\)\@=" contained contains=@Spell,phpIdentifier,phpIdentifierSimply,phpIdentifierComplex,phpSpecialChar,phpMethodsVar,phpStrEsc keepend extend
" including HTML,JavaScript,SQL even if not enabled via options
  syn region phpHereDoc matchgroup=Delimiter start="\(<<<\)\@<=\z(\(\I\i*\)\=\(html\)\c\(\i*\)\)$" end="^\z1\(;\=$\)\@="  contained contains=@htmlTop,phpIdentifier,phpIdentifierSimply,phpIdentifierComplex,phpSpecialChar,phpMethodsVar,phpStrEsc keepend extend
  syn region phpHereDoc matchgroup=Delimiter start="\(<<<\)\@<=\z(\(\I\i*\)\=\(sql\)\c\(\i*\)\)$" end="^\z1\(;\=$\)\@=" contained contains=@sqlTop,phpIdentifier,phpIdentifierSimply,phpIdentifierComplex,phpSpecialChar,phpMethodsVar,phpStrEsc keepend extend
  syn region phpHereDoc matchgroup=Delimiter start="\(<<<\)\@<=\z(\(\I\i*\)\=\(javascript\)\c\(\i*\)\)$" end="^\z1\(;\=$\)\@="  contained contains=@htmlJavascript,phpIdentifierSimply,phpIdentifier,phpIdentifierComplex,phpSpecialChar,phpMethodsVar,phpStrEsc keepend extend
  syn case ignore

" NowDoc
  syn region phpNowDoc matchgroup=Delimiter start=+\(<<<\)\@<='\z(\I\i*\)'$+ end="^\z1\(;\=$\)\@=" contained keepend extend

" Parent
if exists("php_parent_error_close") || exists("php_parent_error_open")
  syn match  phpParent "[{}]"  contained
  syn region phpParent matchgroup=Delimiter start="(" end=")"  contained contains=@phpClFunction transparent
  syn region phpParent matchgroup=Delimiter start="\[" end="\]"  contained contains=@phpClInside transparent
  if !exists("php_parent_error_close")
    syn match phpParent "[\])]" contained
  endif
else
  syn match phpParent "[({[\]})]" contained
endif

" Clusters
syn cluster phpClConst contains=phpFunctions,phpClasses,phpIdentifier,phpStatement,phpKeyword,phpOperator,phpStringSingle,phpStringDouble,phpBacktick,phpNumber,phpType,phpBoolean,phpStructure,phpMethodsVar,phpConstants,phpException,phpSuperglobals,phpMagicConstants,phpServerVars
syn cluster phpClInside contains=@phpClConst,phpComment,phpDocComment,phpParent,phpParentError,phpInclude,phpHereDoc,phpNowDoc
syn cluster phpClFunction contains=@phpClInside,phpDefine,phpParentError,phpStorageClass,phpKeyword
syn cluster phpClTop contains=@phpClFunction,phpFoldFunction,phpFoldClass,phpFoldInterface,phpFoldTry,phpFoldCatch

" Php Region
if exists("php_parent_error_open")
  syn region phpRegion matchgroup=Delimiter start="<?\(php\)\=" end="?>" contains=@phpClTop
else
  syn region phpRegion matchgroup=Delimiter start="<?\(php\)\=" end="?>" contains=@phpClTop keepend
endif

" Fold
if exists("php_folding") && php_folding==1
" match one line constructs here and skip them at folding
  syn keyword phpSCKeyword  abstract final private protected public static  contained
  syn keyword phpFCKeyword  function  contained
  syn match phpDefine "\(\s\|^\)\(abstract\s\+\|final\s\+\|private\s\+\|protected\s\+\|public\s\+\|static\s\+\)*function\(\s\+.*[;}]\)\@="  contained contains=phpSCKeyword
  syn match phpStructure "\(\s\|^\)\(abstract\s\+\|final\s\+\)*class\(\s\+.*}\)\@="  contained
  syn match phpStructure "\(\s\|^\)interface\(\s\+.*}\)\@="  contained
  syn match phpException "\(\s\|^\)try\(\s\+.*}\)\@="  contained
  syn match phpException "\(\s\|^\)catch\(\s\+.*}\)\@="  contained

  set foldmethod=syntax
  syn region phpFoldHtmlInside matchgroup=Delimiter start="?>" end="<?\(php\)\=" contained transparent contains=@htmlTop
  syn region phpFoldFunction matchgroup=Storageclass start="^\z(\s*\)\(abstract\s\+\|final\s\+\|private\s\+\|protected\s\+\|public\s\+\|static\s\+\)*function\s\([^};]*$\)\@="rs=e-9 matchgroup=Delimiter end="^\z1}" contains=@phpClFunction,phpFoldHtmlInside,phpFCKeyword contained transparent fold extend
  syn region phpFoldFunction matchgroup=Define start="^function\s\([^};]*$\)\@=" matchgroup=Delimiter end="^}" contains=@phpClFunction,phpFoldHtmlInside contained transparent fold extend
  syn region phpFoldClass matchgroup=Structure start="^\z(\s*\)\(abstract\s\+\|final\s\+\)*class\s\+\([^}]*$\)\@=" matchgroup=Delimiter end="^\z1}" contains=@phpClFunction,phpFoldFunction,phpSCKeyword contained transparent fold extend
  syn region phpFoldInterface matchgroup=Structure start="^\z(\s*\)interface\s\+\([^}]*$\)\@=" matchgroup=Delimiter end="^\z1}" contains=@phpClFunction,phpFoldFunction contained transparent fold extend
  syn region phpFoldCatch matchgroup=Exception start="^\z(\s*\)catch\s\+\([^}]*$\)\@=" matchgroup=Delimiter end="^\z1}" contains=@phpClFunction,phpFoldFunction contained transparent fold extend
  syn region phpFoldTry matchgroup=Exception start="^\z(\s*\)try\s\+\([^}]*$\)\@=" matchgroup=Delimiter end="^\z1}" contains=@phpClFunction,phpFoldFunction contained transparent fold extend
elseif exists("php_folding") && php_folding==2
  set foldmethod=syntax
  syn region phpFoldHtmlInside matchgroup=Delimiter start="?>" end="<?\(php\)\=" contained transparent contains=@htmlTop
  syn region phpParent matchgroup=Delimiter start="{" end="}"  contained contains=@phpClFunction,phpFoldHtmlInside transparent fold
endif

" Sync
if php_sync_method==-1
  syn sync match phpRegionSync grouphere phpRegion "^\s*<?\(php\)\=\s*$"
  syn sync match phpRegionSync grouphere NONE "^\s*?>\s*$"
  syn sync match phpRegionSync grouphere NONE "^\s*%>\s*$"
  syn sync match phpRegionSync grouphere phpRegion "function\s.*(.*\$"
elseif php_sync_method>0
  exec "syn sync minlines=" . php_sync_method
else
  exec "syn sync fromstart"
endif

" Define the default highlighting.
" For version 5.8 and later: only when an item doesn't have highlighting yet
if !exists("did_php_syn_inits")

  hi def link phpCommentTitle     SpecialComment
  hi def link phpComment          Comment
  hi def link phpDocComment       Comment
  hi def link phpCommentStar      Comment
  hi def link phpMagicConstants   Constant
  hi def link phpServerVars       Constant
  hi def link phpConstants        Constant
  hi def link phpBoolean          Boolean
  hi def link phpNumber           Number
  hi def link phpStringSingle     String
  hi def link phpStringDouble     String
  hi def link phpBacktick         String
  hi def link phpStringDelimiter  String
  hi def link phpHereDoc          String
  hi def link phpNowDoc           String
  hi def link phpFunctions        Function
  hi def link phpMethods          Function
  hi def link phpClasses          StorageClass
  hi def link phpException        StorageClass
  hi def link phpIdentifier       Identifier
  hi def link phpIdentifierSimply Identifier
  hi def link phpDocIdentifier    Identifier
  hi def link phpStatement        Statement
  hi def link phpStructure        Statement
  hi def link phpOperator         Operator
  hi def link phpVarSelector      Operator
  hi def link phpCommentSelector  PreProc
  hi def link phpInclude          PreProc
  hi def link phpDefine           PreProc
  hi def link phpKeyword          Keyword
  hi def link phpFCKeyword        Keyword
  hi def link phpSCKeyword        Keyword
  hi def link phpSuperglobals     Type
  hi def link phpType             Type
  hi def link phpDocParam         Type
  hi def link phpMemberSelector   Operator
  hi def link phpDocTags          Special
  hi def link phpParent           Special
  hi def link phpSpecialChar      SpecialChar
  hi def link phpStrEsc           SpecialChar
  hi def link phpParentError      Error
  hi def link phpOctalError       Error
  hi def link phpTodo             Todo

endif

let b:current_syntax = "php"

if main_syntax == 'php'
  unlet main_syntax
endif

" vim: ts=8 sts=2 sw=2 expandtab
